@@ -1,15 +1,16 @@
 #include <iostream>
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 #include <set>
 
-#include "zypp/Url.h"
-#include "zypp/PathInfo.h"
-#include "zypp/base/Easy.h"
-#include "zypp/media/MediaUserAuth.h"
+#include <zypp/Url.h>
+#include <zypp/PathInfo.h>
+#include <zypp/base/Easy.h>
+#include <zypp/media/MediaUserAuth.h>
 
-#include "zypp/media/CredentialFileReader.h"
+#include <zypp/media/CredentialFileReader.h>
 
-using namespace std;
+using std::cout;
+using std::endl;
 using namespace zypp;
 using namespace zypp::media;
 
