@@ -1,13 +1,13 @@
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 #include <iostream>
 #include <list>
 #include <map>
 
-#include "zypp/ZConfig.h"
-#include "zypp/Pathname.h"
-#include "zypp/Url.h"
-#include "zypp/base/ValueTransform.h"
-#include "zypp/repo/RepoVariables.h"
+#include <zypp/ZConfig.h>
+#include <zypp/Pathname.h>
+#include <zypp/Url.h>
+#include <zypp/base/ValueTransform.h>
+#include <zypp/repo/RepoVariables.h>
 
 using std::cout;
 using std::endl;
