@@ -1,10 +1,10 @@
 #include <stdio.h>
 #include <iostream>
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 
-#include "zypp/base/LogTools.h"
-#include "zypp/base/Easy.h"
-#include "zypp/sat/Queue.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/Easy.h>
+#include <zypp/sat/Queue.h>
 
 
 #define BOOST_TEST_MODULE Queue
