@@ -4,16 +4,15 @@
 #include <list>
 #include <string>
 
-#include "zypp/base/Logger.h"
-#include "zypp/base/Exception.h"
+#include <zypp/base/Logger.h>
+#include <zypp/base/Exception.h>
 
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 
-#include "zypp/ProgressData.h"
+#include <zypp/ProgressData.h>
 
 using boost::unit_test::test_case;
 
-using namespace std;
 using namespace zypp;
 
 BOOST_AUTO_TEST_CASE(progressdata_test)
