@@ -4,18 +4,17 @@
 #include <string>
 
 // Boost.Test
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 
-#include "zypp/base/Logger.h"
-#include "zypp/base/Exception.h"
-#include "zypp/ZYppFactory.h"
-#include "zypp/ZYpp.h"
-#include "zypp/Pattern.h"
+#include <zypp/base/Logger.h>
+#include <zypp/base/Exception.h>
+#include <zypp/ZYppFactory.h>
+#include <zypp/ZYpp.h>
+#include <zypp/Pattern.h>
 
 #include "TestSetup.h"
 
 using boost::unit_test::test_case;
-using namespace std;
 using namespace zypp;
 
 
