@@ -3,16 +3,15 @@
 #include <list>
 #include <string>
 
-#include "zypp/base/Logger.h"
-#include "zypp/base/Exception.h"
-#include "zypp/Signature.h"
+#include <zypp/base/Logger.h>
+#include <zypp/base/Exception.h>
+#include <zypp/Signature.h>
 
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 
 using boost::unit_test::test_suite;
 using boost::unit_test::test_case;
 
-using namespace std;
 using namespace zypp;
 
 
