@@ -13,12 +13,12 @@
 #include <list>
 #include <inttypes.h>
 
-#include "zypp/base/Logger.h"
-#include "zypp/base/Exception.h"
-#include "zypp/base/NonCopyable.h"
-#include "zypp/base/Hash.h"
-#include "zypp/Arch.h"
-#include "zypp/Bit.h"
+#include <zypp/base/Logger.h>
+#include <zypp/base/Exception.h>
+#include <zypp/base/NonCopyable.h>
+#include <zypp/base/Hash.h>
+#include <zypp/Arch.h>
+#include <zypp/Bit.h>
 
 using std::endl;
 
@@ -209,6 +209,8 @@ namespace zypp
   DEF_BUILTIN( armv4l );
   DEF_BUILTIN( armv3l );
 
+  DEF_BUILTIN( riscv64 );
+
   DEF_BUILTIN( sh3 );
 
   DEF_BUILTIN( sh4 );
@@ -357,6 +359,8 @@ namespace zypp
 
         defCompatibleWith( a_aarch64(),		a_noarch() );
         //
+        defCompatibleWith( a_riscv64(),		a_noarch() );
+        //
         defCompatibleWith( a_sh3(),		a_noarch() );
         //
         defCompatibleWith( a_sh4(),		a_noarch() );
