@@ -12,9 +12,9 @@
 #include <iostream>
 #include <set>
 
-#include "zypp/Changelog.h"
+#include <zypp/Changelog.h>
 
-using namespace std;
+using std::endl;
 
 namespace zypp
 { /////////////////////////////////////////////////////////////////
