@@ -11,11 +11,11 @@
 #include <iostream>
 #include <array>
 
-#include "zypp/base/String.h"
-#include "zypp/base/LogTools.h"
-#include "zypp/base/NonCopyable.h"
+#include <zypp/base/String.h>
+#include <zypp/base/LogTools.h>
+#include <zypp/base/NonCopyable.h>
 
-#include "zypp/CpeId.h"
+#include <zypp/CpeId.h>
 
 using std::endl;
 
@@ -75,6 +75,8 @@ namespace zypp
   } // namespace
   ///////////////////////////////////////////////////////////////////
 
+  constexpr CpeId::NoThrowType CpeId::noThrow;
+
   ///////////////////////////////////////////////////////////////////
   /// \class CpeId::Impl
   /// \brief CpeId implementation.
@@ -442,6 +444,9 @@ namespace zypp
   const CpeId::Value CpeId::Value::ANY;
   const CpeId::Value CpeId::Value::NA( "" );
 
+  constexpr CpeId::Value::FsFormatType CpeId::Value::fsFormat;
+  constexpr CpeId::Value::UriFormatType CpeId::Value::uriFormat;
+
   CpeId::Value::Value( const std::string & value_r )
   {
     if ( value_r.empty() )	// NA
