@@ -26,8 +26,10 @@
 #include <fstream>
 #endif
 
-#include "zypp/Digest.h"
-#include "zypp/base/PtrTypes.h"
+#include <zypp/Digest.h>
+#include <zypp/base/PtrTypes.h>
+
+using std::endl;
 
 namespace zypp {
 
@@ -86,7 +88,6 @@ namespace zypp {
     };
 
 
-    using namespace std;
 
     bool Digest::P::openssl_digests_added = false;
 
@@ -187,26 +188,21 @@ namespace zypp {
 
     std::string Digest::digest()
     {
-      if(!_dp->maybeInit())
-    	return std::string();
+      return digestVectorToString( digestVector() );
+    }
 
-      if(!_dp->finalized)
+    std::string Digest::digestVectorToString(const std::vector<unsigned char> &vec)
+    {
+      if ( vec.empty() )
+        return std::string();
+
+      std::vector<char> resData ( vec.size()*2 + 1, '\0' );
+      char *mdtxt = &resData[0];
+      for(unsigned i = 0; i < vec.size(); ++i)
       {
-      if(!EVP_DigestFinal_ex(_dp->mdctx.get(), _dp->md_value, &_dp->md_len))
-    	    return std::string();
-
-    	_dp->finalized = true;
+        ::snprintf( mdtxt+(i*2), 3, "%02hhx", vec[i]);
       }
-
-      char mdtxt[_dp->md_len*2 + 1];
-      mdtxt[_dp->md_len*2] = '\0';
-
-      for(unsigned i = 0; i < _dp->md_len; ++i)
-      {
-    	::snprintf(mdtxt + i*2, 3, "%02hhx", _dp->md_value[i]);
-      }
-
-      return std::string(mdtxt);
+      return std::string( resData.data() );
     }
 
     std::vector<unsigned char> Digest::digestVector()
@@ -250,33 +246,43 @@ namespace zypp {
       return true;
     }
 
-    std::string Digest::digest(const std::string& name, std::istream& is, size_t bufsize)
+    bool Digest::update(std::istream &is, size_t bufsize)
     {
-      if(name.empty() || !is)
-    	return string();
+      if( !is )
+        return false;
 
       char buf[bufsize];
 
-      Digest digest;
-      if(!digest.create(name))
-    	return string();
-
-
       while(is.good())
       {
-        int readed;
+        size_t readed;
         is.read(buf, bufsize);
-    	readed = is.gcount();
-        if(readed && !digest.update(buf, readed))
-    	    return string();
+        readed = is.gcount();
+        if(readed && !update(buf, readed))
+          return false;
       }
 
+      return true;
+    }
+
+    std::string Digest::digest(const std::string& name, std::istream& is, size_t bufsize)
+    {
+      if(name.empty() || !is)
+    	return std::string();
+
+      Digest digest;
+      if(!digest.create(name))
+        return std::string();
+
+      if ( !digest.update( is, bufsize ))
+        return std::string();
+
       return digest.digest();
     }
 
     std::string Digest::digest( const std::string & name, const std::string & input, size_t bufsize )
     {
-      istringstream is( input );
+      std::istringstream is( input );
       return digest( name, is, bufsize );
     }
 
@@ -286,7 +292,7 @@ namespace zypp {
       bool openssl = false;
       unsigned argpos = 1;
 
-      if(argc > 1 && string(argv[argpos]) == "--openssl")
+      if(argc > 1 && std::string(argv[argpos]) == "--openssl")
       {
     	openssl = true;
     	++argpos;
@@ -301,9 +307,9 @@ namespace zypp {
       const char* digestname = argv[argpos++];
       const char* fn = argv[argpos++];
 
-      ifstream file(fn);
+      std::ifstream file(fn);
 
-      string digest = Digest::digest(digestname, file);
+      std::string digest = Digest::digest(digestname, file);
 
       if(openssl)
     	cout << digestname << "(" << fn << ")= " << digest << endl;
