@@ -19,9 +19,9 @@
 #include <string>
 #include <vector>
 
-#include "zypp/APIConfig.h"
-#include "zypp/base/ExternalDataSource.h"
-#include "zypp/Pathname.h"
+#include <zypp/APIConfig.h>
+#include <zypp/base/ExternalDataSource.h>
+#include <zypp/Pathname.h>
 
 namespace zypp {
 
@@ -155,6 +155,11 @@ namespace zypp {
        */
       bool kill();
 
+      /**
+       * Send a signal to the program
+       */
+      bool kill( int sig );
+
       /**
        * Return whether program is running
        */
@@ -231,7 +236,7 @@ namespace zypp {
       void start_program (const char *const *argv, const Environment & environment,
     			Stderr_Disposition stderr_disp = Normal_Stderr,
     			int stderr_fd = -1, bool default_locale = false,
-    			const char* root = NULL, bool switch_pgid = false);
+    			const char* root = NULL, bool switch_pgid = false, bool die_with_parent = false );
 
     };
 
