@@ -10,24 +10,24 @@
 #include <set>
 #include <fstream>
 #include <boost/function.hpp>
-#include <boost/function_output_iterator.hpp>
+#include <boost/iterator/function_output_iterator.hpp>
 #include <algorithm>
 
-#include "zypp/base/Regex.h"
-#include "zypp/base/String.h"
-#include "zypp/base/LogTools.h"
-#include "zypp/base/IOStream.h"
-#include "zypp/PoolItem.h"
-#include "zypp/PoolQueryUtil.tcc"
-#include "zypp/ZYppCallbacks.h"
-#include "zypp/sat/SolvAttr.h"
-#include "zypp/sat/Solvable.h"
-#include "zypp/PathInfo.h"
+#include <zypp/base/Regex.h>
+#include <zypp/base/String.h>
+#include <zypp/base/LogTools.h>
+#include <zypp/base/IOStream.h>
+#include <zypp/PoolItem.h>
+#include <zypp/PoolQueryUtil.tcc>
+#include <zypp/ZYppCallbacks.h>
+#include <zypp/sat/SolvAttr.h>
+#include <zypp/sat/Solvable.h>
+#include <zypp/PathInfo.h>
 
 #undef ZYPP_BASE_LOGGER_LOGGROUP
 #define ZYPP_BASE_LOGGER_LOGGROUP "locks"
 
-#include "zypp/Locks.h"
+#include <zypp/Locks.h>
 
 using std::endl;
 
@@ -257,7 +257,6 @@ void Locks::removeLock( const ResKind &kind_r, const IdString &name_r )
   q.addKind( kind_r );
   q.setMatchExact();
   q.setCaseSensitive(true);
-  q.requireAll();
   DBG << "remove lock by Selectable" << endl;
   removeLock(q);
 }
