@@ -18,17 +18,17 @@
 #include <fstream>
 #include <iomanip>
 
-#include "zypp/base/LogTools.h"
-#include "zypp/base/String.h"
-#include "zypp/base/IOStream.h"
-#include "zypp/base/StrMatcher.h"
-#include "zypp/base/Errno.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/String.h>
+#include <zypp/base/IOStream.h>
+#include <zypp/base/StrMatcher.h>
+#include <zypp/base/Errno.h>
 
-#include "zypp/AutoDispose.h"
-#include "zypp/ExternalProgram.h"
-#include "zypp/PathInfo.h"
-#include "zypp/Digest.h"
-#include "zypp/TmpPath.h"
+#include <zypp/AutoDispose.h>
+#include <zypp/ExternalProgram.h>
+#include <zypp/PathInfo.h>
+#include <zypp/Digest.h>
+#include <zypp/TmpPath.h>
 
 using std::endl;
 using std::string;
@@ -331,11 +331,11 @@ namespace zypp
       }
 
       string spath = path.asString()+"/";
-      string::size_type lastpos = ( path.relative() ? 2 : 1 ); // skip leasding './' or '/'
-      string::size_type pos = string::npos;
+      std::string::size_type lastpos = ( path.relative() ? 2 : 1 ); // skip leasding './' or '/'
+      std::string::size_type pos = std::string::npos;
       int ret = 0;
 
-      while ( (pos = spath.find('/',lastpos)) != string::npos )
+      while ( (pos = spath.find('/',lastpos)) != std::string::npos )
       {
         string dir( spath.substr(0,pos) );
         ret = ::mkdir( dir.c_str(), mode );
@@ -423,6 +423,15 @@ namespace zypp
         return logResult( ENOTDIR );
       }
 
+      p.lstat();	// get dir symlinks
+      if ( !p.isDir() ) {
+	MIL << "unlink symlink ";
+	if ( ::unlink( path.asString().c_str() ) == -1 ) {
+	  return logResult( errno );
+	}
+	return logResult( 0 );
+      }
+
       return logResult( recursive_rmdir_1( path ) );
     }
 
@@ -1081,7 +1090,7 @@ namespace zypp
       int fd = open( file.asString().c_str(), O_RDONLY|O_CLOEXEC );
 
       if ( fd != -1 ) {
-        const int magicSize = 3;
+        const int magicSize = 5;
         unsigned char magic[magicSize];
         memset( magic, 0, magicSize );
         if ( read( fd, magic, magicSize ) == magicSize ) {
@@ -1089,6 +1098,9 @@ namespace zypp
             ret = ZT_GZ;
           } else if ( magic[0] == 'B' && magic[1] == 'Z' && magic[2] == 'h' ) {
             ret = ZT_BZ2;
+          } else if ( magic[0] == '\0' && magic[1] == 'Z' && magic[2] == 'C' && magic[3] == 'K' && magic[4] == '1') {
+            ret = ZT_ZCHNK;
+
           }
         }
         close( fd );
@@ -1149,6 +1161,33 @@ namespace zypp
       return logResult( 0 );
     }
 
+    int assert_file_mode( const Pathname & path, unsigned mode )
+    {
+      int ret = assert_dir( path.dirname() );
+      MIL << "assert_file_mode " << str::octstring( mode ) << " " << path;
+      if ( ret != 0 )
+        return logResult( ret );
+
+      PathInfo pi( path );
+      if ( pi.isExist() )
+      {
+	if ( ! pi.isFile() )
+	  return logResult( EEXIST );
+
+	mode = applyUmaskTo( mode );
+	if ( pi.st_mode() != mode )
+	  return chmod( path, mode );
+
+	return logResult( 0 );
+      }
+
+      int fd = ::creat( path.c_str(), mode );
+      if ( fd == -1 )
+        return logResult( errno );
+      ::close( fd );
+      return logResult( 0 );
+    }
+
     ///////////////////////////////////////////////////////////////////
     //
     //  METHOD NAME : touch
