@@ -27,9 +27,9 @@ extern "C"
 #include <set>
 #include <map>
 
-#include "zypp/Pathname.h"
-#include "zypp/CheckSum.h"
-#include "zypp/ByteCount.h"
+#include <zypp/Pathname.h>
+#include <zypp/CheckSum.h>
+#include <zypp/ByteCount.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -581,6 +581,10 @@ namespace zypp
      * @return 0 on success, errno on failure
      **/
     int assert_file( const Pathname & path, unsigned mode = 0644 );
+    /**
+     * Like \ref assert_file but enforce \a mode even if the file already exists.
+     */
+    int assert_file_mode( const Pathname & path, unsigned mode = 0644 );
 
     /**
      * Change file's modification and access times.
@@ -771,7 +775,7 @@ namespace zypp
      *
      * @return ZT_GZ, ZT_BZ2 if file is compressed, otherwise ZT_NONE.
      **/
-    enum ZIP_TYPE { ZT_NONE, ZT_GZ, ZT_BZ2 };
+    enum ZIP_TYPE { ZT_NONE, ZT_GZ, ZT_BZ2, ZT_ZCHNK };
 
     ZIP_TYPE zipType( const Pathname & file );
 
