@@ -12,23 +12,23 @@
 #include <iostream>
 #include <sstream>
 
-#include "zypp/base/Gettext.h"
-#include "zypp/base/LogTools.h"
-#include "zypp/base/Algorithm.h"
-#include "zypp/base/String.h"
-#include "zypp/repo/RepoException.h"
-#include "zypp/RelCompare.h"
+#include <zypp/base/Gettext.h>
+#include <zypp/base/LogTools.h>
+#include <zypp/base/Algorithm.h>
+#include <zypp/base/String.h>
+#include <zypp/repo/RepoException.h>
+#include <zypp/RelCompare.h>
 
-#include "zypp/sat/Pool.h"
-#include "zypp/sat/Solvable.h"
-#include "zypp/base/StrMatcher.h"
+#include <zypp/sat/Pool.h>
+#include <zypp/sat/Solvable.h>
+#include <zypp/base/StrMatcher.h>
 
-#include "zypp/PoolQuery.h"
+#include <zypp/PoolQuery.h>
 
 #undef ZYPP_BASE_LOGGER_LOGGROUP
 #define ZYPP_BASE_LOGGER_LOGGROUP "PoolQuery"
 
-using namespace std;
+using std::endl;
 using namespace zypp::sat;
 
 ///////////////////////////////////////////////////////////////////
@@ -418,7 +418,6 @@ namespace zypp
     Impl()
       : _flags( Match::SUBSTRING | Match::NOCASE | Match::SKIP_KIND )
       , _match_word(false)
-      , _require_all(false)
       , _status_flags(ALL)
     {}
 
@@ -427,7 +426,7 @@ namespace zypp
 
   public:
     /** String representation */
-    string asString() const;
+    std::string asString() const;
 
     /** \name Raw query options. */
     //@{
@@ -441,7 +440,6 @@ namespace zypp
     /** Sat solver search flags */
     Match _flags;
     bool _match_word;
-    bool _require_all;
 
     /** Sat solver status flags */
     StatusFilter _status_flags;
@@ -468,7 +466,6 @@ namespace zypp
       OUTS( _uncompiledPredicated );
       OUTS( _flags.get() );
       OUTS( _match_word );
-      OUTS( _require_all );
       OUTS( _status_flags );
       OUTS( _edition );
       OUTS( _op.inSwitch() );
@@ -496,7 +493,6 @@ namespace zypp
 	      && _attrs == rhs._attrs
 	      && _uncompiledPredicated == rhs._uncompiledPredicated
 	      && _match_word == rhs._match_word
-	      && _require_all == rhs._require_all
 	      && _status_flags == rhs._status_flags
 	      && _edition == rhs._edition
 	      && _op == rhs._op
@@ -520,8 +516,10 @@ namespace zypp
     mutable AttrMatchList _attrMatchList;
 
   private:
-    /** Pass flags from \ref compile, as they may have been changed. */
-    string createRegex( const StrContainer & container, const Match & flags ) const;
+    /** Join patterns in \a container_r according to \a flags_r into a single \ref StrMatcher.
+     * The \ref StrMatcher returned will be a REGEX if more than one pattern was passed.
+     */
+    StrMatcher joinedStrMatcher( const StrContainer & container_r, const Match & flags_r ) const;
 
   private:
     friend Impl * rwcowClone<Impl>( const Impl * rhs );
@@ -536,7 +534,7 @@ namespace zypp
   {
     MyInserter(PoolQuery::StrContainer & cont) : _cont(cont) {}
 
-    bool operator()(const string & str)
+    bool operator()(const std::string & str)
     {
       _cont.insert(str);
       return true;
@@ -548,7 +546,7 @@ namespace zypp
 
   struct EmptyFilter
   {
-    bool operator()(const string & str)
+    bool operator()(const std::string & str)
     {
       return !str.empty();
     }
@@ -558,13 +556,8 @@ namespace zypp
   {
     _attrMatchList.clear();
 
-    Match cflags( _flags );
-    if ( cflags.mode() == Match::OTHER ) // this will never succeed...
-      ZYPP_THROW( MatchUnknownModeException( cflags ) );
-
-    /** Compiled search strings. */
-    string rcstrings;
-
+    if ( _flags.mode() == Match::OTHER ) // this will never succeed...
+      ZYPP_THROW( MatchUnknownModeException( _flags ) );
 
     // 'different'         - will have to iterate through all and match by ourselves (slow)
     // 'same'              - will pass the compiled string to dataiterator_init
@@ -589,11 +582,8 @@ namespace zypp
       StrContainer joined;
       invokeOnEach(_strings.begin(), _strings.end(), EmptyFilter(), MyInserter(joined));
       invokeOnEach(_attrs.begin()->second.begin(), _attrs.begin()->second.end(), EmptyFilter(), MyInserter(joined));
-      rcstrings = createRegex(joined, cflags);
-      if (joined.size() > 1) // switch to regex for multiple strings
-        cflags.setModeRegex();
-      _attrMatchList.push_back( AttrMatchData( _attrs.begin()->first,
-                                StrMatcher( rcstrings, cflags ) ) );
+
+      _attrMatchList.push_back( AttrMatchData( _attrs.begin()->first, joinedStrMatcher( joined, _flags ) ) );
     }
 
     // // MULTIPLE ATTRIBUTES
@@ -601,16 +591,21 @@ namespace zypp
     {
       // check whether there are any per-attribute strings
       bool attrvals_empty = true;
-      for (AttrRawStrMap::const_iterator ai = _attrs.begin(); ai != _attrs.end(); ++ai)
-        if (!ai->second.empty())
-          for(StrContainer::const_iterator it = ai->second.begin();
-              it != ai->second.end(); it++)
-            if (!it->empty())
-            {
-              attrvals_empty = false;
-              goto attremptycheckend;
-            }
-attremptycheckend:
+      for_( ai, _attrs.begin(), _attrs.end() )
+      {
+        if ( ai->second.empty() )
+	  continue;
+	for_( it, ai->second.begin(), ai->second.end() )
+	{
+	  if ( !it->empty() )
+	  {
+	    attrvals_empty = false;
+	    break;
+	  }
+	}
+        if ( ! attrvals_empty )
+	  break;
+      }
 
       // chceck whether the per-attribute strings are all the same
       bool attrvals_thesame = true;
@@ -641,18 +636,15 @@ attremptycheckend:
         if (attrvals_empty)
         {
           invokeOnEach(_strings.begin(), _strings.end(), EmptyFilter(), MyInserter(joined));
-          rcstrings = createRegex(joined, cflags);
         }
         else
         {
           invokeOnEach(_strings.begin(), _strings.end(), EmptyFilter(), MyInserter(joined));
           invokeOnEach(_attrs.begin()->second.begin(), _attrs.begin()->second.end(), EmptyFilter(), MyInserter(joined));
-          rcstrings = createRegex(joined, cflags);
         }
-        if (joined.size() > 1) // switch to regex for multiple strings
-          cflags.setModeRegex();
+
         // May use the same StrMatcher for all
-        StrMatcher matcher( rcstrings, cflags );
+        StrMatcher matcher( joinedStrMatcher( joined, _flags ) );
         for_( ai, _attrs.begin(), _attrs.end() )
         {
           _attrMatchList.push_back( AttrMatchData( ai->first, matcher ) );
@@ -670,11 +662,8 @@ attremptycheckend:
           StrContainer joined;
           invokeOnEach(_strings.begin(), _strings.end(), EmptyFilter(), MyInserter(joined));
           invokeOnEach(ai->second.begin(), ai->second.end(), EmptyFilter(), MyInserter(joined));
-          string s = createRegex(joined, cflags);
-          if (joined.size() > 1) // switch to regex for multiple strings
-            cflags.setModeRegex();
-          _attrMatchList.push_back( AttrMatchData( ai->first,
-                                    StrMatcher( s, cflags ) ) );
+
+          _attrMatchList.push_back( AttrMatchData( ai->first, joinedStrMatcher( joined, _flags ) ) );
         }
       }
     }
@@ -694,14 +683,9 @@ attremptycheckend:
           if ( ! mstr.empty() )
             joined.insert( mstr );
 
-          cflags = _flags;
-          rcstrings = createRegex( joined, cflags );
-          if ( joined.size() > 1 ) // switch to regex for multiple strings
-            cflags.setModeRegex();
-
 	  // copy and exchange the StrMatcher
 	  AttrMatchData nattr( *it );
-	  nattr.strMatcher = StrMatcher( rcstrings, cflags ),
+	  nattr.strMatcher = joinedStrMatcher( joined, _flags );
           _attrMatchList.push_back( std::move(nattr) );
         }
         else
@@ -715,12 +699,7 @@ attremptycheckend:
     // If no attributes defined at all, then add 'query all'
     if ( _attrMatchList.empty() )
     {
-      cflags = _flags;
-      rcstrings = createRegex( _strings, cflags );
-      if ( _strings.size() > 1 ) // switch to regex for multiple strings
-        cflags.setModeRegex();
-      _attrMatchList.push_back( AttrMatchData( sat::SolvAttr::allAttr,
-                                StrMatcher( rcstrings, cflags ) ) );
+      _attrMatchList.push_back( AttrMatchData( sat::SolvAttr::allAttr, joinedStrMatcher( _strings, _flags ) ) );
     }
 
     // Finally check here, whether all involved regex compile.
@@ -731,107 +710,67 @@ attremptycheckend:
     //DBG << asString() << endl;
   }
 
-
-  /**
-   * Converts '*' and '?' wildcards within str into their regex equivalents.
-   */
-  static string wildcards2regex(const string & str)
+  ///////////////////////////////////////////////////////////////////
+  namespace
   {
-    string regexed = str;
+    /** Escape \a str_r for use in a regex.
+     * \a flags_r determines whether the input string is interpreted
+     * as regex, glob or plain string.
+     */
+    std::string rxEscape( std::string str_r, const Match & flags_r )
+    {
+      if ( str_r.empty() || flags_r.isModeRegex() )
+	return str_r;
 
-    string r_all(".*"); // regex equivalent of '*'
-    string r_one(".");  // regex equivalent of '?'
-    string::size_type pos;
+      if ( flags_r.isModeGlob() )
+	return str::rxEscapeGlob( std::move(str_r) );
 
-    // replace all "*" in input with ".*"
-    for (pos = 0; (pos = regexed.find("*", pos)) != std::string::npos; pos+=2)
-      regexed = regexed.replace(pos, 1, r_all);
+      return str::rxEscapeStr( std::move(str_r) );
+    }
+  } // namespace
+  ///////////////////////////////////////////////////////////////////
 
-    // replace all "?" in input with "."
-    for (pos = 0; (pos = regexed.find('?', pos)) != std::string::npos; ++pos)
-      regexed = regexed.replace(pos, 1, r_one);
+  StrMatcher PoolQuery::Impl::joinedStrMatcher( const StrContainer & container_r, const Match & flags_r ) const
+  {
+    if ( container_r.empty() )
+      return StrMatcher( std::string(), flags_r );
 
-    return regexed;
+    if ( container_r.size() == 1 && !_match_word )	// use RX to match words
+      return StrMatcher( *container_r.begin(), flags_r );
+
+    // Convert to a regex.
+    // Note: Modes STRING and GLOB match whole strings (anchored ^ $)
+    //       SUBSTRING and REGEX match substrings      (match_word anchores SUBSTRING \b)
+    Match retflags( flags_r );
+    retflags.setModeRegex();
+    str::Str ret;
+
+    if ( flags_r.isModeString() || flags_r.isModeGlob() )
+      ret << "^";
+    else if ( _match_word )
+      ret << "\\b";
+
+    // (..|..|..)
+    char sep = '(';
+    for ( const::std::string & s : container_r )
+    {
+      ret << sep << rxEscape( s, flags_r );
+      if ( sep == '(' )
+	sep = '|';
+    }
+    ret << ')';
+
+    if ( flags_r.isModeString() || flags_r.isModeGlob() )
+      ret << "$";
+    else if ( _match_word )
+      ret << "\\b";
+
+    return StrMatcher( ret, retflags );
   }
 
-  string PoolQuery::Impl::createRegex( const StrContainer & container, const Match & flags ) const
+  std::string PoolQuery::Impl::asString() const
   {
-//! macro for word boundary tags for regexes
-#define WB (_match_word ? string("\\b") : string())
-    string rstr;
-
-    if (container.empty())
-      return rstr;
-
-    if (container.size() == 1)
-    {
-      return WB + *container.begin() + WB;
-    }
-
-    // multiple strings
-
-    bool use_wildcards = flags.isModeGlob();
-    StrContainer::const_iterator it = container.begin();
-    string tmp;
-
-    if (use_wildcards)
-      tmp = wildcards2regex(*it);
-    else
-      tmp = *it;
-
-    if (_require_all)
-    {
-      if ( ! flags.isModeString() ) // not match exact
-        tmp += ".*" + WB + tmp;
-      rstr = "(?=" + tmp + ")";
-    }
-    else
-    {
-      if ( flags.isModeString() || flags.isModeGlob() )
-        rstr = "^";
-      rstr += WB + "(" + tmp;
-    }
-
-    ++it;
-
-    for (; it != container.end(); ++it)
-    {
-      if (use_wildcards)
-        tmp = wildcards2regex(*it);
-      else
-        tmp = *it;
-
-      if (_require_all)
-      {
-        if ( ! flags.isModeString() ) // not match exact
-          tmp += ".*" + WB + tmp;
-        rstr += "(?=" + tmp + ")";
-      }
-      else
-      {
-        rstr += "|" + tmp;
-      }
-    }
-
-    if (_require_all)
-    {
-      if ( ! flags.isModeString() ) // not match exact
-        rstr += WB + ".*";
-    }
-    else
-    {
-      rstr += ")" + WB;
-      if ( flags.isModeString() || flags.isModeGlob() )
-        rstr += "$";
-    }
-
-    return rstr;
-#undef WB
-  }
-
-  string PoolQuery::Impl::asString() const
-  {
-    ostringstream o;
+    std::ostringstream o;
 
     o << "kinds: ";
     if ( _kinds.empty() )
@@ -928,7 +867,7 @@ attremptycheckend:
   void PoolQuery::addKind(const ResKind & kind)
   { _pimpl->_kinds.insert(kind); }
 
-  void PoolQuery::addString(const string & value)
+  void PoolQuery::addString(const std::string & value)
   { _pimpl->_strings.insert(value); }
 
   void PoolQuery::addAttribute(const sat::SolvAttr & attr, const std::string & value)
@@ -1009,15 +948,11 @@ attremptycheckend:
     _pimpl->_op = op;
   }
 
-  void PoolQuery::setMatchSubstring()	{ _pimpl->_flags.setModeSubstring(); }
-  void PoolQuery::setMatchExact()	{ _pimpl->_flags.setModeString(); }
-  void PoolQuery::setMatchRegex()	{ _pimpl->_flags.setModeRegex(); }
-  void PoolQuery::setMatchGlob()	{ _pimpl->_flags.setModeGlob(); }
-  void PoolQuery::setMatchWord()
-  {
-    _pimpl->_match_word = true;
-    _pimpl->_flags.setModeRegex();
-  }
+  void PoolQuery::setMatchSubstring()	{ _pimpl->_flags.setModeSubstring();	_pimpl->_match_word = false; }
+  void PoolQuery::setMatchExact()	{ _pimpl->_flags.setModeString();	_pimpl->_match_word = false; }
+  void PoolQuery::setMatchRegex()	{ _pimpl->_flags.setModeRegex();	_pimpl->_match_word = false; }
+  void PoolQuery::setMatchGlob()	{ _pimpl->_flags.setModeGlob();		_pimpl->_match_word = false; }
+  void PoolQuery::setMatchWord()	{ _pimpl->_flags.setModeSubstring();	_pimpl->_match_word = true; }
 
   Match PoolQuery::flags() const
   { return _pimpl->_flags; }
@@ -1033,10 +968,6 @@ attremptycheckend:
   { _pimpl->_status_flags = flags; }
 
 
-  void PoolQuery::setRequireAll(bool require_all)
-  { _pimpl->_require_all = require_all; }
-
-
   const PoolQuery::StrContainer &
   PoolQuery::strings() const
   { return _pimpl->_strings; }
@@ -1079,15 +1010,10 @@ attremptycheckend:
   { _pimpl->_flags.turn( Match::FILES, value ); }
 
   bool PoolQuery::matchExact() const		{ return _pimpl->_flags.isModeString(); }
-  bool PoolQuery::matchSubstring() const	{ return _pimpl->_flags.isModeSubstring(); }
+  bool PoolQuery::matchSubstring() const	{ return _pimpl->_flags.isModeSubstring() && !_pimpl->_match_word; }
   bool PoolQuery::matchGlob() const		{ return _pimpl->_flags.isModeGlob(); }
   bool PoolQuery::matchRegex() const		{ return _pimpl->_flags.isModeRegex(); }
-
-  bool PoolQuery::matchWord() const
-  { return _pimpl->_match_word; }
-
-  bool PoolQuery::requireAll() const
-  { return _pimpl->_require_all; }
+  bool PoolQuery::matchWord() const		{ return _pimpl->_flags.isModeSubstring() && _pimpl->_match_word; }
 
   PoolQuery::StatusFilter PoolQuery::statusFilterFlags() const
   { return _pimpl->_status_flags; }
@@ -1116,6 +1042,9 @@ attremptycheckend:
   { invokeOnEach( begin(), end(), fnc); }
 
 
+  /*DEPRECATED LEGACY:*/void PoolQuery::setRequireAll( bool ) {}
+  /*DEPRECATED LEGACY:*/bool PoolQuery::requireAll() const    { return false; }
+
   ///////////////////////////////////////////////////////////////////
   //
   //  CLASS NAME : PoolQuery::Attr
@@ -1150,7 +1079,7 @@ attremptycheckend:
     static const PoolQueryAttr kindAttr;
     static const PoolQueryAttr stringAttr;
     static const PoolQueryAttr stringTypeAttr;
-    static const PoolQueryAttr requireAllAttr;
+    static const PoolQueryAttr requireAllAttr;	// LEAGACY: attribute was defined but never implemented.
     static const PoolQueryAttr caseSensitiveAttr;
     static const PoolQueryAttr installStatusAttr;
     static const PoolQueryAttr editionAttr;
@@ -1163,7 +1092,7 @@ attremptycheckend:
   const PoolQueryAttr PoolQueryAttr::kindAttr( "type" );
   const PoolQueryAttr PoolQueryAttr::stringAttr( "query_string" );
   const PoolQueryAttr PoolQueryAttr::stringTypeAttr("match_type");
-  const PoolQueryAttr PoolQueryAttr::requireAllAttr("require_all");
+  const PoolQueryAttr PoolQueryAttr::requireAllAttr("require_all");	// LEAGACY: attribute was defined but never implemented.
   const PoolQueryAttr PoolQueryAttr::caseSensitiveAttr("case_sensitive");
   const PoolQueryAttr PoolQueryAttr::installStatusAttr("install_status");
   const PoolQueryAttr PoolQueryAttr::editionAttr("version");
@@ -1203,10 +1132,10 @@ attremptycheckend:
 
   //\TODO maybe ctor with stream can be usefull
   //\TODO let it throw, let it throw, let it throw.
-  bool PoolQuery::recover( istream &str, char delim )
+  bool PoolQuery::recover( std::istream &str, char delim )
   {
     bool finded_something = false; //indicates some atributes is finded
-    string s;
+    std::string s;
     do {
       if ( str.eof() )
         break;
@@ -1218,7 +1147,7 @@ attremptycheckend:
         continue;
       }
 
-      string::size_type pos = s.find(':');
+      std::string::size_type pos = s.find(':');
       if (s.empty() || pos == s.npos) // some garbage on line... act like blank line
       {
         if (finded_something) //is first blank line after record?
@@ -1233,8 +1162,8 @@ attremptycheckend:
 
       finded_something = true;
 
-      string attrName(str::trim(string(s,0,pos))); // trimmed name of atribute
-      string attrValue(str::trim(string(s,pos+1,s.npos))); //trimmed value
+      std::string attrName(str::trim(std::string(s,0,pos))); // trimmed name of atribute
+      std::string attrValue(str::trim(std::string(s,pos+1,s.npos))); //trimmed value
 
       PoolQueryAttr attribute( attrName );
 
@@ -1287,18 +1216,8 @@ attremptycheckend:
       }
       else if ( attribute==PoolQueryAttr::requireAllAttr )
       {
-        if ( str::strToTrue(attrValue) )
-        {
-          setRequireAll(true);
-        }
-        else if ( !str::strToFalse(attrValue) )
-        {
-          setRequireAll(false);
-        }
-        else
-        {
-          WAR << "unknown boolean value " << attrValue << endl;
-        }
+	// LEAGACY: attribute was defined but never implemented.
+	// Actually it should not occur outside our testcases.
       }
       else if ( attribute==PoolQueryAttr::caseSensitiveAttr )
       {
@@ -1336,7 +1255,7 @@ attremptycheckend:
       }
       else if ( attribute == PoolQueryAttr::editionAttr)
       {
-        string::size_type pos;
+        std::string::size_type pos;
         Rel rel("==");
         if (attrValue.find_first_of("=<>!") == 0)
         {
@@ -1365,7 +1284,7 @@ attremptycheckend:
       }
       else
       {
-        string s = attrName;
+        std::string s = attrName;
         str::replaceAll( s,"_",":" );
         SolvAttr a(s);
 	if ( a == SolvAttr::name || isDependencyAttribute( a ) )
@@ -1383,10 +1302,74 @@ attremptycheckend:
 
     } while ( true );
 
+    // OLD STYLE VERSIONED LOCKS:
+    //	solvable_name: kernel
+    //	version: > 1
+    //
+    // NEW STYLE VERSIONED LOCKS:
+    //	complex: AttrMatchData solvable:name kernel C SolvableRange\ >\ 1\ \"\"
+    //   or
+    //	solvable_name: kernel > 1
+    //
+    // Semantically equivalent as locks, but due to the different syntax
+    // the complex lock is wrongly handled by zypper.
+    //
+    // bsc#1112911: Unfortunately all styles are found in real-life locks-files.
+    // libzypp will try to make sure, when parsing the locks-file, that complex
+    // locks are rewritten into to OLD STYLE queries zypper can handle.
+    if ( !_pimpl->_attrs.count(SolvAttr::name) && _pimpl->_uncompiledPredicated.size() == 1 )
+    {
+      // No OLD STYLE lock for SolvAttr::name and exactly one complex lock...
+      const AttrMatchData & attrmatch {  *_pimpl->_uncompiledPredicated.begin() };
+      if ( attrmatch.attr == SolvAttr::name && attrmatch.strMatcher.flags().mode() == Match::OTHER )
+      {
+	// ...for SolvAttr::name and following the global search flags.
+	// A candidate for a rewrite?
+
+	std::vector<std::string> words;
+	str::splitEscaped( attrmatch.predicateStr, std::back_inserter(words) );
+	if ( words.size() < 4 || words[3].empty() )
+	{
+	  // We have _NO_ arch rule in the complex predicate, so we can simplify it.
+	  //
+	  // NOTE: AFAIK it's not possible to create (or have created) a complex lock
+	  // with arch rule with zypper means. Nevertheless, in case such a rule made it
+	  // into a locks file, it's better to have a strange looking 'zypper locks' list
+	  // than to lock the wrong packages.
+	  // (and remember that you can't use "addAttribute( SolvAttr::arch, ... )" because
+	  // attributes are `OR`ed)
+
+	  // kind
+	  if ( attrmatch.kindPredicate )
+	  {
+	    _pimpl->_kinds.clear();	// an explicit kind overwrites any global one
+	    addKind( attrmatch.kindPredicate );
+	  }
+
+	  // name
+	  addAttribute( SolvAttr::name, attrmatch.strMatcher.searchstring() );
+
+	  // edition
+	  std::vector<std::string> words;
+	  str::splitEscaped( attrmatch.predicateStr, std::back_inserter(words) );
+	  if ( ! words.empty() )
+	  {
+	    if ( words[0] == "EditionRange" || words[0] == "SolvableRange" )
+	    {
+	      setEdition( Edition(words[2]), Rel(words[1]) );
+	    }
+	  }
+
+	  // finally remove the complex lock
+	  _pimpl->_uncompiledPredicated.clear();
+	}
+      }
+    }
+
     return finded_something;
   }
 
-  void PoolQuery::serialize( ostream &str, char delim ) const
+  void PoolQuery::serialize( std::ostream &str, char delim ) const
   {
     //separating delim
     str << delim;
@@ -1442,19 +1425,6 @@ attremptycheckend:
       }
     }
 
-    if( requireAll() != q.requireAll() )
-    {
-      str << "require_all: ";
-      if (requireAll())
-      {
-        str << "on" << delim;
-      }
-      else
-      {
-        str << "off" << delim;
-      }
-    }
-
     if( statusFilterFlags() != q.statusFilterFlags() )
     {
       switch( statusFilterFlags() )
@@ -1478,7 +1448,7 @@ attremptycheckend:
 
     for_( it, attributes().begin(), attributes().end() )
     {
-      string s = it->first.asString();
+      std::string s = it->first.asString();
       str::replaceAll(s,":","_");
       for_( it2,it->second.begin(),it->second.end() )
       {
@@ -1495,10 +1465,10 @@ attremptycheckend:
     str << delim;
   }
 
-  string PoolQuery::asString() const
+  std::string PoolQuery::asString() const
   { return _pimpl->asString(); }
 
-  ostream & operator<<( ostream & str, const PoolQuery & obj )
+  std::ostream & operator<<( std::ostream & str, const PoolQuery & obj )
   { return str << obj.asString(); }
 
   std::ostream & dumpOn( std::ostream & str, const PoolQuery & obj )
