@@ -16,14 +16,14 @@
 #include <set>
 #include <map>
 
-#include "zypp/base/Regex.h"
-#include "zypp/base/PtrTypes.h"
-#include "zypp/base/Function.h"
+#include <zypp/base/Regex.h>
+#include <zypp/base/PtrTypes.h>
+#include <zypp/base/Function.h>
 
-#include "zypp/sat/SolvIterMixin.h"
-#include "zypp/sat/LookupAttr.h"
-#include "zypp/base/StrMatcher.h"
-#include "zypp/sat/Pool.h"
+#include <zypp/sat/SolvIterMixin.h>
+#include <zypp/sat/LookupAttr.h>
+#include <zypp/base/StrMatcher.h>
+#include <zypp/sat/Pool.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -189,8 +189,7 @@ namespace zypp
      * This method can be used multiple times in which case the query strings
      * will be combined (together with strings added via addAttribute()) into
      * a regex. Searched attribute value will match this regex if <b>any</b>
-     * of these strings will match the value. This can be changed by
-     * (not yet implemented) \ref setRequireAll() method.
+     * of these strings will match the value.
      */
     void addString(const std::string & value);
 
@@ -202,8 +201,6 @@ namespace zypp
      * case the query strings will be combined (together with strings added
      * via addString()) into a regex. Searched attribute value will match
      * this regex if <b>any</b> of these strings will match the value.
-     * This can be changed by (not yet implemented) \ref setRequireAll()
-     * method.
      *
      * \note Though it is possible to use dependency attributes like
      * \ref Solv::Attr::provides here, note that the query string is
@@ -374,20 +371,11 @@ namespace zypp
     void setMatchGlob();
     /** Set to use the query strings as regexes */
     void setMatchRegex();
-    /** Set to match words (uses regex) */
+    /** Set substring to match words */
     void setMatchWord();
     //void setLocale(const Locale & locale);
     //@}
 
-    /**
-     * Require that all of the values set by addString or addAttribute
-     * match the values of respective attributes.
-     *
-     * \todo doesn't work yet, don't use this function
-     */
-    void setRequireAll( bool require_all = true );
-
-
     /** \name getters */
     //@{
 
@@ -430,12 +418,6 @@ namespace zypp
     Match::Mode matchMode() const
     { return flags().mode(); }
 
-    /**
-     * Whether all values added via addString() or addAttribute() are required
-     * to match the values of the respective attributes.
-     */
-    bool requireAll() const;
-
     StatusFilter statusFilterFlags() const;
     //@}
 
@@ -487,6 +469,12 @@ namespace zypp
      */
     void setFlags( const Match & flags );
 
+  public:
+    /** \deprecated Attribute was defined but never implemented/used. Will be removed in future versions. */
+    void setRequireAll( bool require_all = true ) ZYPP_DEPRECATED;
+    /** \deprecated Attribute was defined but never implemented/used. Will be removed in future versions. */
+    bool requireAll() const ZYPP_DEPRECATED;
+
   public:
     class Impl;
   private:
