@@ -10,16 +10,16 @@
  *
 */
 #include <iostream>
-#include "zypp/base/LogTools.h"
-#include "zypp/base/StrMatcher.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/StrMatcher.h>
 
-#include "zypp/Product.h"
-#include "zypp/Url.h"
+#include <zypp/Product.h>
+#include <zypp/Url.h>
 
-#include "zypp/sat/LookupAttr.h"
-#include "zypp/sat/WhatProvides.h"
-#include "zypp/sat/WhatObsoletes.h"
-#include "zypp/PoolItem.h"
+#include <zypp/sat/LookupAttr.h>
+#include <zypp/sat/WhatProvides.h>
+#include <zypp/sat/WhatObsoletes.h>
+#include <zypp/PoolItem.h>
 
 using std::endl;
 
@@ -31,20 +31,6 @@ namespace zypp
 
   namespace
   {
-    void fillList( std::list<Url> & ret_r, sat::Solvable solv_r, sat::SolvAttr attr_r )
-    {
-      sat::LookupAttr query( attr_r, solv_r );
-      for_( it, query.begin(), query.end() )
-      {
-        try // ignore malformed urls
-        {
-          ret_r.push_back( Url( it.asString() ) );
-        }
-        catch( const url::UrlException & )
-        {}
-      }
-    }
-
     void fillList( std::list<std::string> & ret_r, sat::Solvable solv_r, sat::SolvAttr attr_r )
     {
       sat::LookupAttr query( attr_r, solv_r );
