@@ -14,17 +14,17 @@
 #include <iostream>
 #include <vector>
 
-#include "zypp/base/Gettext.h"
-#include "zypp/base/String.h"
-#include "zypp/base/Regex.h"
-#include "zypp/PublicKey.h"
-#include "zypp/ExternalProgram.h"
-#include "zypp/TmpPath.h"
-#include "zypp/PathInfo.h"
-#include "zypp/base/Exception.h"
-#include "zypp/base/LogTools.h"
-#include "zypp/Date.h"
-#include "zypp/KeyManager.h"
+#include <zypp/base/Gettext.h>
+#include <zypp/base/String.h>
+#include <zypp/base/Regex.h>
+#include <zypp/PublicKey.h>
+#include <zypp/ExternalProgram.h>
+#include <zypp/TmpPath.h>
+#include <zypp/PathInfo.h>
+#include <zypp/base/Exception.h>
+#include <zypp/base/LogTools.h>
+#include <zypp/Date.h>
+#include <zypp/KeyManager.h>
 
 #include <gpgme.h>
 
@@ -102,6 +102,15 @@ namespace zypp
       return ret;
     }
 
+    std::string keyAlgoName( const gpgme_subkey_t & key_r )
+    {
+      std::string ret;
+      if ( const char * n = ::gpgme_pubkey_algo_name( key_r->pubkey_algo ) )
+	ret = str::Str() << n << ' ' << key_r->length;
+      else
+	ret = "?";
+      return ret;
+    }
   } //namespace
   ///////////////////////////////////////////////////////////////////
 
@@ -190,6 +199,7 @@ namespace zypp
     std::string _id;
     std::string _name;
     std::string _fingerprint;
+    std::string _algoName;
     Date        _created;
     Date        _expires;
 
@@ -237,14 +247,23 @@ namespace zypp
     gpgme_subkey_t sKey = rawData->subkeys;
     if (sKey) {
       shared_ptr<PublicKeyData::Impl> data(new Impl);
-      //libzypp expects the date of the first signature on the first uid
-      if(rawData->uids && rawData->uids->signatures)
+      //libzypp expects the date of the latest signature on the first uid
+      if ( rawData->uids && rawData->uids->signatures ) {
         data->_created = zypp::Date(rawData->uids->signatures->timestamp);
+	// bsc#1179222: The keyring does not order the signatures when multiple
+	// versions of the same key are imported. We take the last signature here,
+	// the one GPGME_EXPORT_MODE_MINIMAL will later use in export.
+	for ( auto t = rawData->uids->signatures->next; t; t = t->next ) {
+	  if ( t->timestamp > data->_created )
+	    data->_created = t->timestamp;
+	}
+      }
       else
         data->_created = zypp::Date(sKey->timestamp);
 
       data->_expires = zypp::Date(sKey->expires);
       data->_fingerprint = str::asString(sKey->fpr);
+      data->_algoName = keyAlgoName( sKey );
       data->_id = str::asString(sKey->keyid);
 
       //get the primary user ID
@@ -298,6 +317,9 @@ namespace zypp
   std::string PublicKeyData::fingerprint() const
   { return _pimpl->_fingerprint; }
 
+  std::string PublicKeyData::algoName() const
+  {  return _pimpl->_algoName; }
+
   Date PublicKeyData::created() const
   { return _pimpl->_created; }
 
@@ -345,13 +367,14 @@ namespace zypp
   }
 
   PublicKeyData::AsciiArt PublicKeyData::asciiArt() const
-  { return AsciiArt( fingerprint() /* TODO: key algorithm could be added as top tile. */ ); }
+  { return AsciiArt( fingerprint(), algoName() ); }
 
   std::ostream & dumpOn( std::ostream & str, const PublicKeyData & obj )
   {
     str << "[" << obj.name() << "]" << endl;
     str << "  fpr " << obj.fingerprint() << endl;
     str << "   id " << obj.id() << endl;
+    str << "  alg " << obj.algoName() << endl;
     str << "  cre " << Date::ValueType(obj.created()) << ' ' << obj.created() << endl;
     str << "  exp " << Date::ValueType(obj.expires()) << ' ' << obj.expiresAsString() << endl;
     str << "  ttl " << obj.daysToLive() << endl;
@@ -393,6 +416,7 @@ namespace zypp
       : _dontUseThisPtrDirectly( new filesystem::TmpFile( sharedFile_r ) )
     { readFromFile(); }
 
+    // private from keyring
     Impl( const filesystem::TmpFile & sharedFile_r, const PublicKeyData & keyData_r )
       : _dontUseThisPtrDirectly( new filesystem::TmpFile( sharedFile_r ) )
       , _keyData( keyData_r )
@@ -404,6 +428,7 @@ namespace zypp
       }
     }
 
+    // private from keyring
     Impl( const PublicKeyData & keyData_r )
       : _keyData( keyData_r )
     {}
@@ -419,23 +444,12 @@ namespace zypp
       { return _hiddenKeys; }
 
     protected:
-      std::string _initHomeDir()	///< readFromFile helper to prepare the 'gpg --homedir'
-      { Pathname ret( zypp::myTmpDir() / "PublicKey" ); filesystem::assert_dir( ret ); return ret.asString(); }
-
       void readFromFile()
       {
         PathInfo info( path() );
         MIL << "Reading pubkey from " << info.path() << " of size " << info.size() << " and sha1 " << filesystem::checksum(info.path(), "sha1") << endl;
 
-        //@TODO is this still required? KeyManagerCtx creates a homedir on the fly
-        static std::string tmppath( _initHomeDir() );
-
-        KeyManagerCtx::Ptr ctx = KeyManagerCtx::createForOpenPGP();
-        if (!ctx || !ctx->setHomedir(tmppath)) {
-          ZYPP_THROW( Exception( std::string("Can't read public key data: Setting the keyring path failed!")) );
-        }
-
-        std::list<PublicKeyData> keys = ctx->readKeyFromFile(path());
+        std::list<PublicKeyData> keys = KeyManagerCtx::createForOpenPGP().readKeyFromFile( path() );
         switch ( keys.size() )
         {
           case 0:
@@ -524,6 +538,9 @@ namespace zypp
   std::string PublicKey::fingerprint() const
   { return keyData().fingerprint(); }
 
+  std::string PublicKey::algoName() const
+  { return keyData().algoName(); }
+
   Date PublicKey::created() const
   { return keyData().created(); }
 
