@@ -18,13 +18,13 @@
 #include <set>
 #include <string>
 
-#include "zypp/base/Iterable.h"
-#include "zypp/base/PtrTypes.h"
-#include "zypp/base/Exception.h"
-#include "zypp/base/DrunkenBishop.h"
-#include "zypp/Pathname.h"
-#include "zypp/Edition.h"
-#include "zypp/Date.h"
+#include <zypp/base/Iterable.h>
+#include <zypp/base/PtrTypes.h>
+#include <zypp/base/Exception.h>
+#include <zypp/base/DrunkenBishop.h>
+#include <zypp/Pathname.h>
+#include <zypp/Edition.h>
+#include <zypp/Date.h>
 
 struct _gpgme_key;
 struct _gpgme_subkey;
@@ -115,7 +115,7 @@ namespace zypp
     std::string asString() const;
 
   private:
-    class Impl;
+    struct Impl;
     RWCOW_pointer<Impl> _pimpl;
     friend class PublicKeyData;
     friend std::ostream & dumpOn( std::ostream & str, const PublicKeyData & obj );
@@ -157,6 +157,9 @@ namespace zypp
     /** Key fingerprint.*/
     std::string fingerprint() const;
 
+    /** Key algorithm string like `RSA 2048` */
+    std::string algoName() const;
+
     /** Creation / last modification date (latest selfsig). */
     Date created() const;
 
@@ -233,7 +236,7 @@ namespace zypp
     AsciiArt asciiArt() const;
 
   private:
-    class Impl;
+    struct Impl;
     RWCOW_pointer<Impl> _pimpl;
 
     friend class KeyManagerCtx;
@@ -273,7 +276,7 @@ namespace zypp
   {
   public:
     /** Implementation  */
-    class Impl;
+    struct Impl;
 
   public:
     /** Default ctor. */
@@ -311,6 +314,7 @@ namespace zypp
     std::string id() const;			//!< \see \ref PublicKeyData
     std::string name() const;			//!< \see \ref PublicKeyData
     std::string fingerprint() const;		//!< \see \ref PublicKeyData
+    std::string algoName() const;		//!< \see \ref PublicKeyData
     Date created() const;			//!< \see \ref PublicKeyData
     Date expires() const;			//!< \see \ref PublicKeyData
     std::string expiresAsString() const;	//!< \see \ref PublicKeyData
