@@ -15,16 +15,16 @@
 #include <list>
 #include <set>
 
-#include "zypp/base/Iterator.h"
-#include "zypp/APIConfig.h"
+#include <zypp/base/Iterator.h>
+#include <zypp/APIConfig.h>
 
-#include "zypp/Url.h"
-#include "zypp/Locale.h"
-#include "zypp/TriBool.h"
-#include "zypp/repo/RepoType.h"
-#include "zypp/repo/RepoVariables.h"
+#include <zypp/Url.h>
+#include <zypp/Locale.h>
+#include <zypp/TriBool.h>
+#include <zypp/repo/RepoType.h>
+#include <zypp/repo/RepoVariables.h>
 
-#include "zypp/repo/RepoInfoBase.h"
+#include <zypp/repo/RepoInfoBase.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -204,10 +204,13 @@ namespace zypp
        * \param url The base url for the list
        */
       void setMirrorListUrl( const Url &url );
-      /**
-       * Like \ref setMirrorListUrl but expect metalink format.
-       */
+      /** Like \ref setMirrorListUrl but take an \a url_set */
+      void setMirrorListUrls( url_set urls );
+
+      /** Like \ref setMirrorListUrl but expect metalink format. */
       void setMetalinkUrl( const Url &url );
+      /** Like \ref setMirrorListUrls but expect metalink format. */
+      void setMetalinkUrls( url_set urls );
 
       /**
        * Type of repository,
@@ -541,7 +544,7 @@ namespace zypp
        */
       virtual std::ostream & dumpAsXmlOn( std::ostream & str, const std::string & content = "" ) const;
 
-      class Impl;
+      struct Impl;
     private:
       friend class RepoManager;
       /** Raw values for RepoManager */
