@@ -20,39 +20,37 @@
 
 #include <solv/solvversion.h>
 
-#include "zypp/base/String.h"
-#include "zypp/base/InputStream.h"
-#include "zypp/base/LogTools.h"
-#include "zypp/base/Gettext.h"
-#include "zypp/base/DefaultIntegral.h"
-#include "zypp/base/Function.h"
-#include "zypp/base/Regex.h"
-#include "zypp/PathInfo.h"
-#include "zypp/TmpPath.h"
+#include <zypp/base/InputStream.h>
+#include <zypp/base/LogTools.h>
+#include <zypp/base/Gettext.h>
+#include <zypp/base/DefaultIntegral.h>
+#include <zypp/base/Function.h>
+#include <zypp/base/Regex.h>
+#include <zypp/PathInfo.h>
+#include <zypp/TmpPath.h>
 
-#include "zypp/ServiceInfo.h"
-#include "zypp/repo/RepoException.h"
-#include "zypp/RepoManager.h"
+#include <zypp/ServiceInfo.h>
+#include <zypp/repo/RepoException.h>
+#include <zypp/RepoManager.h>
 
-#include "zypp/media/MediaManager.h"
-#include "zypp/media/CredentialManager.h"
-#include "zypp/MediaSetAccess.h"
-#include "zypp/ExternalProgram.h"
-#include "zypp/ManagedFile.h"
-#include "zypp/KeyManager.h"
+#include <zypp/media/MediaManager.h>
+#include <zypp/media/CredentialManager.h>
+#include <zypp/MediaSetAccess.h>
+#include <zypp/ExternalProgram.h>
+#include <zypp/ManagedFile.h>
 
-#include "zypp/parser/RepoFileReader.h"
-#include "zypp/parser/ServiceFileReader.h"
-#include "zypp/repo/ServiceRepos.h"
-#include "zypp/repo/yum/Downloader.h"
-#include "zypp/repo/susetags/Downloader.h"
-#include "zypp/repo/PluginServices.h"
+#include <zypp/parser/RepoFileReader.h>
+#include <zypp/parser/ServiceFileReader.h>
+#include <zypp/repo/ServiceRepos.h>
+#include <zypp/repo/yum/Downloader.h>
+#include <zypp/repo/susetags/Downloader.h>
+#include <zypp/repo/PluginServices.h>
 
-#include "zypp/Target.h" // for Target::targetDistribution() for repo index services
-#include "zypp/ZYppFactory.h" // to get the Target from ZYpp instance
-#include "zypp/HistoryLog.h" // to write history :O)
+#include <zypp/Target.h> // for Target::targetDistribution() for repo index services
+#include <zypp/ZYppFactory.h> // to get the Target from ZYpp instance
+#include <zypp/HistoryLog.h> // to write history :O)
 
-#include "zypp/ZYppCallbacks.h"
+#include <zypp/ZYppCallbacks.h>
 
 #include "sat/Pool.h"
 
@@ -816,11 +814,20 @@ namespace zypp
 	std::set<std::string> oldfiles;
 	set_difference( entries.begin(), entries.end(), repoEscAliases_r.begin(), repoEscAliases_r.end(),
 			std::inserter( oldfiles, oldfiles.end() ) );
+
+	// bsc#1178966: Files or symlinks here have been created by the user
+	// for whatever purpose. It's our cache, so we purge them now before
+	// they may later conflict with directories we need.
+	PathInfo pi;
 	for ( const std::string & old : oldfiles )
 	{
 	  if ( old == Repository::systemRepoAlias() )	// don't remove the @System solv file
 	    continue;
-	  filesystem::recursive_rmdir( cachePath_r / old );
+	  pi( cachePath_r/old );
+	  if ( pi.isDir() )
+	    filesystem::recursive_rmdir( pi.path() );
+	  else
+	    filesystem::unlink( pi.path() );
 	}
       }
     }
@@ -903,6 +910,10 @@ namespace zypp
     if ( repokind == RepoType::NONE )
       repokind = probeCache( productdatapath );
 
+    // NOTE: The calling code expects an empty RepoStatus being returned
+    // if the metadata cache is empty. So additioanl components like the
+    // RepoInfos status are joined after the switch IFF the status is not
+    // empty.
     RepoStatus status;
     switch ( repokind.toEnum() )
     {
@@ -915,7 +926,7 @@ namespace zypp
 	break;
 
       case RepoType::RPMPLAINDIR_e :
-	status = RepoStatus::fromCookieFile( productdatapath/"cookie" );
+	status = RepoStatus::fromCookieFile( productdatapath/"cookie" );	// dir status at last refresh
 	break;
 
       case RepoType::NONE_e :
@@ -924,6 +935,10 @@ namespace zypp
         // ZYPP_THROW(RepoUnknownTypeException());
 	break;
     }
+
+    if ( ! status.empty() )
+      status = status && RepoStatus( info );
+
     return status;
   }
 
@@ -970,12 +985,13 @@ namespace zypp
     assert_alias(info);
     try
     {
-      MIL << "Going to try to check whether refresh is needed for " << url << " (" << info.type() << ")" << endl;
+      MIL << "Check if to refresh repo " << info.alias() << " at " << url << " (" << info.type() << ")" << endl;
 
       // first check old (cached) metadata
       Pathname mediarootpath = rawcache_path_for_repoinfo( _options, info );
       filesystem::assert_dir( mediarootpath );
       RepoStatus oldstatus = metadataStatus( info );
+
       if ( oldstatus.empty() )
       {
         MIL << "No cached metadata, going to refresh" << endl;
@@ -999,33 +1015,37 @@ namespace zypp
 	policy = RefreshIfNeededIgnoreDelay;
       }
 
-      // now we've got the old (cached) status, we can decide repo.refresh.delay
+      // Check whether repo.refresh.delay applies...
       if ( policy != RefreshIfNeededIgnoreDelay )
       {
-        // difference in seconds
-        double diff = difftime(
-          (Date::ValueType)Date::now(),
-          (Date::ValueType)oldstatus.timestamp()) / 60;
+	// bsc#1174016: Prerequisite to skipping the refresh is that metadata
+	// and solv cache status match. They will not, if the repos URL was
+	// changed e.g. due to changed repovars.
+	RepoStatus cachestatus = cacheStatus( info );
 
-        DBG << "oldstatus: " << (Date::ValueType)oldstatus.timestamp() << endl;
-        DBG << "current time: " << (Date::ValueType)Date::now() << endl;
-        DBG << "last refresh = " << diff << " minutes ago" << endl;
-
-        if ( diff < ZConfig::instance().repo_refresh_delay() )
-        {
-	  if ( diff < 0 )
+	if ( oldstatus == cachestatus )
+	{
+	  // difference in seconds
+	  double diff = ::difftime( (Date::ValueType)Date::now(), (Date::ValueType)oldstatus.timestamp() ) / 60;
+	  if ( diff < ZConfig::instance().repo_refresh_delay() )
 	  {
-	    WAR << "Repository '" << info.alias() << "' was refreshed in the future!" << endl;
+	    if ( diff < 0 )
+	    {
+	      WAR << "Repository '" << info.alias() << "' was refreshed in the future!" << endl;
+	    }
+	    else
+	    {
+	      MIL << "Repository '" << info.alias()
+	      << "' has been refreshed less than repo.refresh.delay ("
+	      << ZConfig::instance().repo_refresh_delay()
+	      << ") minutes ago. Advising to skip refresh" << endl;
+	      return REPO_CHECK_DELAYED;
+	    }
 	  }
-	  else
-	  {
-	    MIL << "Repository '" << info.alias()
-		<< "' has been refreshed less than repo.refresh.delay ("
-		<< ZConfig::instance().repo_refresh_delay()
-		<< ") minutes ago. Advising to skip refresh" << endl;
-	    return REPO_CHECK_DELAYED;
-	  }
-        }
+	}
+	else {
+	  MIL << "Metadata and solv cache don't match. Check data on server..." << endl;
+	}
       }
 
       repo::RepoType repokind = info.type();
@@ -1040,19 +1060,19 @@ namespace zypp
 	case RepoType::RPMMD_e:
 	{
 	  MediaSetAccess media( url );
-	  newstatus = yum::Downloader( info, mediarootpath ).status( media );
+	  newstatus = RepoStatus( info ) && yum::Downloader( info, mediarootpath ).status( media );
 	}
 	break;
 
 	case RepoType::YAST2_e:
 	{
 	  MediaSetAccess media( url );
-	  newstatus = susetags::Downloader( info, mediarootpath ).status( media );
+	  newstatus = RepoStatus( info ) && susetags::Downloader( info, mediarootpath ).status( media );
 	}
 	break;
 
 	case RepoType::RPMPLAINDIR_e:
-	  newstatus = RepoStatus( MediaMounter(url).getPathName(info.path()) );	// dir status
+	  newstatus = RepoStatus( info ) && RepoStatus( MediaMounter(url).getPathName(info.path()) );	// dir status
 	  break;
 
 	default:
@@ -1120,20 +1140,24 @@ namespace zypp
 	  if ( repokind != probed )
 	  {
 	    repokind = probed;
-	    // Adjust the probed type in RepoInfo
-	    info.setProbedType( repokind ); // lazy init!
-	    //save probed type only for repos in system
+	    // update probed type only for repos in system
 	    for_( it, repoBegin(), repoEnd() )
 	    {
 	      if ( info.alias() == (*it).alias() )
 	      {
-		RepoInfo modifiedrepo = info;
+		RepoInfo modifiedrepo = *it;
 		modifiedrepo.setType( repokind );
-		modifyRepository( info.alias(), modifiedrepo );
+		// don't modify .repo in refresh.
+		// modifyRepository( info.alias(), modifiedrepo );
 		break;
 	      }
 	    }
+	    // Adjust the probed type in RepoInfo
+	    info.setProbedType( repokind ); // lazy init!
 	  }
+	  // no need to continue with an unknown type
+	  if ( repokind.toEnum() == RepoType::NONE_e )
+	    ZYPP_THROW(RepoUnknownTypeException( info ));
 	}
 
         Pathname mediarootpath = rawcache_path_for_repoinfo( _options, info );
@@ -1181,6 +1205,7 @@ namespace zypp
         }
         else if ( repokind.toEnum() == RepoType::RPMPLAINDIR_e )
         {
+	  // as substitute for real metadata remember the checksum of the directory we refreshed
           MediaMounter media( url );
           RepoStatus newstatus = RepoStatus( media.getPathName( info.path() ) );	// dir status
 
@@ -2243,7 +2268,7 @@ namespace zypp
 
 	// Make sure the service repo is created with the appropriate enablement
 	if ( ! indeterminate(toBeEnabled) )
-	  it->setEnabled( toBeEnabled );
+	  it->setEnabled( ( bool ) toBeEnabled );
 
         DBG << "Service adds repo " << it->alias() << " " << (it->enabled()?"enabled":"disabled") << endl;
         addRepository( *it );
