@@ -13,14 +13,14 @@
 #define ZYPP_SAT_REPOSITORY_H
 
 #include <iosfwd>
-#include "zypp/base/Iterator.h"
-#include "zypp/Pathname.h"
-#include "zypp/sat/detail/PoolMember.h"
-#include "zypp/sat/LookupAttr.h"     // LookupAttrTools.h included at EOF
-#include "zypp/sat/Solvable.h"
-#include "zypp/RepoInfo.h"
-#include "zypp/Date.h"
-#include "zypp/CpeId.h"
+#include <zypp/base/Iterator.h>
+#include <zypp/Pathname.h>
+#include <zypp/sat/detail/PoolMember.h>
+#include <zypp/sat/LookupAttr.h>     // LookupAttrTools.h included at EOF
+#include <zypp/sat/Solvable.h>
+#include <zypp/RepoInfo.h>
+#include <zypp/Date.h>
+#include <zypp/CpeId.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -293,6 +293,15 @@ namespace zypp
          */
         void addHelix( const Pathname & file_r );
 
+        /** Load \ref Solvables from a libsolv testtags-file.
+         * Supports loading of gzip compressed files (.gz). In case of an exception
+         * the repository remains in the \ref Pool.
+         * \throws Exception if this is \ref noRepository
+         * \throws Exception if loading the helix-file fails.
+         * \see \ref Pool::addRepoTesttags and \ref Repository::EraseFromPool
+         */
+        void addTesttags(const Pathname &file_r);
+
        /** Add \c count_r new empty \ref Solvable to this \ref Repository. */
         sat::Solvable::IdType addSolvables( unsigned count_r );
         /** \overload Add only one new \ref Solvable. */
@@ -316,7 +325,6 @@ namespace zypp
         int satInternalPriority() const;
         int satInternalSubPriority() const;
         //@}
-
     private:
         IdType _id;
     };
@@ -499,6 +507,6 @@ namespace zypp
 ///////////////////////////////////////////////////////////////////
 
 // Late include as sat::ArrayAttr requires Repository.h
-#include "zypp/sat/LookupAttrTools.h"
+#include <zypp/sat/LookupAttrTools.h>
 
 #endif // ZYPP_SAT_REPOSITORY_H
