@@ -13,15 +13,12 @@
 
 #define ZYPP_USE_RESOLVER_INTERNALS
 
-#include "zypp/Resolver.h"
-#include "zypp/ZConfig.h"
-#include "zypp/TriBool.h"
-#include "zypp/solver/detail/Resolver.h"
-#include "zypp/solver/detail/Testcase.h"
-#include "zypp/solver/detail/ItemCapKind.h"
-#include "zypp/sat/Transaction.h"
+#include <zypp/Resolver.h>
+#include <zypp/solver/detail/Resolver.h>
+#include <zypp/solver/detail/Testcase.h>
+#include <zypp/solver/detail/ItemCapKind.h>
+#include <zypp/sat/Transaction.h>
 
-using namespace std;
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -53,6 +50,9 @@ namespace zypp
   //	Resolver interface forwarded to implementation
   //
   ///////////////////////////////////////////////////////////////////
+  sat::detail::CSolver * Resolver::get() const
+  { return _pimpl->get(); }
+
   bool Resolver::verifySystem ()
   { return _pimpl->verifySystem(); }
 
@@ -80,6 +80,9 @@ namespace zypp
   void Resolver::doUpdate()
   { _pimpl->doUpdate(); }
 
+  void Resolver::setFocus( ResolverFocus focus_r )	{ _pimpl->setFocus( focus_r ); }
+  ResolverFocus Resolver::focus() const			{ return _pimpl->focus(); }
+
   void Resolver::setForceResolve( bool yesno_r )	{ _pimpl->setForceResolve( yesno_r ); }
   bool Resolver::forceResolve() const			{ return _pimpl->forceResolve(); }
 
