@@ -15,19 +15,10 @@
 #include <iosfwd>
 #include <functional>
 
-#include "zypp/base/ReferenceCounted.h"
-#include "zypp/base/PtrTypes.h"
+#include <zypp/base/ReferenceCounted.h>
 
-#include "zypp/ResPool.h"
-#include "zypp/PoolItem.h"
-#include "zypp/Capabilities.h"
-#include "zypp/Capability.h"
-
-#include "zypp/solver/detail/Types.h"
-
-#include "zypp/ProblemTypes.h"
-#include "zypp/ResolverProblem.h"
-#include "zypp/ProblemSolution.h"
+#include <zypp/solver/Types.h>
+#include <zypp/solver/detail/Types.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -172,6 +163,13 @@ namespace zypp
      */
     sat::Transaction getTransaction();
 
+    /**
+     * Define the resolvers general attitude when resolving jobs.
+     * \see \ref ResolverFocus
+     */
+    void setFocus( ResolverFocus focus_r );
+    ResolverFocus focus() const;
+
     /**
      * Remove resolvables which are conflicts with others or
      * have unfulfilled requirements.
@@ -439,6 +437,9 @@ namespace zypp
      */
     solver::detail::ItemCapKindList installedSatisfied( const PoolItem & item );
 
+  public:
+    /** Expert backdoor. */
+    sat::detail::CSolver * get() const;
 
   private:
     friend std::ostream & operator<<( std::ostream & str, const Resolver & obj );
