@@ -10,11 +10,11 @@
  * \file zypp/Url.cc
  */
 
-#include "zypp/Url.h"
-#include "zypp/Pathname.h"
-#include "zypp/base/Gettext.h"
-#include "zypp/base/String.h"
-#include "zypp/base/Regex.h"
+#include <zypp/Url.h>
+#include <zypp/Pathname.h>
+#include <zypp/base/Gettext.h>
+#include <zypp/base/String.h>
+#include <zypp/base/Regex.h>
 #include <stdexcept>
 #include <iostream>
 
@@ -181,6 +181,10 @@ namespace zypp
 
         // =====================================
         ref.reset( new UrlBase());
+        // don't show empty authority
+        ref->setViewOptions( zypp::url::ViewOption::DEFAULTS -
+                             zypp::url::ViewOption::EMPTY_AUTHORITY);
+
         ref->config("with_authority",   "n");   // disallow host,...
         ref->config("require_pathname", "m");   // path is mandatory
         addUrlByScheme("hd",     ref);
@@ -189,9 +193,6 @@ namespace zypp
         addUrlByScheme("dir",    ref);
         addUrlByScheme("iso",    ref);
 
-        // don't show empty authority
-        ref->setViewOptions( zypp::url::ViewOption::DEFAULTS -
-                             zypp::url::ViewOption::EMPTY_AUTHORITY);
         addUrlByScheme("mailto", ref);
         addUrlByScheme("urn",    ref);
         addUrlByScheme("plugin", ref);	// zypp plugable media handler:
@@ -876,6 +877,11 @@ namespace zypp
     return (lhs.asCompleteString() != rhs.asCompleteString());
   }
 
+  namespace hotfix1050625 {
+    std::string asString( const Url & url_r )
+    { return url_r.m_impl->asString1050625(); }
+  }
+
   ////////////////////////////////////////////////////////////////////
 } // namespace zypp
 //////////////////////////////////////////////////////////////////////
