@@ -12,14 +12,18 @@
 #ifndef   ZYPP_URL_H
 #define   ZYPP_URL_H
 
-#include "zypp/url/UrlBase.h"
-#include "zypp/url/UrlUtils.h"
+#include <zypp/url/UrlBase.h>
+#include <zypp/url/UrlUtils.h>
 
 
 //////////////////////////////////////////////////////////////////////
 namespace zypp
 { ////////////////////////////////////////////////////////////////////
 
+  class Url;
+  namespace hotfix1050625 {
+    std::string asString( const Url & url_r );
+  }
   namespace filesystem {
     class Pathname;
   }
@@ -687,6 +691,11 @@ namespace zypp
     setPathName(const char *path,
                 EEncoding         eflag = zypp::url::E_DECODED);
 
+    /**
+     * \brief Extend the path name.
+     */
+    void appendPathName( const Pathname & path_r, EEncoding eflag_r = zypp::url::E_DECODED );
+
     /**
      * \brief Set the path parameters.
      * \param params The new encoded path parameter string.
@@ -816,6 +825,7 @@ namespace zypp
     setViewOptions(const ViewOptions &vopts);
 
   private:
+    friend std::string hotfix1050625::asString( const Url & url_r );
     url::UrlRef m_impl;
   };
 
