@@ -21,21 +21,21 @@ extern "C"
 }
 #include <iostream>
 #include <fstream>
-#include "zypp/base/LogTools.h"
-#include "zypp/base/IOStream.h"
-#include "zypp/base/InputStream.h"
-#include "zypp/base/String.h"
-#include "zypp/base/Regex.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/IOStream.h>
+#include <zypp/base/InputStream.h>
+#include <zypp/base/String.h>
+#include <zypp/base/Regex.h>
 
-#include "zypp/ZConfig.h"
-#include "zypp/ZYppFactory.h"
-#include "zypp/PathInfo.h"
-#include "zypp/parser/IniDict.h"
+#include <zypp/ZConfig.h>
+#include <zypp/ZYppFactory.h>
+#include <zypp/PathInfo.h>
+#include <zypp/parser/IniDict.h>
 
-#include "zypp/sat/Pool.h"
-#include "zypp/sat/detail/PoolImpl.h"
+#include <zypp/sat/Pool.h>
+#include <zypp/sat/detail/PoolImpl.h>
 
-using namespace std;
+using std::endl;
 using namespace zypp::filesystem;
 using namespace zypp::parser;
 
@@ -326,6 +326,7 @@ namespace zypp
 	, gpgCheck			( true )
 	, repoGpgCheck			( indeterminate )
 	, pkgGpgCheck			( indeterminate )
+	, solver_focus			( ResolverFocus::Default )
         , solver_onlyRequires		( false )
         , solver_allowVendorChange	( false )
 	, solver_dupAllowDowngrade	( true )
@@ -338,7 +339,7 @@ namespace zypp
         , apply_locks_file		( true )
         , pluginsPath			( "/usr/lib/zypp/plugins" )
       {
-        MIL << "libzypp: " << VERSION << endl;
+        MIL << "libzypp: " LIBZYPP_VERSION_STRING << endl;
         // override_r has higest prio
         // ZYPP_CONF might override /etc/zypp/zypp.conf
         if ( _parsedZyppConf.empty() )
@@ -348,7 +349,9 @@ namespace zypp
         else
         {
           // Inject this into ZConfig. Be shure this is
-          // allocated via new. See: reconfigureZConfig
+          // allocated via new.
+          // ma: override_r might not be needed anymore since the
+          //     Vendor_test is now able to initialize VendorAttr directly.
           INT << "Reconfigure to " << _parsedZyppConf << endl;
           ZConfig::instance()._pimpl.reset( this );
         }
@@ -359,14 +362,14 @@ namespace zypp
                 sit != dict.sectionsEnd();
                 ++sit )
           {
-            string section(*sit);
+            std::string section(*sit);
             //MIL << section << endl;
             for ( IniDict::entry_const_iterator it = dict.entriesBegin(*sit);
                   it != dict.entriesEnd(*sit);
                   ++it )
             {
-              string entry(it->first);
-              string value(it->second);
+              std::string entry(it->first);
+              std::string value(it->second);
               //DBG << (*it).first << "=" << (*it).second << endl;
               if ( section == "main" )
               {
@@ -494,6 +497,14 @@ namespace zypp
                 {
                   cfg_multiversion_path = Pathname(value);
                 }
+                else if ( entry == "multiversion.kernels" )
+                {
+                  cfg_kernel_keep_spec = value;
+                }
+                else if ( entry == "solver.focus" )
+                {
+		  fromString( value, solver_focus );
+                }
                 else if ( entry == "solver.onlyRequires" )
                 {
                   solver_onlyRequires.set( str::strToBool( value, solver_onlyRequires ) );
@@ -632,6 +643,7 @@ namespace zypp
 
     Pathname cfg_vendor_path;
     Pathname cfg_multiversion_path;
+    std::string cfg_kernel_keep_spec;
     Pathname locks_file;
 
     Pathname update_data_path;
@@ -661,6 +673,7 @@ namespace zypp
     DefaultOption<TriBool>	repoGpgCheck;
     DefaultOption<TriBool>	pkgGpgCheck;
 
+    ResolverFocus	solver_focus;
     Option<bool>	solver_onlyRequires;
     Option<bool>	solver_allowVendorChange;
     Option<bool>	solver_dupAllowDowngrade;
@@ -706,7 +719,7 @@ namespace zypp
 	// _specMap[root] - scan root/zypp.conf and root/multiversion.d
 
 	if ( root_r.empty() )
-	  root_r == "/";
+	  root_r = "/";
 	bool cacheHit = _specMap.count( root_r );
 	MultiversionSpec & ret( _specMap[root_r] );	// creates new entry on the fly
 
@@ -778,14 +791,6 @@ namespace zypp
   };
   ///////////////////////////////////////////////////////////////////
 
-  // Backdoor to redirect ZConfig from within the running
-  // TEST-application. HANDLE WITH CARE!
-  void reconfigureZConfig( const Pathname & override_r )
-  {
-    // ctor puts itself unter smart pointer control.
-    new ZConfig::Impl( override_r );
-  }
-
   ///////////////////////////////////////////////////////////////////
   //
   //	METHOD NAME : ZConfig::instance
@@ -874,7 +879,7 @@ namespace zypp
     {
       WAR << "Overriding text locale (" << _pimpl->cfg_textLocale << "): " << locale_r << endl;
       _pimpl->cfg_textLocale = locale_r;
-#warning prefer signal
+      // Propagate changes
       sat::Pool::instance().setTextLocale( locale_r );
     }
   }
@@ -976,6 +981,12 @@ namespace zypp
         ? (configPath()/"services.d") : _pimpl->cfg_known_services_path );
   }
 
+  Pathname ZConfig::needrebootFile() const
+  { return configPath()/"needreboot"; }
+
+  Pathname ZConfig::needrebootPath() const
+  { return configPath()/"needreboot.d"; }
+
   Pathname ZConfig::varsPath() const
   {
     return ( _pimpl->cfg_vars_path.empty()
@@ -1061,6 +1072,7 @@ namespace zypp
   void ZConfig::resetRepoGpgCheck()			{ _pimpl->repoGpgCheck.restoreToDefault(); }
   void ZConfig::resetPkgGpgCheck()			{ _pimpl->pkgGpgCheck.restoreToDefault(); }
 
+  ResolverFocus ZConfig::solver_focus() const		{ return _pimpl->solver_focus; }
 
   bool ZConfig::solver_onlyRequires() const
   { return _pimpl->solver_onlyRequires; }
@@ -1169,11 +1181,16 @@ namespace zypp
   Pathname ZConfig::pluginsPath() const
   { return _pimpl->pluginsPath.get(); }
 
+  std::string ZConfig::multiversionKernels() const
+  {
+    return _pimpl->cfg_kernel_keep_spec;
+  }
+
   ///////////////////////////////////////////////////////////////////
 
   std::ostream & ZConfig::about( std::ostream & str ) const
   {
-    str << "libzypp: " << VERSION << endl;
+    str << "libzypp: " LIBZYPP_VERSION_STRING << endl;
 
     str << "libsolv: " << solv_version;
     if ( ::strcmp( solv_version, LIBSOLV_VERSION_STRING ) )
