@@ -16,18 +16,18 @@
 #include <set>
 #include <string>
 
-#include "zypp/APIConfig.h"
-#include "zypp/base/NonCopyable.h"
-#include "zypp/base/PtrTypes.h"
+#include <zypp/APIConfig.h>
+#include <zypp/base/NonCopyable.h>
+#include <zypp/base/PtrTypes.h>
 
-#include "zypp/Arch.h"
-#include "zypp/Locale.h"
-#include "zypp/Pathname.h"
-#include "zypp/IdString.h"
-#include "zypp/TriBool.h"
-
-#include "zypp/DownloadMode.h"
-#include "zypp/target/rpm/RpmFlags.h"
+#include <zypp/Arch.h>
+#include <zypp/Locale.h>
+#include <zypp/Pathname.h>
+#include <zypp/IdString.h>
+#include <zypp/TriBool.h>
+#include <zypp/ResolverFocus.h>
+#include <zypp/DownloadMode.h>
+#include <zypp/target/rpm/RpmFlags.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -39,7 +39,7 @@ namespace zypp
   //
   /** Interim helper class to collect global options and settings.
    * Use it to avoid hardcoded values and calls to getZYpp() just
-   * to retrieve some value like architecture, languages or tmppath.
+   * to retrieve some value like architecture, languages or temppath.
    *
    * It reads /etc/zypp/zypp.conf, the filename can be overridden by
    * setting the ZYPP_CONF environment variable to a different file.
@@ -74,7 +74,7 @@ namespace zypp
       Pathname systemRoot() const;
 
       /** The RepoManager root directory.
-       *  Returns the same as \sa systemRoot() if not explicitely set.
+       *  Returns the same as \ref systemRoot() if not explicitly set.
        */
       Pathname repoManagerRoot() const;
 
@@ -94,7 +94,7 @@ namespace zypp
       /** Override the zypp system architecture.
        * This is useful for test scenarious. <b>But be warned</b>, zypp does
        * not expect the system architecture to change at runtime. So
-       * set it at the verry beginning before you acess any other
+       * set it at the very beginning before you access any other
        * zypp component.
       */
       void setSystemArchitecture( const Arch & arch_r );
@@ -104,7 +104,7 @@ namespace zypp
       { setSystemArchitecture( defaultSystemArchitecture() ); }
 
     public:
-      /** The autodetected prefered locale for translated texts.
+      /** The autodetected preferred locale for translated texts.
        */
       static Locale defaultTextLocale();
 
@@ -112,7 +112,7 @@ namespace zypp
        */
       Locale textLocale() const;
 
-      /** Set the prefered locale for translated texts. */
+      /** Set the preferred locale for translated texts. */
       void setTextLocale( const Locale & locale_r );
 
       /** Reset the locale for translated texts to the default. */
@@ -206,6 +206,18 @@ namespace zypp
        */
       Pathname knownServicesPath() const;
 
+      /**
+       * Path of the default needreboot config file (configPath()/needreboot).
+       * \ingroup g_ZC_CONFIGFILES
+       */
+      Pathname needrebootFile() const;
+
+      /**
+       * Path where the custom needreboot config files are kept (configPath()/needreboot.d).
+       * \ingroup g_ZC_CONFIGFILES
+       */
+      Pathname needrebootPath() const;
+
       /**
        * Path containing custom repo variable definitions (configPath()/vars.d).
        * \see \ref zypp::repo::RepoVarExpand Repo variable expander
@@ -348,6 +360,11 @@ namespace zypp
        */
       Pathname vendorPath() const;
 
+      /**
+       * The resolvers general attitude when resolving jobs.
+       */
+      ResolverFocus solver_focus() const;
+
       /**
        * Solver regards required packages,patterns,... only
        */
@@ -517,6 +534,11 @@ namespace zypp
        */
       Pathname pluginsPath() const;
 
+      /*!
+       * Defaults to a empty string, if no keep spec is defined no kernels are removed
+       */
+      std::string multiversionKernels() const;
+
       //@}
     public:
       class Impl;
