@@ -17,16 +17,15 @@ extern "C"
 #include <fstream>
 #include <signal.h>
 
-#include "zypp/base/Logger.h"
-#include "zypp/base/Gettext.h"
-#include "zypp/base/IOStream.h"
-#include "zypp/base/Functional.h"
-#include "zypp/base/Backtrace.h"
-#include "zypp/PathInfo.h"
+#include <zypp/base/Logger.h>
+#include <zypp/base/Gettext.h>
+#include <zypp/base/IOStream.h>
+#include <zypp/base/Functional.h>
+#include <zypp/base/Backtrace.h>
+#include <zypp/PathInfo.h>
 
-#include "zypp/ZYppFactory.h"
-#include "zypp/zypp_detail/ZYppImpl.h"
-#include "zypp/zypp_detail/ZYppReadOnlyHack.h"
+#include <zypp/ZYppFactory.h>
+#include <zypp/zypp_detail/ZYppImpl.h>
 
 #include <boost/interprocess/sync/file_lock.hpp>
 #include <boost/interprocess/sync/scoped_lock.hpp>
@@ -70,7 +69,7 @@ namespace zypp
 
     static bool active = getenv("ZYPP_READONLY_HACK");
 
-    void IWantIt()
+    void IWantIt()	// see zypp/zypp_detail/ZYppReadOnlyHack.h
     {
       active = true;
       MIL << "ZYPP_READONLY promised." <<  endl;
@@ -94,7 +93,7 @@ namespace zypp
   {
   public:
     ZYppGlobalLock()
-    : _zyppLockFilePath( env::ZYPP_LOCKFILE_ROOT() / "/var/run/zypp.pid" )
+    : _zyppLockFilePath( env::ZYPP_LOCKFILE_ROOT() / "/run/zypp.pid" )
     , _zyppLockFile( NULL )
     , _lockerPid( 0 )
     , _cleanLock( false )
@@ -114,7 +113,7 @@ namespace zypp
 	    // still use it to synchronsize.
 	    ftruncate( fileno(_zyppLockFile), 0 );
 	  }
-	  MIL << "Cleanned lock file. (" << getpid() << ")" << std::endl;
+	  MIL << "Cleaned lock file. (" << getpid() << ")" << std::endl;
 	}
 	catch(...) {} // let no exception escape.
     }
@@ -190,7 +189,7 @@ namespace zypp
     bool isProcessRunning( pid_t pid_r )
     {
       // it is another program, not me, see if it is still running
-      Pathname procdir( "/proc"/str::numstring(pid_r) );
+      Pathname procdir( Pathname("/proc")/str::numstring(pid_r) );
       PathInfo status( procdir );
       MIL << "Checking " <<  status << endl;
 
@@ -371,7 +370,7 @@ namespace zypp
 	{
 	  MIL << "Waiting whether pid " << globalLock().lockerPid() << " ends within $LOCK_TIMEOUT=" << LOCK_TIMEOUT << " sec." << endl;
 	  unsigned delay = 1;
-	  Pathname procdir( "/proc"/str::numstring(globalLock().lockerPid()) );
+          Pathname procdir( Pathname("/proc")/str::numstring(globalLock().lockerPid()) );
 	  for ( long i = 0; i < LOCK_TIMEOUT; i += delay )
 	  {
 	    if ( PathInfo( procdir ).isDir() )	// wait for /proc/pid to disapear
@@ -384,7 +383,7 @@ namespace zypp
 	      {
 		// another proc locked faster. maybe it ends fast as well....
 		MIL << "Waiting whether pid " << globalLock().lockerPid() << " ends within " << (LOCK_TIMEOUT-i) << " sec." << endl;
-		procdir = Pathname( "/proc"/str::numstring(globalLock().lockerPid()) );
+                procdir = Pathname( Pathname("/proc")/str::numstring(globalLock().lockerPid()) );
 	      }
 	      else
 	      {
