@@ -13,7 +13,7 @@
 
 #include <unistd.h>
 
-#include "zypp/APIConfig.h"
+#include <zypp/APIConfig.h>
 
 namespace zypp
 {
