@@ -1,8 +1,7 @@
 #include <fcntl.h>
 #include <unistd.h>
-#include "zypp/base/Random.h"
+#include <zypp/base/Random.h>
 
-using namespace std;
 
 namespace zypp { namespace base {
 
