@@ -15,8 +15,8 @@
 #include <iosfwd>
 #include <string>
 
-#include "zypp/base/PtrTypes.h"
-#include "zypp/base/Exception.h"
+#include <zypp/base/PtrTypes.h>
+#include <zypp/base/Exception.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -303,7 +303,7 @@ namespace zypp
 
   public:
     /** Implementation  */
-    class Impl;
+    struct Impl;
 
   public:
     /** Default ctor matches nothing. */
