@@ -21,9 +21,9 @@
 #include <boost/format.hpp>
 #include <boost/utility/string_ref.hpp>
 
-#include "zypp/base/Easy.h"
-#include "zypp/base/PtrTypes.h"
-#include "zypp/base/Function.h"
+#include <zypp/base/Easy.h>
+#include <zypp/base/PtrTypes.h>
+#include <zypp/base/Function.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace boost { namespace logic { class tribool; } }
@@ -136,10 +136,8 @@ namespace zypp
     inline const std::string & asString( const std::string & t )
     { return t; }
 
-#ifndef SWIG // Swig treats it as syntax error
     inline std::string && asString( std::string && t )
     { return std::move(t); }
-#endif
 
     inline std::string asString( const char * t )
     { return t == nullptr ? std::string() : t; }
@@ -415,10 +413,10 @@ namespace zypp
     /** Parsing boolean from string.
     */
     //@{
-    /** Return \c true if str is <tt>1, true, yes, on</tt> (or a nonzero number). */
+    /** Return \c true if str is <tt>1, true, yes, on, always</tt> (or a nonzero number). */
     bool strToTrue( const C_Str & str );
 
-    /** Return \c false if str is <tt>0, false, no, off</tt>. */
+    /** Return \c false if str is <tt>0, false, no, off, never</tt>. */
     bool strToFalse( const C_Str & str );
 
     /** Parse \c str into a bool depending on the default value.
@@ -486,6 +484,33 @@ namespace zypp
       return inp_r;
     }
 
+    ///////////////////////////////////////////////////////////////////
+    /** \name Trimming whitepace.
+     * \todo optimize l/r trim.
+    */
+    //@{
+    /** To define how to trim. */
+    enum Trim {
+      NO_TRIM = 0x00,
+      L_TRIM  = 0x01,
+      R_TRIM  = 0x02,
+      TRIM    = (L_TRIM|R_TRIM)
+    };
+
+    std::string trim( const std::string & s, const Trim trim_r = TRIM );
+    std::string trim( std::string && s, const Trim trim_r = TRIM );
+
+    inline std::string ltrim( const std::string & s )
+    { return trim( s, L_TRIM ); }
+    inline std::string ltrim( std::string && s )
+    { return trim( std::move(s), L_TRIM ); }
+
+    inline std::string rtrim( const std::string & s )
+    { return trim( s, R_TRIM ); }
+    inline std::string rtrim( std::string && s )
+    { return trim( std::move(s), R_TRIM ); }
+    //@}
+
     ///////////////////////////////////////////////////////////////////
     /** \name Split. */
     //@{
@@ -499,7 +524,7 @@ namespace zypp
      *
     */
     template<class TOutputIterator>
-      unsigned split( const C_Str & line_r, TOutputIterator result_r, const C_Str & sepchars_r = " \t" )
+      unsigned split( const C_Str & line_r, TOutputIterator result_r, const C_Str & sepchars_r = " \t", const Trim trim_r = NO_TRIM )
       {
         const char * beg = line_r;
         const char * cur = beg;
@@ -513,7 +538,7 @@ namespace zypp
             while( *cur && !::strchr( sepchars_r, *cur ) )
               ++cur;
             // build string
-            *result_r = std::string( beg, cur-beg );
+            *result_r = trim( std::string( beg, cur-beg ), trim_r );
             // skip sepchars
             while ( *cur && ::strchr( sepchars_r, *cur ) )
               ++cur;
@@ -521,6 +546,11 @@ namespace zypp
         return ret;
       }
 
+    template<class TOutputIterator>
+      unsigned split( const C_Str & line_r, TOutputIterator result_r, const Trim trim_r )
+      { return split( line_r, result_r, " \t", trim_r ); }
+
+
     /** Split \a line_r into words with respect to escape delimeters.
      * Any sequence of characters in \a sepchars_r is treated as
      * delimiter if not inside \c "" or \c '' or escaped by \c \.
@@ -895,6 +925,15 @@ namespace zypp
           str_r += escape( next_r, sep_r );
       }
 
+      /** Return \a str_r with '\'-escaped chars occurring in \a special_r (and '\'). */
+      std::string bEscape( std::string str_r, const C_Str & special_r );
+
+      /** Escape plain STRING \a str_r for use in a regex (not anchored by "^" or "$"). */
+      std::string rxEscapeStr( std::string str_r );
+
+      /** Escape GLOB \a str_r for use in a regex (not anchored by "^" or "$"). */
+      std::string rxEscapeGlob( std::string str_r );
+
       //! \todo unsecape()
 
     //@}
@@ -952,33 +991,6 @@ namespace zypp
     { return ::strcasestr( str_r, val_r ); }
     //@}
 
-    ///////////////////////////////////////////////////////////////////
-    /** \name Trimming whitepace.
-     * \todo optimize l/r trim.
-    */
-    //@{
-    /** To define how to trim. */
-    enum Trim {
-      NO_TRIM = 0x00,
-      L_TRIM  = 0x01,
-      R_TRIM  = 0x02,
-      TRIM    = (L_TRIM|R_TRIM)
-    };
-
-    std::string trim( const std::string & s, const Trim trim_r = TRIM );
-    std::string trim( std::string && s, const Trim trim_r = TRIM );
-
-    inline std::string ltrim( const std::string & s )
-    { return trim( s, L_TRIM ); }
-    inline std::string ltrim( std::string && s )
-    { return trim( std::move(s), L_TRIM ); }
-
-    inline std::string rtrim( const std::string & s )
-    { return trim( s, R_TRIM ); }
-    inline std::string rtrim( std::string && s )
-    { return trim( std::move(s), R_TRIM ); }
-    //@}
-
     std::string stripFirstWord( std::string & line, const bool ltrim_first = true );
 
     std::string stripLastWord( std::string & line, const bool rtrim_first = true );
