@@ -18,25 +18,19 @@ extern "C"
 #endif
 }
 
-#ifndef HAVE_UDEV
-#if HAVE_HAL
-#include "zypp/target/hal/HalContext.h"
-#endif
-#endif
-
 #include <cstring> // strerror
 #include <cstdlib> // getenv
 #include <iostream>
 
-#include "zypp/base/Logger.h"
-#include "zypp/ExternalProgram.h"
-#include "zypp/media/Mount.h"
-#include "zypp/media/MediaCD.h"
-#include "zypp/media/MediaManager.h"
-#include "zypp/Url.h"
-#include "zypp/AutoDispose.h"
-
+#include <zypp/base/Logger.h>
+#include <zypp/ExternalProgram.h>
+#include <zypp/media/Mount.h>
+#include <zypp/media/MediaCD.h>
+#include <zypp/media/MediaManager.h>
+#include <zypp/Url.h>
+#include <zypp/AutoDispose.h>
 
+using std::endl;
 
 /*
 ** if to throw exception on eject errors or ignore them
@@ -50,7 +44,6 @@ extern "C"
 #define EJECT_TOOL_PATH "/bin/eject"
 
 
-using namespace std;
 
 //////////////////////////////////////////////////////////////////
 namespace zypp
@@ -65,13 +58,9 @@ namespace zypp
       typedef std::list<MediaSource> DeviceList;
 
       //////////////////////////////////////////////////////////////////
-      /// \brief Try to detect cd/dvd devices using hal/udev
+      /// \brief Try to detect cd/dvd devices using udev
       ///
       /// Returns an empty device list on error.
-      ///
-      /// \todo I took the code more or less as it was from MediaCD::detectDevices
-      /// into this function. Semantic between HAL and UDEV seems to be slightly
-      /// different, esp. in supportingDVD mode. This should be investigated and fixed.
       //////////////////////////////////////////////////////////////////
       DeviceList systemDetectDevices( bool supportingDVD_r )
       {
@@ -136,62 +125,6 @@ namespace zypp
 	{
 	  WAR << "Did not find any CD/DVD device." << endl;
 	}
-#elif HAVE_HAL
-	using namespace zypp::target::hal;
-	try
-	{
-	  HalContext hal(true);
-
-	  std::vector<std::string> drv_udis;
-	  drv_udis = hal.findDevicesByCapability("storage.cdrom");
-
-	  DBG << "Found " << drv_udis.size() << " cdrom drive udis" << std::endl;
-	  for(size_t d = 0; d < drv_udis.size(); d++)
-	  {
-	    HalDrive drv( hal.getDriveFromUDI( drv_udis[d]));
-
-	    if( drv)
-	    {
-	      bool supportsDVD=false;
-	      if( supportingDVD_r)
-	      {
-		std::vector<std::string> caps;
-		try {
-		  caps = drv.getCdromCapabilityNames();
-		}
-		catch(const HalException &e)
-		{
-		  ZYPP_CAUGHT(e);
-		}
-
-		std::vector<std::string>::const_iterator ci;
-		for( ci=caps.begin(); ci != caps.end(); ++ci)
-		{
-		  if( *ci == "dvd")
-		    supportsDVD = true;
-		}
-	      }
-
-	      MediaSource media("cdrom", drv.getDeviceFile(),
-		      drv.getDeviceMajor(),
-		      drv.getDeviceMinor());
-		  DBG << "Found " << drv_udis[d] << ": "
-		  << media.asString() << std::endl;
-		  if( supportingDVD_r && supportsDVD)
-		  {
-		    detected.push_front(media);
-		  }
-		  else
-		  {
-		    detected.push_back(media);
-		  }
-	    }
-	  }
-	}
-	catch(const zypp::target::hal::HalException &e)
-	{
-	  ZYPP_CAUGHT(e);
-	}
 #endif
 	return detected;
       }
@@ -213,7 +146,7 @@ namespace zypp
       ZYPP_THROW(MediaUnsupportedUrlSchemeException(_url));
     }
 
-    string devices = _url.getQueryParam( "devices" );
+    std::string devices = _url.getQueryParam( "devices" );
     if ( ! devices.empty() )
     {
       std::vector<std::string> words;
@@ -330,7 +263,7 @@ namespace zypp
 
     if ( detected.empty() )
     {
-      WAR << "CD/DVD drive detection with HAL/UDEV failed! Guessing..." << std::endl;
+      WAR << "CD/DVD drive detection with UDEV failed! Guessing..." << std::endl;
       PathInfo dvdinfo( "/dev/dvd" );
       PathInfo cdrinfo( "/dev/cdrom" );
       if ( dvdinfo.isBlk() )
@@ -355,7 +288,7 @@ namespace zypp
     {
       DBG << "creating on-demand device list" << endl;
       //default is /dev/cdrom; for dvd: /dev/dvd if it exists
-      string device( "/dev/cdrom" );
+      std::string device( "/dev/cdrom" );
       if ( _url.getScheme() == "dvd" && PathInfo( "/dev/dvd" ).isBlk() )
       {
         device = "/dev/dvd";
@@ -412,14 +345,14 @@ namespace zypp
     Mount mount;
     MediaMountException merr;
 
-    string options = _url.getQueryParam( "mountoptions" );
+    std::string options = _url.getQueryParam( "mountoptions" );
     if ( options.empty() )
     {
       options="ro";
     }
 
     //TODO: make configurable
-    list<string> filesystems;
+    std::list<std::string> filesystems;
 
     filesystems.push_back("iso9660");
 
@@ -520,7 +453,7 @@ namespace zypp
       closeTray( it->name );
 
       // try all filesystems in sequence
-      for(list<string>::iterator fsit = filesystems.begin()
+      for(std::list<std::string>::iterator fsit = filesystems.begin()
           ; !mountsucceeded && fsit != filesystems.end()
           ; ++fsit)
       {
