@@ -17,15 +17,15 @@
 #include <string>
 #include <list>
 
-#include "zypp/Pathname.h"
-#include "zypp/PathInfo.h"
-#include "zypp/base/PtrTypes.h"
+#include <zypp/Pathname.h>
+#include <zypp/PathInfo.h>
+#include <zypp/base/PtrTypes.h>
 
-#include "zypp/Url.h"
+#include <zypp/Url.h>
 
-#include "zypp/media/MediaSource.h"
-#include "zypp/media/MediaException.h"
-#include "zypp/APIConfig.h"
+#include <zypp/media/MediaSource.h>
+#include <zypp/media/MediaException.h>
+#include <zypp/APIConfig.h>
 
 namespace zypp {
   namespace media {
