@@ -12,8 +12,8 @@
 #ifndef ZYPP_MEDIA_MEDIAISO_H
 #define ZYPP_MEDIA_MEDIAISO_H
 
-#include "zypp/media/MediaHandler.h"
-#include "zypp/media/MediaManager.h"
+#include <zypp/media/MediaHandler.h>
+#include <zypp/media/MediaManager.h>
 
 //////////////////////////////////////////////////////////////////////
 namespace zypp
@@ -36,20 +36,19 @@ namespace zypp
     {
       private:
         Pathname      _isofile;
-        MediaAccessId _isosource;
         std::string   _filesystem;
 
       protected:
 
-	virtual void attachTo (bool next = false);
-        virtual void releaseFrom( const std::string & ejectDev = "" );
-	virtual void getFile( const Pathname & filename, const ByteCount &expectedFileSize_r ) const;
-	virtual void getDir( const Pathname & dirname, bool recurse_r ) const;
+	virtual void attachTo (bool next = false) override;
+        virtual void releaseFrom( const std::string & ejectDev = "" ) override;
+	virtual void getFile( const Pathname & filename, const ByteCount &expectedFileSize_r ) const override;
+	virtual void getDir( const Pathname & dirname, bool recurse_r ) const override;
         virtual void getDirInfo( std::list<std::string> & retlist,
-                                 const Pathname & dirname, bool dots = true ) const;
+                                 const Pathname & dirname, bool dots = true ) const override;
         virtual void getDirInfo( filesystem::DirContent & retlist,
-                                 const Pathname & dirname, bool dots = true ) const;
-        virtual bool getDoesFileExist( const Pathname & filename ) const;
+                                 const Pathname & dirname, bool dots = true ) const override;
+        virtual bool getDoesFileExist( const Pathname & filename ) const override;
 
       public:
 
@@ -57,10 +56,10 @@ namespace zypp
                  const Pathname &attach_point_hint_r);
 
         virtual
-        ~MediaISO();
+        ~MediaISO() override;
 
         virtual bool
-        isAttached() const;
+        isAttached() const override;
     };
 
 
