@@ -22,12 +22,14 @@
 #include <algorithm>
 
 
-#include "zypp/ZConfig.h"
-#include "zypp/base/Logger.h"
-#include "zypp/media/MediaMultiCurl.h"
-#include "zypp/media/MetaLinkParser.h"
+#include <zypp/ZConfig.h>
+#include <zypp/base/Logger.h>
+#include <zypp/media/MediaMultiCurl.h>
+#include <zypp/media/MetaLinkParser.h>
+#include <zypp/ManagedFile.h>
+#include <zypp/media/CurlHelper.h>
 
-using namespace std;
+using std::endl;
 using namespace zypp::base;
 
 #undef CURLVERSION_AT_LEAST
@@ -91,7 +93,7 @@ private:
 
   multifetchrequest *_request;
   int _pass;
-  string _urlbuf;
+  std::string _urlbuf;
   off_t _off;
   size_t _size;
   Digest _dig;
@@ -250,7 +252,7 @@ multifetchworker::headerfunction(char *p, size_t size)
   size_t l = size;
   if (l > 9 && !strncasecmp(p, "Location:", 9))
     {
-      string line(p + 9, l - 9);
+      std::string line(p + 9, l - 9);
       if (line[l - 10] == '\r')
 	line.erase(l - 10, 1);
       XXX << "#" << _workerno << ": redirecting to" << line << endl;
@@ -359,7 +361,7 @@ multifetchworker::multifetchworker(int no, multifetchrequest &request, const Url
       if ( _settings.userPassword().size() )
 	{
 	  curl_easy_setopt(_curl, CURLOPT_USERPWD, _settings.userPassword().c_str());
-	  string use_auth = _settings.authType();
+	  std::string use_auth = _settings.authType();
 	  if (use_auth.empty())
 	    use_auth = "digest,basic";        // our default
 	  long auth = CurlAuthData::auth_type_str2long(use_auth);
@@ -415,7 +417,7 @@ multifetchworker::~multifetchworker()
   disconnectFrom();
 }
 
-static inline bool env_isset(string name)
+static inline bool env_isset(std::string name)
 {
   const char *s = getenv(name.c_str());
   return s && *s ? true : false;
@@ -424,7 +426,7 @@ static inline bool env_isset(string name)
 void
 multifetchworker::checkdns()
 {
-  string host = _url.getHost();
+  std::string host = _url.getHost();
 
   if (host.empty())
     return;
@@ -444,7 +446,7 @@ multifetchworker::checkdns()
     return;
   if (env_isset("all_proxy") || env_isset("ALL_PROXY"))
     return;
-  string schemeproxy = _url.getScheme() + "_proxy";
+  std::string schemeproxy = _url.getScheme() + "_proxy";
   if (env_isset(schemeproxy))
     return;
   if (schemeproxy != "http_proxy")
@@ -1267,7 +1269,7 @@ int MediaMultiCurl::progressCallback( void *clientp, double dltotal, double dlno
   bool ismetalink = false;
   if (curl_easy_getinfo(_curl, CURLINFO_CONTENT_TYPE, &ptr) == CURLE_OK && ptr) 
     {    
-      string ct = string(ptr);
+      std::string ct = std::string(ptr);
       if (ct.find("application/metalink+xml") == 0 || ct.find("application/metalink4+xml") == 0)
         ismetalink = true;
     }    
@@ -1300,35 +1302,36 @@ void MediaMultiCurl::doGetFileCopy( const Pathname & filename , const Pathname &
   if( assert_dir( dest.dirname() ) )
   {
     DBG << "assert_dir " << dest.dirname() << " failed" << endl;
-    Url url(getFileUrl(filename));
-    ZYPP_THROW( MediaSystemException(url, "System error on " + dest.dirname().asString()) );
-  }
-  string destNew = target.asString() + ".new.zypp.XXXXXX";
-  char *buf = ::strdup( destNew.c_str());
-  if( !buf)
-  {
-    ERR << "out of memory for temp file name" << endl;
-    Url url(getFileUrl(filename));
-    ZYPP_THROW(MediaSystemException(url, "out of memory for temp file name"));
+    ZYPP_THROW( MediaSystemException(getFileUrl(filename), "System error on " + dest.dirname().asString()) );
   }
 
-  int tmp_fd = ::mkostemp( buf, O_CLOEXEC );
-  if( tmp_fd == -1)
+  ManagedFile destNew { target.extend( ".new.zypp.XXXXXX" ) };
+  AutoFILE file;
   {
-    free( buf);
-    ERR << "mkstemp failed for file '" << destNew << "'" << endl;
-    ZYPP_THROW(MediaWriteException(destNew));
-  }
-  destNew = buf;
-  free( buf);
+    AutoFREE<char> buf { ::strdup( (*destNew).c_str() ) };
+    if( ! buf )
+    {
+      ERR << "out of memory for temp file name" << endl;
+      ZYPP_THROW(MediaSystemException(getFileUrl(filename), "out of memory for temp file name"));
+    }
 
-  FILE *file = ::fdopen( tmp_fd, "we" );
-  if ( !file ) {
-    ::close( tmp_fd);
-    filesystem::unlink( destNew );
-    ERR << "fopen failed for file '" << destNew << "'" << endl;
-    ZYPP_THROW(MediaWriteException(destNew));
+    AutoFD tmp_fd { ::mkostemp( buf, O_CLOEXEC ) };
+    if( tmp_fd == -1 )
+    {
+      ERR << "mkstemp failed for file '" << destNew << "'" << endl;
+      ZYPP_THROW(MediaWriteException(destNew));
+    }
+    destNew = ManagedFile( (*buf), filesystem::unlink );
+
+    file = ::fdopen( tmp_fd, "we" );
+    if ( ! file )
+    {
+      ERR << "fopen failed for file '" << destNew << "'" << endl;
+      ZYPP_THROW(MediaWriteException(destNew));
+    }
+    tmp_fd.resetDispose();	// don't close it here! ::fdopen moved ownership to file
   }
+
   DBG << "dest: " << dest << endl;
   DBG << "temp: " << destNew << endl;
 
@@ -1347,15 +1350,13 @@ void MediaMultiCurl::doGetFileCopy( const Pathname & filename , const Pathname &
   curl_easy_setopt(_curl, CURLOPT_HTTPHEADER, _customHeadersMetalink);
   // change to our own progress funcion
   curl_easy_setopt(_curl, CURLOPT_PROGRESSFUNCTION, &progressCallback);
-  curl_easy_setopt(_curl, CURLOPT_PRIVATE, file);
+  curl_easy_setopt(_curl, CURLOPT_PRIVATE, (*file) );	// important to pass the FILE* explicitly (passing through varargs)
   try
     {
       MediaCurl::doGetFileCopyFile(filename, dest, file, report, expectedFileSize_r, options);
     }
   catch (Exception &ex)
     {
-      ::fclose(file);
-      filesystem::unlink(destNew);
       curl_easy_setopt(_curl, CURLOPT_TIMECONDITION, CURL_TIMECOND_NONE);
       curl_easy_setopt(_curl, CURLOPT_TIMEVALUE, 0L);
       curl_easy_setopt(_curl, CURLOPT_HTTPHEADER, _customHeaders);
@@ -1388,7 +1389,7 @@ void MediaMultiCurl::doGetFileCopy( const Pathname & filename , const Pathname &
   char *ptr = NULL;
   if (curl_easy_getinfo(_curl, CURLINFO_CONTENT_TYPE, &ptr) == CURLE_OK && ptr)
     {
-      string ct = string(ptr);
+      std::string ct = std::string(ptr);
       if (ct.find("application/metalink+xml") == 0 || ct.find("application/metalink4+xml") == 0)
 	ismetalink = true;
     }
@@ -1398,24 +1399,33 @@ void MediaMultiCurl::doGetFileCopy( const Pathname & filename , const Pathname &
       // some proxies do not store the content type, so also look at the file to find
       // out if we received a metalink (bnc#649925)
       fflush(file);
-      if (looks_like_metalink(Pathname(destNew)))
+      if (looks_like_metalink(destNew))
 	ismetalink = true;
     }
 
   if (ismetalink)
     {
       bool userabort = false;
-      fclose(file);
-      file = NULL;
       Pathname failedFile = ZConfig::instance().repoCachePath() / "MultiCurl.failed";
+      file = nullptr;	// explicitly close destNew before the parser reads it.
       try
 	{
 	  MetaLinkParser mlp;
-	  mlp.parse(Pathname(destNew));
+	  mlp.parse(destNew);
 	  MediaBlockList bl = mlp.getBlockList();
-	  vector<Url> urls = mlp.getUrls();
+
+          /*
+           * gihub issue libzipp:#277 Multicurl backend breaks with MirrorCache and Metalink with unknown filesize.
+           * Fall back to a normal download if we have no knowledge about the filesize we want to download.
+           */
+          if ( !bl.haveFilesize() && expectedFileSize_r == 0 ) {
+            XXX << "No filesize in metalink file and no expected filesize, aborting multicurl." << std::endl;
+            ZYPP_THROW( MediaException("Multicurl requires filesize but none was provided.") );
+          }
+
+	  std::vector<Url> urls = mlp.getUrls();
 	  XXX << bl << endl;
-	  file = fopen(destNew.c_str(), "w+e");
+	  file = fopen((*destNew).c_str(), "w+e");
 	  if (!file)
 	    ZYPP_THROW(MediaWriteException(destNew));
 	  if (PathInfo(target).isExist())
@@ -1454,9 +1464,7 @@ void MediaMultiCurl::doGetFileCopy( const Pathname & filename , const Pathname &
       catch (Exception &ex)
 	{
 	  // something went wrong. fall back to normal download
-	  if (file)
-	    fclose(file);
-	  file = NULL;
+	  file = nullptr;	// explicitly close destNew before moving it
 	  if (PathInfo(destNew).size() >= 63336)
 	    {
 	      ::unlink(failedFile.asString().c_str());
@@ -1464,10 +1472,9 @@ void MediaMultiCurl::doGetFileCopy( const Pathname & filename , const Pathname &
 	    }
 	  if (userabort)
 	    {
-	      filesystem::unlink(destNew);
 	      ZYPP_RETHROW(ex);
 	    }
-	  file = fopen(destNew.c_str(), "w+e");
+	  file = fopen((*destNew).c_str(), "w+e");
 	  if (!file)
 	    ZYPP_THROW(MediaWriteException(destNew));
 	  MediaCurl::doGetFileCopyFile(filename, dest, file, report, expectedFileSize_r, options | OPTION_NO_REPORT_START);
@@ -1478,36 +1485,25 @@ void MediaMultiCurl::doGetFileCopy( const Pathname & filename , const Pathname &
     {
       ERR << "Failed to chmod file " << destNew << endl;
     }
+
+  file.resetDispose();	// we're going to close it manually here
   if (::fclose(file))
     {
       filesystem::unlink(destNew);
       ERR << "Fclose failed for file '" << destNew << "'" << endl;
       ZYPP_THROW(MediaWriteException(destNew));
     }
+
   if ( rename( destNew, dest ) != 0 )
     {
       ERR << "Rename failed" << endl;
       ZYPP_THROW(MediaWriteException(dest));
     }
+  destNew.resetDispose();	// no more need to unlink it
+
   DBG << "done: " << PathInfo(dest) << endl;
 }
 
-///////////////////////////////////////////////////////////////////
-namespace {
-  // bsc#933839: propagate proxy settings passed in the repo URL
-  inline Url propagateQueryParams( Url url_r, const Url & template_r )
-  {
-    for ( std::string param : { "proxy", "proxyport", "proxyuser", "proxypass"} )
-    {
-      const std::string & value( template_r.getQueryParam( param ) );
-      if ( ! value.empty() )
-	url_r.setQueryParam( param, value );
-    }
-    return url_r;
-  }
-}
-///////////////////////////////////////////////////////////////////
-
 void MediaMultiCurl::multifetch(const Pathname & filename, FILE *fp, std::vector<Url> *urllist, callback::SendReport<DownloadProgressReport> *report, MediaBlockList *blklist, off_t filesize) const
 {
   Url baseurl(getFileUrl(filename));
@@ -1543,11 +1539,11 @@ void MediaMultiCurl::multifetch(const Pathname & filename, FILE *fp, std::vector
     {
       try
 	{
-	  string scheme = urliter->getScheme();
+	  std::string scheme = urliter->getScheme();
 	  if (scheme == "http" || scheme == "https" || scheme == "ftp" || scheme == "tftp")
 	    {
 	      checkProtocol(*urliter);
-	      myurllist.push_back(propagateQueryParams(*urliter, _url));
+              myurllist.push_back(internal::propagateQueryParams(*urliter, _url));
 	    }
 	}
       catch (...)
@@ -1576,17 +1572,17 @@ void MediaMultiCurl::checkFileDigest(Url &url, FILE *fp, MediaBlockList *blklist
     ZYPP_THROW(MediaCurlException(url, "file verification failed", "checksum error"));
 }
 
-bool MediaMultiCurl::isDNSok(const string &host) const
+bool MediaMultiCurl::isDNSok(const std::string &host) const
 {
   return _dnsok.find(host) == _dnsok.end() ? false : true;
 }
 
-void MediaMultiCurl::setDNSok(const string &host) const
+void MediaMultiCurl::setDNSok(const std::string &host) const
 {
   _dnsok.insert(host);
 }
 
-CURL *MediaMultiCurl::fromEasyPool(const string &host) const
+CURL *MediaMultiCurl::fromEasyPool(const std::string &host) const
 {
   if (_easypool.find(host) == _easypool.end())
     return 0;
