@@ -11,22 +11,21 @@
  */
 #include <iostream>
 
-#include "zypp/base/String.h"
-#include "zypp/base/Logger.h"
+#include <zypp/base/String.h>
+#include <zypp/base/Logger.h>
 
-#include "zypp/Pathname.h"
-#include "zypp/Date.h"
-#include "zypp/CheckSum.h"
-#include "zypp/parser/xml/Reader.h"
+#include <zypp/Pathname.h>
+#include <zypp/Date.h>
+#include <zypp/CheckSum.h>
+#include <zypp/parser/xml/Reader.h>
 
-#include "zypp/parser/yum/RepomdFileReader.h"
+#include <zypp/parser/yum/RepomdFileReader.h>
 
 #undef ZYPP_BASE_LOGGER_LOGGROUP
 #define ZYPP_BASE_LOGGER_LOGGROUP "parser::yum"
 
-using namespace std;
+using std::endl;
 using namespace zypp::xml;
-using zypp::repo::yum::ResourceType;
 
 namespace zypp
 {
@@ -43,57 +42,37 @@ namespace zypp
   class RepomdFileReader::Impl : private base::NonCopyable
   {
   public:
-
-    /**
-     * Enumeration of repomd.xml tags.
-     * \see _tag
-     */
-    enum Tag
-    {
-      tag_NONE,
-      tag_Repomd,
-      tag_Data,
-      tag_Location,
-      tag_CheckSum,
-      tag_Timestamp,
-      tag_OpenCheckSum
-    };
-
-  public:
-    /** Ctro taking a ProcessResource2 callback */
-    Impl(const Pathname &repomd_file, const ProcessResource2 & callback )
+    /** Ctro taking a ProcessResource callback */
+    Impl(const Pathname &repomd_file, const ProcessResource & callback )
     : _callback( callback )
-    , _tag( tag_NONE )
-    , _type( ResourceType::NONE_e )
     {
       Reader reader( repomd_file );
       MIL << "Reading " << repomd_file << endl;
       reader.foreachNode( bind( &RepomdFileReader::Impl::consumeNode, this, _1 ) );
     }
-   /** \overload Redirect an old ProcessResource callback */
-    Impl(const Pathname &repomd_file, const ProcessResource & callback)
-    : Impl( repomd_file, ProcessResource2( bind( callback, _1, _2 ) ) )
-    {}
 
     /**
      * Callback provided to the XML parser.
      */
     bool consumeNode( Reader & reader_r );
 
+  private:
+    /** Retrieve a checksum node. */
+    CheckSum getChecksum( Reader & reader_r )
+    { return CheckSum( reader_r->getAttribute("type").asString(), reader_r.nodeText().asString() ); }
+
+    /** Retrieve a size node. */
+    ByteCount getSize( Reader & reader_r )
+    { return ByteCount( str::strtonum<ByteCount::SizeType>( reader_r.nodeText().asString() ) ); }
+
 
   private:
     /** Function for processing collected data. Passed-in through constructor. */
-    ProcessResource2 _callback;
+    ProcessResource _callback;
 
-    /** Used to remember currently processed tag */
-    Tag _tag;
-
-    /** Type of metadata file (string) */
+    /** The resource type string. */
     std::string _typeStr;
 
-    /** Type of metadata file as enum of well known repoinded.xml entries. */
-    repo::yum::ResourceType _type;
-
     /** Location of metadata file. */
     OnMediaLocation _location;
   };
@@ -117,23 +96,19 @@ namespace zypp
       // xpath: /repomd
       if ( reader_r->name() == "repomd" )
       {
-        _tag = tag_Repomd;
         return true;
       }
 
       // xpath: /repomd/data (+)
       if ( reader_r->name() == "data" )
       {
-        _tag = tag_Data;
 	_typeStr = reader_r->getAttribute("type").asString();
-        _type = ResourceType(_typeStr);
         return true;
       }
 
       // xpath: /repomd/location
       if ( reader_r->name() == "location" )
       {
-        _tag = tag_Location;
         _location.setLocation( reader_r->getAttribute("href").asString(), 1 );
         // ignoring attribute xml:base
         return true;
@@ -142,10 +117,14 @@ namespace zypp
       // xpath: /repomd/checksum
       if ( reader_r->name() == "checksum" )
       {
-        _tag = tag_CheckSum;
-        string checksum_type = reader_r->getAttribute("type").asString() ;
-        string checksum_vaue = reader_r.nodeText().asString();
-        _location.setChecksum( CheckSum( checksum_type, checksum_vaue ) );
+	_location.setChecksum( getChecksum( reader_r ) );
+        return true;
+      }
+
+      // xpath: /repomd/header-checksum
+      if ( reader_r->name() == "header-checksum" )
+      {
+	_location.setHeaderChecksum( getChecksum( reader_r ) );
         return true;
       }
 
@@ -159,9 +138,14 @@ namespace zypp
       // xpath: /repomd/size
       if ( reader_r->name() == "size" )
       {
-        string size_value = reader_r.nodeText().asString();
-        zypp::ByteCount size = zypp::ByteCount( str::strtonum<ByteCount::SizeType>( size_value ) );
-        _location.setDownloadSize( size );
+	_location.setDownloadSize( getSize( reader_r ) );
+        return true;
+      }
+
+      // xpath: /repomd/header-size
+      if ( reader_r->name() == "header-size" )
+      {
+	_location.setHeaderSize( getSize( reader_r ) );
         return true;
       }
 
@@ -173,9 +157,11 @@ namespace zypp
       // xpath: /repomd/data
       if ( reader_r->name() == "data" )
       {
-        if (_callback)
-          _callback( _location, _type, _typeStr );
-
+        if (_callback) {
+          _callback( std::move(_location), _typeStr );
+	  _location = OnMediaLocation();
+	  _typeStr.clear();
+	}
         return true;
       }
     }
@@ -194,10 +180,6 @@ namespace zypp
   : _pimpl( new Impl(repomd_file, callback) )
   {}
 
-  RepomdFileReader::RepomdFileReader( const Pathname & repomd_file, const ProcessResource2 & callback )
-  : _pimpl( new Impl(repomd_file, callback) )
-  {}
-
   RepomdFileReader::~RepomdFileReader()
   {}
 
