@@ -8,15 +8,15 @@
 \---------------------------------------------------------------------*/
 
 #include <fstream>
-#include "zypp/base/String.h"
-#include "zypp/base/Logger.h"
-#include "zypp/base/Gettext.h"
+#include <zypp/base/String.h>
+#include <zypp/base/Logger.h>
+#include <zypp/base/Gettext.h>
 
 #include "Downloader.h"
-#include "zypp/KeyContext.h"
-#include "zypp/ZYppCallbacks.h"
+#include <zypp/KeyContext.h>
+#include <zypp/ZYppCallbacks.h>
 
-using namespace std;
+using std::endl;
 
 namespace zypp
 {
