@@ -8,14 +8,13 @@
 \---------------------------------------------------------------------*/
 
 #include <fstream>
-#include "zypp/base/String.h"
-#include "zypp/base/Logger.h"
-#include "zypp/base/Function.h"
+#include <zypp/base/String.h>
+#include <zypp/base/Logger.h>
+#include <zypp/base/Function.h>
 
 #include "MediaInfoDownloader.h"
-#include "zypp/base/UserRequestException.h"
+#include <zypp/base/UserRequestException.h>
 
-using namespace std;
 
 namespace zypp
 {
