@@ -9,16 +9,16 @@
 #include <iostream>
 #include <fstream>
 
-#include "zypp/base/LogTools.h"
-#include "zypp/base/String.h"
-#include "zypp/base/Regex.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/String.h>
+#include <zypp/base/Regex.h>
 
-#include "zypp/ZYppFactory.h"
-#include "zypp/ZConfig.h"
-#include "zypp/Target.h"
-#include "zypp/Arch.h"
-#include "zypp/repo/RepoVariables.h"
-#include "zypp/base/NonCopyable.h"
+#include <zypp/ZYppFactory.h>
+#include <zypp/ZConfig.h>
+#include <zypp/Target.h>
+#include <zypp/Arch.h>
+#include <zypp/repo/RepoVariables.h>
+#include <zypp/base/NonCopyable.h>
 
 #define ZYPP_DBG_VAREXPAND 0
 #if ( ZYPP_DBG_VAREXPAND )
@@ -400,6 +400,11 @@ namespace zypp
       private:
 	const std::string * _lookup( const std::string & name_r )
 	{
+	  // Safe guard in case the caller does not own a zypp instance. In this case
+	  // getZYpp()->getTarget() in checkOverride would create a zypp instance which
+	  // would clear the variables parsed so far.
+	  auto guard { getZYpp() };
+
 	  if ( empty() )	// at init / after reset
 	  {
 	    // load user definitions from vars.d
@@ -548,14 +553,21 @@ namespace zypp
 
     Url RepoVariablesUrlReplacer::operator()( const Url & value ) const
     {
-      static const Url::ViewOptions toReplace = url::ViewOption::DEFAULTS - url::ViewOption::WITH_USERNAME - url::ViewOption::WITH_PASSWORD;
-      const std::string & replaced( RepoVarExpand()( value.asString( toReplace ), RepoVarsMap::lookup ) );
+      Url::ViewOptions toReplace = value.getViewOptions() - url::ViewOption::WITH_USERNAME - url::ViewOption::WITH_PASSWORD;
+      // Legacy: Not 100% correct because it substitutes inside the 'proxypass=' value,
+      // but this was done before as well. The final fix will have to keep the proxypasswd
+      // out side the url in a cedential file.
+      Url tmpurl { value };
+      tmpurl.setViewOptions( toReplace );
+      const std::string & replaced( RepoVarExpand()( hotfix1050625::asString( tmpurl ), RepoVarsMap::lookup ) );
+
       Url newurl;
       if ( !replaced.empty() )
       {
 	newurl = replaced;
 	newurl.setUsername( value.getUsername( url::E_ENCODED ), url::E_ENCODED );
 	newurl.setPassword( value.getPassword( url::E_ENCODED ), url::E_ENCODED );
+	newurl.setViewOptions( value.getViewOptions() );
       }
       return newurl;
     }
