@@ -10,10 +10,10 @@
 #ifndef ZYPP_REPO_SERVICE_REPOS
 #define ZYPP_REPO_SERVICE_REPOS
 
-#include "zypp/base/NonCopyable.h"
-#include "zypp/ProgressData.h"
-#include "zypp/ServiceInfo.h"
-#include "zypp/RepoInfo.h"
+#include <zypp/base/NonCopyable.h>
+#include <zypp/ProgressData.h>
+#include <zypp/ServiceInfo.h>
+#include <zypp/RepoInfo.h>
 
 namespace zypp
 {
@@ -42,7 +42,7 @@ namespace zypp
       ~ServiceRepos();
 
     public:
-      class Impl;	//!< Expose type only
+      struct Impl;	//!< Expose type only
     private:
       RW_pointer<Impl> _impl;
     };
