@@ -12,16 +12,16 @@
 #include <iostream>
 #include <sstream>
 
-#include "zypp/base/LogTools.h"
-#include "zypp/base/String.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/String.h>
 
-#include "zypp/sat/detail/PoolImpl.h"
+#include <zypp/sat/detail/PoolImpl.h>
 
-#include "zypp/sat/Pool.h"
-#include "zypp/sat/LookupAttr.h"
-#include "zypp/base/StrMatcher.h"
+#include <zypp/sat/Pool.h>
+#include <zypp/sat/LookupAttr.h>
+#include <zypp/base/StrMatcher.h>
 
-#include "zypp/CheckSum.h"
+#include <zypp/CheckSum.h>
 
 using std::endl;
 
@@ -383,7 +383,6 @@ namespace zypp
     {
       switch ( solvAttrType() )
       {
-        case REPOKEY_TYPE_U32:
         case REPOKEY_TYPE_NUM:
         case REPOKEY_TYPE_CONSTANT:
           return true;
@@ -547,7 +546,6 @@ namespace zypp
       {
         switch ( solvAttrType() )
         {
-          case REPOKEY_TYPE_U32:
           case REPOKEY_TYPE_NUM:
           case REPOKEY_TYPE_CONSTANT:
             return _dip->kv.num;
@@ -566,7 +564,6 @@ namespace zypp
       {
         switch ( solvAttrType() )
         {
-          case REPOKEY_TYPE_U32:
           case REPOKEY_TYPE_NUM:
           case REPOKEY_TYPE_CONSTANT:
             return SOLV_KV_NUM64(&_dip->kv);
@@ -634,7 +631,6 @@ namespace zypp
             }
             break;
 
-          case REPOKEY_TYPE_U32:
           case REPOKEY_TYPE_NUM:
           case REPOKEY_TYPE_CONSTANT:
             return str::numstring( asInt() );
