@@ -14,11 +14,11 @@
 
 #include <iosfwd>
 
-#include "zypp/base/PtrTypes.h"
-#include "zypp/base/DefaultIntegral.h"
+#include <zypp/base/PtrTypes.h>
+#include <zypp/base/DefaultIntegral.h>
 
-#include "zypp/sat/detail/PoolMember.h"
-#include "zypp/sat/SolvAttr.h"
+#include <zypp/sat/detail/PoolMember.h>
+#include <zypp/sat/SolvAttr.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -26,7 +26,7 @@ namespace zypp
 
   class CheckSum;
   class Match;
-  class MatchException;
+  struct MatchException;
   class StrMatcher;
 
   ///////////////////////////////////////////////////////////////////
