@@ -14,13 +14,13 @@
 
 #include <iosfwd>
 
-#include "zypp/Pathname.h"
+#include <zypp/Pathname.h>
 
-#include "zypp/sat/detail/PoolMember.h"
-#include "zypp/Repository.h"
-#include "zypp/sat/WhatProvides.h"
-#include "zypp/sat/SolvableSet.h"
-#include "zypp/sat/Queue.h"
+#include <zypp/sat/detail/PoolMember.h>
+#include <zypp/Repository.h>
+#include <zypp/sat/WhatProvides.h>
+#include <zypp/sat/SolvableSet.h>
+#include <zypp/sat/Queue.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -33,6 +33,8 @@ namespace zypp
   namespace sat
   { /////////////////////////////////////////////////////////////////
 
+    class SolvableSpec;
+
     ///////////////////////////////////////////////////////////////////
     //
     //	CLASS NAME : Pool
@@ -190,6 +192,10 @@ namespace zypp
         WhatProvides whatProvides( Capability cap_r ) const
         { return WhatProvides( cap_r ); }
 
+        Queue whatMatchesDep( const SolvAttr &attr, const Capability &cap ) const;
+        Queue whatMatchesSolvable ( const SolvAttr &attr, const Solvable &solv ) const;
+        Queue whatContainsDep ( const SolvAttr &attr, const Capability &cap ) const;
+
       public:
         /** \name Requested locales. */
         //@{
@@ -265,6 +271,13 @@ namespace zypp
 	void setAutoInstalled( const Queue & autoInstalled_r );
         //@}
 
+      public:
+        /** \name Needreboot */
+        //@{
+        /** Solvables which should trigger the reboot-needed hint if installed/updated. */
+        void setNeedrebootSpec( sat::SolvableSpec needrebootSpec_r );
+        //@}
+
       public:
         /** Expert backdoor. */
         detail::CPool * get() const;
