@@ -11,23 +11,23 @@
 */
 #include <iostream>
 
-#include "zypp/base/Logger.h"
-#include "zypp/base/Gettext.h"
-#include "zypp/base/Exception.h"
-#include "zypp/base/Functional.h"
-#include "zypp/base/Collector.h"
-#include "zypp/base/Xml.h"
+#include <zypp/base/Logger.h>
+#include <zypp/base/Gettext.h>
+#include <zypp/base/Exception.h>
+#include <zypp/base/Functional.h>
+#include <zypp/base/Collector.h>
+#include <zypp/base/Xml.h>
 
-#include "zypp/sat/detail/PoolImpl.h"
-#include "zypp/sat/Solvable.h"
-#include "zypp/sat/Pool.h"
-#include "zypp/sat/LookupAttr.h"
+#include <zypp/sat/detail/PoolImpl.h>
+#include <zypp/sat/Solvable.h>
+#include <zypp/sat/Pool.h>
+#include <zypp/sat/LookupAttr.h>
 
-#include "zypp/Repository.h"
-#include "zypp/OnMediaLocation.h"
-#include "zypp/ZConfig.h"
+#include <zypp/Repository.h>
+#include <zypp/OnMediaLocation.h>
+#include <zypp/ZConfig.h>
 
-#include "zypp/ui/Selectable.h"
+#include <zypp/ui/Selectable.h>
 
 using std::endl;
 
@@ -97,6 +97,9 @@ namespace zypp
 
     const Solvable Solvable::noSolvable;
 
+    const IdString Solvable::retractedToken	{ "retracted-patch-package()" };
+    const IdString Solvable::ptfToken		{ "ptf()" };
+
     /////////////////////////////////////////////////////////////////
 
     detail::CSolvable * Solvable::get() const
@@ -387,6 +390,28 @@ namespace zypp
       return myPool().isOnSystemByAuto( ident_r );
     }
 
+    bool Solvable::isNeedreboot() const
+    {
+      NO_SOLVABLE_RETURN( false );
+      return myPool().isNeedreboot( *this );
+    }
+
+    bool Solvable::isRetracted() const
+    {
+      NO_SOLVABLE_RETURN( false );
+      if ( isKind<Package>() )
+	return provides().contains( Capability( retractedToken.id() ) );
+      if ( isKind<Patch>() )
+	return lookupStrAttribute( SolvAttr::updateStatus ) == "retracted";
+      return false;
+    }
+
+    bool Solvable::isPtf() const
+    {
+      NO_SOLVABLE_RETURN( false );
+      return provides().contains( Capability( ptfToken.id() ) );
+    }
+
     bool Solvable::multiversionInstall() const
     {
       NO_SOLVABLE_RETURN( false );
@@ -522,6 +547,18 @@ namespace zypp
       return ret;
     }
 
+    std::pair<bool, CapabilitySet> Solvable::matchesSolvable(const SolvAttr &attr, const Solvable &solv) const
+    {
+      sat::Queue capQueue;
+      int res = solvable_matchessolvable( get(), attr.id(), static_cast<Id>( solv.id() ), capQueue, 0 );
+
+      CapabilitySet caps;
+      if ( capQueue.size() )
+        std::for_each( capQueue.begin(), capQueue.end(), [ &caps ]( auto cap ){ caps.insert( Capability(cap) );});
+
+      return std::make_pair( res == 1, std::move(caps) );
+    }
+
     ///////////////////////////////////////////////////////////////////
     namespace
     {
