@@ -14,16 +14,16 @@
 
 #include <iosfwd>
 
-#include "zypp/sat/detail/PoolMember.h"
-#include "zypp/sat/SolvAttr.h"
-#include "zypp/ResTraits.h"
-#include "zypp/IdString.h"
-#include "zypp/Edition.h"
-#include "zypp/Arch.h"
-#include "zypp/Dep.h"
-#include "zypp/Capabilities.h"
-#include "zypp/Capability.h"
-#include "zypp/Locale.h"
+#include <zypp/sat/detail/PoolMember.h>
+#include <zypp/sat/SolvAttr.h>
+#include <zypp/ResTraits.h>
+#include <zypp/IdString.h>
+#include <zypp/Edition.h>
+#include <zypp/Arch.h>
+#include <zypp/Dep.h>
+#include <zypp/Capabilities.h>
+#include <zypp/Capability.h>
+#include <zypp/Locale.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -55,6 +55,9 @@ namespace zypp
     public:
       typedef sat::detail::SolvableIdType IdType;
 
+      static const IdString retractedToken;	///< Indicator provides `retracted-patch-package()`
+      static const IdString ptfToken;		///< Indicator provides `ptf()`
+
     public:
       /** Default ctor creates \ref noSolvable.*/
       Solvable()
@@ -141,6 +144,15 @@ namespace zypp
        */
       bool multiversionInstall() const;
 
+      /** Whether this solvable triggers the reboot-needed hint if installed/updated. */
+      bool isNeedreboot() const;
+
+      /** Whether this solvable is retracted (provides \ref retractedToken). */
+      bool isRetracted() const;
+
+      /** Whether this solvable is a PTF (provides \ref ptfToken). */
+      bool isPtf() const;
+
       /** The items build time. */
       Date buildtime() const;
 
@@ -220,6 +232,8 @@ namespace zypp
       CapabilitySet valuesOfNamespace( const std::string & namespace_r ) const;
       //@}
 
+      std::pair<bool, CapabilitySet> matchesSolvable ( const SolvAttr &attr, const sat::Solvable &solv ) const;
+
     public:
       /** \name Locale support. */
       //@{
