@@ -13,33 +13,35 @@
 #include <fstream>
 #include <boost/mpl/int.hpp>
 
-#include "zypp/base/Easy.h"
-#include "zypp/base/LogTools.h"
-#include "zypp/base/Gettext.h"
-#include "zypp/base/Exception.h"
-#include "zypp/base/Measure.h"
-#include "zypp/base/WatchFile.h"
-#include "zypp/base/Sysconfig.h"
-#include "zypp/base/IOStream.h"
+#include <zypp/base/Easy.h>
+#include <zypp/base/LogTools.h>
+#include <zypp/base/Gettext.h>
+#include <zypp/base/Exception.h>
+#include <zypp/base/Measure.h>
+#include <zypp/base/WatchFile.h>
+#include <zypp/base/Sysconfig.h>
+#include <zypp/base/IOStream.h>
 
-#include "zypp/ZConfig.h"
+#include <zypp/ZConfig.h>
 
-#include "zypp/sat/detail/PoolImpl.h"
-#include "zypp/sat/SolvableSet.h"
-#include "zypp/sat/Pool.h"
-#include "zypp/Capability.h"
-#include "zypp/Locale.h"
-#include "zypp/PoolItem.h"
+#include <zypp/sat/detail/PoolImpl.h>
+#include <zypp/sat/SolvableSet.h>
+#include <zypp/sat/Pool.h>
+#include <zypp/Capability.h>
+#include <zypp/Locale.h>
+#include <zypp/PoolItem.h>
 
-#include "zypp/target/modalias/Modalias.h"
-#include "zypp/media/MediaPriority.h"
+#include <zypp/target/modalias/Modalias.h>
+#include <zypp/media/MediaPriority.h>
 
 extern "C"
 {
 // Workaround libsolv project not providing a common include
 // directory. (the -devel package does, but the git repo doesn't).
 // #include <solv/repo_helix.h>
+// #include <solv/testcase.h>
 int repo_add_helix( ::Repo *repo, FILE *fp, int flags );
+int testcase_add_testtags(Repo *repo, FILE *fp, int flags);
 }
 
 using std::endl;
@@ -108,6 +110,10 @@ namespace zypp
       static void logSat( CPool *, void *data, int type, const char *logString )
       {
 	//                            "1234567890123456789012345678901234567890
+	if ( 0 == strncmp( logString, "job: user installed", 19 ) )
+	  return;
+	if ( 0 == strncmp( logString, "job: multiversion", 17 ) )
+	  return;
 	if ( 0 == strncmp( logString, "  - no rule created", 19 ) )
 	  return;
 	if ( 0 == strncmp( logString, "    next rules: 0 0", 19 ) )
@@ -236,6 +242,7 @@ namespace zypp
         _serial.setDirty();           // pool content change
         _availableLocalesPtr.reset(); // available locales may change
         _multiversionListPtr.reset(); // re-evaluate ZConfig::multiversionSpec.
+	_needrebootSpec.setDirty();   // re-evaluate needrebootSpec
 
         depSetDirty();	// invaldate dependency/namespace related indices
       }
@@ -337,6 +344,15 @@ namespace zypp
         return 0;
       }
 
+      int PoolImpl::_addTesttags(CRepo *repo_r, FILE *file_r)
+      {
+        setDirty(__FUNCTION__, repo_r->name );
+        int ret = ::testcase_add_testtags( repo_r, file_r, 0 );
+        if ( ret == 0 )
+          _postRepoAdd( repo_r );
+        return 0;
+      }
+
       void PoolImpl::_postRepoAdd( CRepo * repo_r )
       {
         if ( ! isSystemRepo( repo_r ) )
@@ -421,6 +437,14 @@ namespace zypp
 
       void PoolImpl::setTextLocale( const Locale & locale_r )
       {
+	if ( ! locale_r )
+	{
+	  // We need one, so "en" is the last resort
+	  const char *needone[] { "en" };
+	  ::pool_set_languages( _pool, needone, 1 );
+	  return;
+	}
+
 	std::vector<std::string> fallbacklist;
 	for ( Locale l( locale_r ); l; l = l.fallback() )
 	{
@@ -509,10 +533,10 @@ namespace zypp
 	    { localeIds.removed().insert( IdString(lang) ); }
 	  }
 
-	  // Assert that TrackedLocaleIds::current is not empty.
-	  // If, so fill in LanguageCode::enCode as last resort.
-	  if ( localeIds.current().empty() )
-	  { localeIds.current().insert( IdString(Locale::enCode) ); }
+	  // bsc#1155678: We try to differ between an empty RequestedLocales
+	  // and one containing 'en' (explicit or as fallback). An empty RequestedLocales
+	  // should not even drag in recommended 'en' packages. So we no longer enforce
+	  // 'en' being in the set.
 	}
 	return *_trackedLocaleIdsPtr;
       }
