@@ -21,16 +21,17 @@ extern "C"
 }
 #include <iosfwd>
 
-#include "zypp/base/Hash.h"
-#include "zypp/base/NonCopyable.h"
-#include "zypp/base/SerialNumber.h"
-#include "zypp/base/SetTracker.h"
-#include "zypp/sat/detail/PoolMember.h"
-#include "zypp/sat/Queue.h"
-#include "zypp/RepoInfo.h"
-#include "zypp/Locale.h"
-#include "zypp/Capability.h"
-#include "zypp/IdString.h"
+#include <zypp/base/Hash.h>
+#include <zypp/base/NonCopyable.h>
+#include <zypp/base/SerialNumber.h>
+#include <zypp/base/SetTracker.h>
+#include <zypp/sat/detail/PoolMember.h>
+#include <zypp/sat/SolvableSpec.h>
+#include <zypp/sat/Queue.h>
+#include <zypp/RepoInfo.h>
+#include <zypp/Locale.h>
+#include <zypp/Capability.h>
+#include <zypp/IdString.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -142,6 +143,12 @@ namespace zypp
           */
           int _addHelix( CRepo * repo_r, FILE * file_r );
 
+          /** Adding testtags file to a repo.
+           * Except for \c isSystemRepo_r, solvables of incompatible architecture
+           * are filtered out.
+          */
+          int _addTesttags( CRepo * repo_r, FILE * file_r );
+
           /** Adding Solvables to a repo. */
           detail::SolvableIdType _addSolvables( CRepo * repo_r, unsigned count_r );
           //@}
@@ -308,6 +315,21 @@ namespace zypp
           { return _autoinstalled.contains( ident_r.id() ); }
           //@}
 
+	public:
+	  /** \name Solvables which should trigger the reboot-needed hint if installed/updated. */
+          //@{
+          /** Set new Solvable specs.*/
+          void setNeedrebootSpec( sat::SolvableSpec needrebootSpec_r )
+	  {
+	    _needrebootSpec = std::move(needrebootSpec_r);
+	    _needrebootSpec.setDirty();
+	  }
+
+	  /** Whether \a solv_r matches the spec.*/
+	  bool isNeedreboot( const Solvable & solv_r ) const
+	  { return _needrebootSpec.contains( solv_r ); }
+          //@}
+
 	public:
 	  /** accessor for etc/sysconfig/storage reading file on demand */
 	  const std::set<std::string> & requiredFilesystems() const;
@@ -337,6 +359,9 @@ namespace zypp
           /**  */
 	  sat::StringQueue _autoinstalled;
 
+	  /** Solvables which should trigger the reboot-needed hint if installed/updated. */
+	  sat::SolvableSpec _needrebootSpec;
+
 	  /** filesystems mentioned in /etc/sysconfig/storage */
 	  mutable scoped_ptr<std::set<std::string> > _requiredFilesystemsPtr;
       };
