@@ -22,31 +22,27 @@
 
 #define ZYPP_USE_RESOLVER_INTERNALS
 
-#include "zypp/solver/detail/Resolver.h"
-#include "zypp/solver/detail/Testcase.h"
-#include "zypp/solver/detail/SATResolver.h"
-#include "zypp/solver/detail/ItemCapKind.h"
-#include "zypp/solver/detail/SolutionAction.h"
-#include "zypp/solver/detail/SolverQueueItem.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/Algorithm.h>
 
-#include "zypp/Capabilities.h"
-#include "zypp/ZConfig.h"
-#include "zypp/base/Logger.h"
-#include "zypp/base/String.h"
-#include "zypp/base/Gettext.h"
-#include "zypp/base/Algorithm.h"
-#include "zypp/ResPool.h"
-#include "zypp/ResFilters.h"
-#include "zypp/sat/Pool.h"
-#include "zypp/sat/Solvable.h"
-#include "zypp/sat/Transaction.h"
-#include "zypp/ResolverProblem.h"
+#include <zypp/solver/detail/Resolver.h>
+#include <zypp/solver/detail/Testcase.h>
+#include <zypp/solver/detail/SATResolver.h>
+#include <zypp/solver/detail/ItemCapKind.h>
+#include <zypp/solver/detail/SolutionAction.h>
+#include <zypp/solver/detail/SolverQueueItem.h>
+
+#include <zypp/ZConfig.h>
+#include <zypp/sat/Transaction.h>
 
 #define MAXSOLVERRUNS 5
 
 using std::endl;
 using std::make_pair;
 
+#undef ZYPP_BASE_LOGGER_LOGGROUP
+#define ZYPP_BASE_LOGGER_LOGGROUP "zypp::solver"
+
 /////////////////////////////////////////////////////////////////////////
 namespace zypp
 { ///////////////////////////////////////////////////////////////////////
@@ -57,7 +53,6 @@ namespace zypp
     namespace detail
     { ///////////////////////////////////////////////////////////////////
 
-      //using namespace std;
 
 //---------------------------------------------------------------------------
 
@@ -91,7 +86,6 @@ Resolver::Resolver (const ResPool & pool)
     , _solveSrcPackages		( false )
     , _cleandepsOnRemove	( ZConfig::instance().solver_cleandepsOnRemove() )
     , _ignoreAlreadyRecommended	( true )
-
 {
     sat::Pool satPool( sat::Pool::instance() );
     _satResolver = new SATResolver(_pool, satPool.get());
@@ -103,8 +97,15 @@ Resolver::~Resolver()
   delete _satResolver;
 }
 
+sat::detail::CSolver * Resolver::get() const
+{ return _satResolver->get(); }
+
 //---------------------------------------------------------------------------
 // forward flags too SATResolver
+
+void Resolver::setFocus( ResolverFocus focus_r )	{ _satResolver->_focus = ( focus_r == ResolverFocus::Default ) ? ZConfig::instance().solver_focus() : focus_r; }
+ResolverFocus Resolver::focus() const			{ return _satResolver->_focus; }
+
 #define ZOLV_FLAG_TRIBOOL( ZSETTER, ZGETTER, ZVARNAME, ZVARDEFAULT )			\
     void Resolver::ZSETTER( TriBool state_r )						\
     { _satResolver->ZVARNAME = indeterminate(state_r) ? ZVARDEFAULT : bool(state_r); }	\
