@@ -30,16 +30,8 @@
 #include <list>
 #include <map>
 
-#include "zypp/ResPool.h"
-#include "zypp/TriBool.h"
-#include "zypp/base/SerialNumber.h"
-#include "zypp/base/NonCopyable.h"
-
-#include "zypp/ProblemTypes.h"
-#include "zypp/ResolverProblem.h"
-#include "zypp/ProblemSolution.h"
-#include "zypp/Capabilities.h"
-#include "zypp/Capability.h"
+#include <zypp/solver/Types.h>
+#include <zypp/base/SerialNumber.h>
 
 /////////////////////////////////////////////////////////////////////////
 namespace zypp
@@ -186,6 +178,9 @@ class Resolver : private base::NonCopyable
     void setCleandepsOnRemove( TriBool state_r );
     //@}
 
+    void setFocus( ResolverFocus focus_r );
+    ResolverFocus focus() const;
+
 #define ZOLV_FLAG_TRIBOOL( ZSETTER, ZGETTER )	\
     void ZSETTER( TriBool state_r );		\
     bool ZGETTER() const;			\
@@ -225,6 +220,9 @@ class Resolver : private base::NonCopyable
     ItemCapKindList satifiedByInstalled (const PoolItem & item );
     ItemCapKindList installedSatisfied( const PoolItem & item );
 
+public:
+    /** Expert backdoor. */
+    sat::detail::CSolver * get() const;
 };
 
 ///////////////////////////////////////////////////////////////////
