@@ -35,17 +35,7 @@ extern "C"
 #include <map>
 #include <string>
 
-#include "zypp/base/ReferenceCounted.h"
-#include "zypp/base/PtrTypes.h"
-#include "zypp/ResPool.h"
-#include "zypp/base/SerialNumber.h"
-#include "zypp/ProblemTypes.h"
-#include "zypp/ResolverProblem.h"
-#include "zypp/ProblemSolution.h"
-#include "zypp/Capability.h"
-#include "zypp/solver/detail/SolverQueueItem.h"
-
-#include "zypp/sat/detail/PoolMember.h"
+#include <zypp/solver/Types.h>
 
 /////////////////////////////////////////////////////////////////////////
 namespace zypp
@@ -94,6 +84,8 @@ class SATResolver : public base::ReferenceCounted, private base::NonCopyable, pr
     PoolItemList _result_items_to_install;
     PoolItemList _result_items_to_remove;
   public:
+    ResolverFocus _focus;		// The resolvers general attitude
+
     bool _fixsystem:1;			// repair errors in rpm dependency graph
     bool _allowdowngrade:1;		// allow to downgrade installed solvable
     bool _allownamechange:1;		// allow to change name of installed solvable
@@ -103,7 +95,7 @@ class SATResolver : public base::ReferenceCounted, private base::NonCopyable, pr
     bool _updatesystem:1;		// update
     bool _noupdateprovide:1;		// true: update packages needs not to provide old package
     bool _dosplitprovides:1;		// true: consider legacy split provides
-    bool _onlyRequires:1;		// true: consider required packages only
+    bool _onlyRequires:1;		// true: consider required packages only (but recommended namespaces)
     bool _ignorealreadyrecommended:1;	// true: ignore recommended packages that were already recommended by the installed packages
     bool _distupgrade:1;
     bool _distupgrade_removeunsupported:1;
@@ -117,6 +109,8 @@ class SATResolver : public base::ReferenceCounted, private base::NonCopyable, pr
   private:
     // ---------------------------------- methods
     std::string SATprobleminfoString (Id problem, std::string &detail, Id &ignoreId);
+    std::string SATproblemRuleInfoString (Id rule, std::string &detail, Id &ignoreId);
+    std::vector<std::string> SATgetCompleteProblemInfoStrings ( Id problem );
     void resetItemTransaction (PoolItem item);
 
     // Create a SAT solver and reset solver selection in the pool (Collecting
@@ -220,6 +214,10 @@ class SATResolver : public base::ReferenceCounted, private base::NonCopyable, pr
 
     sat::StringQueue autoInstalled() const;
     sat::StringQueue userInstalled() const;
+
+public:
+  /** Expert backdoor. */
+  sat::detail::CSolver * get() const { return _satSolver; }
 };
 
 ///////////////////////////////////////////////////////////////////
