@@ -14,12 +14,12 @@
 
 #include <iosfwd>
 
-#include "zypp/base/PtrTypes.h"
-#include "zypp/base/Function.h"
+#include <zypp/base/PtrTypes.h>
+#include <zypp/base/Function.h>
 
-#include "zypp/PoolItem.h"
-#include "zypp/Pathname.h"
-#include "zypp/ManagedFile.h"
+#include <zypp/PoolItem.h>
+#include <zypp/Pathname.h>
+#include <zypp/ManagedFile.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
