@@ -19,45 +19,81 @@
 #include <sys/types.h>
 #include <dirent.h>
 
-#include "zypp/base/LogTools.h"
-#include "zypp/base/Exception.h"
-#include "zypp/base/Iterator.h"
-#include "zypp/base/Gettext.h"
-#include "zypp/base/IOStream.h"
-#include "zypp/base/Functional.h"
-#include "zypp/base/UserRequestException.h"
-#include "zypp/base/Json.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/Exception.h>
+#include <zypp/base/Iterator.h>
+#include <zypp/base/Gettext.h>
+#include <zypp/base/IOStream.h>
+#include <zypp/base/Functional.h>
+#include <zypp/base/UserRequestException.h>
+#include <zypp/base/Json.h>
 
-#include "zypp/ZConfig.h"
-#include "zypp/ZYppFactory.h"
+#include <zypp/ZConfig.h>
+#include <zypp/ZYppFactory.h>
+#include <zypp/PathInfo.h>
 
-#include "zypp/PoolItem.h"
-#include "zypp/ResObjects.h"
-#include "zypp/Url.h"
-#include "zypp/TmpPath.h"
-#include "zypp/RepoStatus.h"
-#include "zypp/ExternalProgram.h"
-#include "zypp/Repository.h"
-#include "zypp/ShutdownLock_p.h"
+#include <zypp/PoolItem.h>
+#include <zypp/ResObjects.h>
+#include <zypp/Url.h>
+#include <zypp/TmpPath.h>
+#include <zypp/RepoStatus.h>
+#include <zypp/ExternalProgram.h>
+#include <zypp/Repository.h>
+#include <zypp/ShutdownLock_p.h>
 
-#include "zypp/ResFilters.h"
-#include "zypp/HistoryLog.h"
-#include "zypp/target/TargetImpl.h"
-#include "zypp/target/TargetCallbackReceiver.h"
-#include "zypp/target/rpm/librpmDb.h"
-#include "zypp/target/CommitPackageCache.h"
-#include "zypp/target/RpmPostTransCollector.h"
+#include <zypp/ResFilters.h>
+#include <zypp/HistoryLog.h>
+#include <zypp/target/TargetImpl.h>
+#include <zypp/target/TargetCallbackReceiver.h>
+#include <zypp/target/rpm/librpmDb.h>
+#include <zypp/target/CommitPackageCache.h>
+#include <zypp/target/RpmPostTransCollector.h>
 
-#include "zypp/parser/ProductFileReader.h"
-#include "zypp/repo/SrcPackageProvider.h"
+#include <zypp/parser/ProductFileReader.h>
+#include <zypp/repo/SrcPackageProvider.h>
 
-#include "zypp/sat/Pool.h"
-#include "zypp/sat/detail/PoolImpl.h"
-#include "zypp/sat/Transaction.h"
+#include <zypp/sat/Pool.h>
+#include <zypp/sat/detail/PoolImpl.h>
+#include <zypp/sat/SolvableSpec.h>
+#include <zypp/sat/Transaction.h>
 
-#include "zypp/PluginExecutor.h"
+#include <zypp/PluginExecutor.h>
 
-using namespace std;
+using std::endl;
+
+///////////////////////////////////////////////////////////////////
+extern "C"
+{
+#include <solv/repo_rpmdb.h>
+}
+namespace zypp
+{
+  namespace target
+  {
+    inline std::string rpmDbStateHash( const Pathname & root_r )
+    {
+      std::string ret;
+      AutoDispose<void*> state { ::rpm_state_create( sat::Pool::instance().get(), root_r.c_str() ), ::rpm_state_free };
+      AutoDispose<Chksum*> chk { ::solv_chksum_create( REPOKEY_TYPE_SHA1 ), []( Chksum *chk ) -> void {
+	::solv_chksum_free( chk, nullptr );
+      } };
+      if ( ::rpm_hash_database_state( state, chk ) == 0 )
+      {
+	int md5l;
+	const unsigned char * md5 = ::solv_chksum_get( chk, &md5l );
+	ret = ::pool_bin2hex( sat::Pool::instance().get(), md5, md5l );
+      }
+      else
+	WAR << "rpm_hash_database_state failed" << endl;
+      return ret;
+    }
+
+    inline RepoStatus rpmDbRepoStatus( const Pathname & root_r )
+    { return RepoStatus( rpmDbStateHash( root_r ), Date() ); }
+
+  } // namespace target
+} // namespace
+///////////////////////////////////////////////////////////////////
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -569,7 +605,7 @@ namespace zypp
         else if ( format == DIGEST || format == BULK )
         {
           filesystem::TmpFile tmpfile;
-          ofstream out( tmpfile.path().c_str() );
+	  std::ofstream out( tmpfile.path().c_str() );
           for_( it, notifications_r.begin(), notifications_r.end() )
           {
             if ( format == DIGEST )
@@ -662,6 +698,31 @@ namespace zypp
         sendNotification( root_r, result_r.updateMessages() );
       }
 
+      /** jsc#SLE-5116: Log patch status changes to history.
+       * Adjust precomputed set if transaction is incomplete.
+       */
+      void logPatchStatusChanges( const sat::Transaction & transaction_r, TargetImpl & target_r )
+      {
+	ResPool::ChangedPseudoInstalled changedPseudoInstalled { ResPool::instance().changedPseudoInstalled() };
+	if ( changedPseudoInstalled.empty() )
+	  return;
+
+	if ( ! transaction_r.actionEmpty( ~sat::Transaction::STEP_DONE ) )
+	{
+	  // Need to recompute the patch list if commit is incomplete!
+	  // We remember the initially established status, then reload the
+	  // Target to get the current patch status. Then compare.
+	  WAR << "Need to recompute the patch status changes as commit is incomplete!" << endl;
+	  ResPool::EstablishedStates establishedStates{ ResPool::instance().establishedStates() };
+	  target_r.load();
+	  changedPseudoInstalled = establishedStates.changedPseudoInstalled();
+	}
+
+	HistoryLog historylog;
+	for ( const auto & el : changedPseudoInstalled )
+	  historylog.patchStateChange( el.first, el.second );
+      }
+
       /////////////////////////////////////////////////////////////////
     } // namespace
     ///////////////////////////////////////////////////////////////////
@@ -686,8 +747,9 @@ namespace zypp
     , _requestedLocalesFile( home() / "RequestedLocales" )
     , _autoInstalledFile( home() / "AutoInstalled" )
     , _hardLocksFile( Pathname::assertprefix( _root, ZConfig::instance().locksFile() ) )
+    , _vendorAttr( Pathname::assertprefix( _root, ZConfig::instance().vendorPath() ) )
     {
-      _rpm.initDatabase( root_r, Pathname(), doRebuild_r );
+      _rpm.initDatabase( root_r, doRebuild_r );
 
       HistoryLog::setRoot(_root);
 
@@ -712,9 +774,9 @@ namespace zypp
      */
     void updateFileContent( const Pathname &filename,
                             boost::function<bool ()> condition,
-                            boost::function<string ()> value )
+			    boost::function<std::string ()> value )
     {
-        string val = value();
+        std::string val = value();
         // if the value is empty, then just dont
         // do anything, regardless of the condition
         if ( val.empty() )
@@ -786,7 +848,7 @@ namespace zypp
           return;
       }
 
-      string flavor = p->flavor();
+      std::string flavor = p->flavor();
 
       try
       {
@@ -794,7 +856,7 @@ namespace zypp
         updateFileContent( flavorpath,
                            // only if flavor is not empty
                            functor::Constant<bool>( ! flavor.empty() ),
-                           functor::Constant<string>(flavor) );
+			   functor::Constant<std::string>(flavor) );
       }
       catch ( const Exception &e )
       {
@@ -841,7 +903,7 @@ namespace zypp
       bool build_rpm_solv = true;
       // lets see if the rpm solv cache exists
 
-      RepoStatus rpmstatus( RepoStatus(_root/"var/lib/rpm/Name") && RepoStatus(_root/"etc/products.d") );
+      RepoStatus rpmstatus( rpmDbRepoStatus(_root) && RepoStatus(_root/"etc/products.d") );
 
       bool solvexisted = PathInfo(rpmsolv).isExist();
       if ( solvexisted )
@@ -914,6 +976,8 @@ namespace zypp
           cmd.push_back( "-r" );
           cmd.push_back( _root.asString() );
         }
+        cmd.push_back( "-D" );
+        cmd.push_back( rpm().dbPath().asString() );
         cmd.push_back( "-X" );	// autogenerate pattern/product/... from -package
         // bsc#1104415: no more application support // cmd.push_back( "-A" );	// autogenerate application pseudo packages
         cmd.push_back( "-p" );
@@ -1072,6 +1136,36 @@ namespace zypp
 	  q.push( idstr.id() );
 	satpool.setAutoInstalled( q );
       }
+
+      // Load the needreboot package specs
+      {
+	sat::SolvableSpec needrebootSpec;
+	needrebootSpec.addProvides( Capability("installhint(reboot-needed)") );
+
+	Pathname needrebootFile { Pathname::assertprefix( root(), ZConfig::instance().needrebootFile() ) };
+	if ( PathInfo( needrebootFile ).isFile() )
+	  needrebootSpec.parseFrom( needrebootFile );
+
+	Pathname needrebootDir { Pathname::assertprefix( root(), ZConfig::instance().needrebootPath() ) };
+        if ( PathInfo( needrebootDir ).isDir() )
+	{
+	  static const StrMatcher isRpmConfigBackup( "\\.rpm(new|save|orig)$", Match::REGEX );
+
+	  filesystem::dirForEach( needrebootDir, filesystem::matchNoDots(),
+				  [&]( const Pathname & dir_r, const char *const str_r )->bool
+				  {
+				    if ( ! isRpmConfigBackup( str_r ) )
+				    {
+				      Pathname needrebootFile { needrebootDir / str_r };
+				      if ( PathInfo( needrebootFile ).isFile() )
+					needrebootSpec.parseFrom( needrebootFile );
+				    }
+				    return true;
+				  });
+	}
+        satpool.setNeedrebootSpec( std::move(needrebootSpec) );
+      }
+
       if ( ZConfig::instance().apply_locks_file() )
       {
         const HardLocksFile::Data & hardLocks( _hardLocksFile.data() );
@@ -1096,6 +1190,8 @@ namespace zypp
     {
       // ----------------------------------------------------------------- //
       ZYppCommitPolicy policy_r( policy_rX );
+      bool explicitDryRun = policy_r.dryRun();	// explicit dry run will trigger a fileconflict check, implicit (download-only) not.
+
       ShutdownLock lck("Zypp commit running.");
 
       // Fake outstanding YCP fix: Honour restriction to media 1
@@ -1220,7 +1316,7 @@ namespace zypp
 	  if ( ! report->show( patch ) )
 	  {
 	    WAR << "commit aborted by the user" << endl;
-	    ZYPP_THROW( TargetAbortedException( N_("Installation has been aborted as directed.") ) );
+	    ZYPP_THROW( TargetAbortedException( ) );
           }
         }
       }
@@ -1274,7 +1370,7 @@ namespace zypp
 		it->stepStage( sat::Transaction::STEP_ERROR );
                 miss = true;
                 WAR << "commit cache preload aborted by the user" << endl;
-                ZYPP_THROW( TargetAbortedException( N_("Installation has been aborted as directed.") ) );
+                ZYPP_THROW( TargetAbortedException( ) );
                 break;
               }
               catch ( const SkipRequestException & exp )
@@ -1315,12 +1411,32 @@ namespace zypp
 	  else
 	  {
 	    DBG << "dryRun/downloadOnly: Not installing/deleting anything." << endl;
+	    if ( explicitDryRun ) {
+	      // if cache is preloaded, check for file conflicts
+	      commitFindFileConflicts( policy_r, result );
+	    }
 	  }
 	}
       }
       else
       {
         DBG << "dryRun: Not downloading/installing/deleting anything." << endl;
+	if ( explicitDryRun ) {
+	  // if cache is preloaded, check for file conflicts
+	  commitFindFileConflicts( policy_r, result );
+	}
+      }
+
+      {
+	// NOTE: Removing rpm in a transaction, rpm removes the /var/lib/rpm compat symlink.
+	// We re-create it, in case it was lost to prevent legacy tools from accidentally
+	// assuming no database is present.
+	if ( ! PathInfo(_root/"/var/lib/rpm",PathInfo::LSTAT).isExist()
+	  && PathInfo(_root/"/usr/lib/sysimage/rpm").isDir() ) {
+	  WAR << "(rpm removed in commit?) Inject missing /var/lib/rpm compat symlink to /usr/lib/sysimage/rpm" << endl;
+	  filesystem::assert_dir( _root/"/var/lib" );
+	  filesystem::symlink( "../../usr/lib/sysimage/rpm", _root/"/var/lib/rpm" );
+	}
       }
 
       ///////////////////////////////////////////////////////////////////
@@ -1427,7 +1543,6 @@ namespace zypp
               continue;
             }
 
-#warning Exception handling
             // create a installation progress report proxy
             RpmInstallPackageReceiver progress( citem.resolvable() );
             progress.connect(); // disconnected on destruction.
@@ -1468,6 +1583,12 @@ namespace zypp
               }
               else
               {
+                if ( citem.isNeedreboot() ) {
+                  auto rebootNeededFile = root() / "/run/reboot-needed";
+                  if ( filesystem::assert_file( rebootNeededFile ) == EEXIST)
+                    filesystem::touch( rebootNeededFile );
+                }
+
                 success = true;
 		step->stepStage( sat::Transaction::STEP_DONE );
               }
@@ -1578,11 +1699,18 @@ namespace zypp
                 }
                 else
                 {
-                  PathInfo referenceFile( Pathname::assertprefix( _root, Pathname( "/etc/products.d" ) ) / referenceFilename );
-                  if ( ! referenceFile.isFile() || filesystem::unlink( referenceFile.path() ) != 0 )
-                  {
-                    ERR << "Delete orphan product failed: " << referenceFile << endl;
-                  }
+		  Pathname referencePath { Pathname("/etc/products.d") / referenceFilename };	// no root prefix for rpmdb lookup!
+		  if ( ! rpm().hasFile( referencePath.asString() ) )
+		  {
+		    // If it's not owned by a package, we can delete it.
+		    referencePath = Pathname::assertprefix( _root, referencePath );	// now add a root prefix
+		    if ( filesystem::unlink( referencePath ) != 0 )
+		      ERR << "Delete orphan product failed: " << referencePath << endl;
+		  }
+		  else
+		  {
+		    WAR << "Won't remove orphan product: '/etc/products.d/" << referenceFilename << "' is owned by a package." << endl;
+		  }
                 }
               }
             }
@@ -1623,9 +1751,15 @@ namespace zypp
 			   result_r );
       }
 
+      // jsc#SLE-5116: Log patch status changes to history
+      // NOTE: Should be the last action as it may need to reload
+      // the Target in case of an incomplete transaction.
+      logPatchStatusChanges( result_r.transaction(), *this );
+
       if ( abort )
       {
-        ZYPP_THROW( TargetAbortedException( N_("Installation has been aborted as directed.") ) );
+	HistoryLog().comment( "Commit was aborted." );
+        ZYPP_THROW( TargetAbortedException( ) );
       }
     }
 
@@ -1641,12 +1775,6 @@ namespace zypp
       return _rpm.hasFile(path_str, name_str);
     }
 
-
-    Date TargetImpl::timestamp() const
-    {
-      return _rpm.timestamp();
-    }
-
     ///////////////////////////////////////////////////////////////////
     namespace
     {
@@ -1845,6 +1973,13 @@ namespace zypp
 
     ///////////////////////////////////////////////////////////////////
 
+    void TargetImpl::vendorAttr( VendorAttr vendorAttr_r )
+    {
+      MIL << "New VendorAttr: " << vendorAttr_r << endl;
+      _vendorAttr = std::move(vendorAttr_r);
+    }
+    ///////////////////////////////////////////////////////////////////
+
     void TargetImpl::installSrcPackage( const SrcPackage_constPtr & srcPackage_r )
     {
       // provide on local disk
