@@ -29,26 +29,29 @@ extern "C"
 #include <vector>
 #include <algorithm>
 
-#include "zypp/base/Logger.h"
-#include "zypp/base/String.h"
-#include "zypp/base/Gettext.h"
-#include "zypp/base/LocaleGuard.h"
+#include <zypp/base/Logger.h>
+#include <zypp/base/String.h>
+#include <zypp/base/Gettext.h>
+#include <zypp/base/LocaleGuard.h>
+#include <zypp/base/DtorReset.h>
 
-#include "zypp/Date.h"
-#include "zypp/Pathname.h"
-#include "zypp/PathInfo.h"
-#include "zypp/PublicKey.h"
+#include <zypp/Date.h>
+#include <zypp/Pathname.h>
+#include <zypp/PathInfo.h>
+#include <zypp/PublicKey.h>
+#include <zypp/ProgressData.h>
 
-#include "zypp/target/rpm/RpmDb.h"
-#include "zypp/target/rpm/RpmCallbacks.h"
+#include <zypp/target/rpm/RpmDb.h>
+#include <zypp/target/rpm/RpmCallbacks.h>
 
-#include "zypp/HistoryLog.h"
-#include "zypp/target/rpm/librpmDb.h"
-#include "zypp/target/rpm/RpmException.h"
-#include "zypp/TmpPath.h"
-#include "zypp/KeyRing.h"
-#include "zypp/ZYppFactory.h"
-#include "zypp/ZConfig.h"
+#include <zypp/HistoryLog.h>
+#include <zypp/target/rpm/librpmDb.h>
+#include <zypp/target/rpm/RpmException.h>
+#include <zypp/TmpPath.h>
+#include <zypp/KeyRing.h>
+#include <zypp/ZYppFactory.h>
+#include <zypp/ZConfig.h>
+#include <zypp/base/IOTools.h>
 
 using std::endl;
 using namespace zypp::filesystem;
@@ -59,16 +62,33 @@ using namespace zypp::filesystem;
 
 #define WORKAROUNDRPMPWDBUG
 
+#undef ZYPP_BASE_LOGGER_LOGGROUP
+#define ZYPP_BASE_LOGGER_LOGGROUP "librpmDb"
+
 namespace zypp
 {
   namespace zypp_readonly_hack
   {
     bool IGotIt(); // in readonly-mode
   }
+  namespace env
+  {
+    inline bool ZYPP_RPM_DEBUG()
+    {
+      static bool val = [](){
+	const char * env = getenv("ZYPP_RPM_DEBUG");
+	return( env && str::strToBool( env, true ) );
+      }();
+      return val;
+    }
+  } // namespace env
 namespace target
 {
 namespace rpm
 {
+  const callback::UserData::ContentType InstallResolvableReport::contentRpmout( "rpmout","installpkg" );
+  const callback::UserData::ContentType RemoveResolvableReport::contentRpmout( "rpmout","removepkg" );
+
 namespace
 {
 #if 1 // No more need to escape whitespace since rpm-4.4.2.3
@@ -180,37 +200,6 @@ inline std::string stringPath( const Pathname & root_r, const Pathname & sub_r )
   return librpmDb::stringPath( root_r, sub_r );
 }
 
-/******************************************************************
- **
- **
- **	FUNCTION NAME : operator<<
- **	FUNCTION TYPE : std::ostream &
-*/
-std::ostream & operator<<( std::ostream & str, const RpmDb::DbStateInfoBits & obj )
-{
-  if ( obj == RpmDb::DbSI_NO_INIT )
-  {
-    str << "NO_INIT";
-  }
-  else
-  {
-#define ENUM_OUT(B,C) str << ( obj & RpmDb::B ? C : '-' )
-    str << "V4(";
-    ENUM_OUT( DbSI_HAVE_V4,	'X' );
-    ENUM_OUT( DbSI_MADE_V4,	'c' );
-    ENUM_OUT( DbSI_MODIFIED_V4,	'm' );
-    str << ")V3(";
-    ENUM_OUT( DbSI_HAVE_V3,	'X' );
-    ENUM_OUT( DbSI_HAVE_V3TOV4,	'B' );
-    ENUM_OUT( DbSI_MADE_V3TOV4,	'c' );
-    str << ")";
-#undef ENUM_OUT
-  }
-  return str;
-}
-
-
-
 ///////////////////////////////////////////////////////////////////
 //
 //	CLASS NAME : RpmDb
@@ -228,11 +217,8 @@ std::ostream & operator<<( std::ostream & str, const RpmDb::DbStateInfoBits & ob
 //	METHOD TYPE : Constructor
 //
 RpmDb::RpmDb()
-    : _dbStateInfo( DbSI_NO_INIT )
-#warning Check for obsolete memebers
-    , _backuppath ("/var/adm/backup")
+    : _backuppath ("/var/adm/backup")
     , _packagebackups(false)
-    , _warndirexists(false)
 {
   process = 0;
   exit_code = -1;
@@ -258,23 +244,6 @@ RpmDb::~RpmDb()
   sKeyRingReceiver.reset();
 }
 
-Date RpmDb::timestamp() const
-{
-  Date ts_rpm;
-
-  Pathname db_path;
-  if ( dbPath().empty() )
-    db_path = "/var/lib/rpm";
-  else
-    db_path = dbPath();
-
-  PathInfo rpmdb_info(root() + db_path + "/Packages");
-
-  if ( rpmdb_info.isExist() )
-    return rpmdb_info.mtime();
-  else
-    return Date::now();
-}
 ///////////////////////////////////////////////////////////////////
 //
 //
@@ -283,27 +252,7 @@ Date RpmDb::timestamp() const
 //
 std::ostream & RpmDb::dumpOn( std::ostream & str ) const
 {
-  str << "RpmDb[";
-
-  if ( _dbStateInfo == DbSI_NO_INIT )
-  {
-    str << "NO_INIT";
-  }
-  else
-  {
-#define ENUM_OUT(B,C) str << ( _dbStateInfo & B ? C : '-' )
-    str << "V4(";
-    ENUM_OUT( DbSI_HAVE_V4,	'X' );
-    ENUM_OUT( DbSI_MADE_V4,	'c' );
-    ENUM_OUT( DbSI_MODIFIED_V4,	'm' );
-    str << ")V3(";
-    ENUM_OUT( DbSI_HAVE_V3,	'X' );
-    ENUM_OUT( DbSI_HAVE_V3TOV4,	'B' );
-    ENUM_OUT( DbSI_MADE_V3TOV4,	'c' );
-    str << "): " << stringPath( _root, _dbPath );
-#undef ENUM_OUT
-  }
-  return str << "]";
+  return str << "RpmDb[" << stringPath( _root, _dbPath ) << "]";
 }
 
 ///////////////////////////////////////////////////////////////////
@@ -312,7 +261,7 @@ std::ostream & RpmDb::dumpOn( std::ostream & str ) const
 //	METHOD NAME : RpmDb::initDatabase
 //	METHOD TYPE : PMError
 //
-void RpmDb::initDatabase( Pathname root_r, Pathname dbPath_r, bool doRebuild_r )
+void RpmDb::initDatabase( Pathname root_r, bool doRebuild_r )
 {
   ///////////////////////////////////////////////////////////////////
   // Check arguments
@@ -322,34 +271,39 @@ void RpmDb::initDatabase( Pathname root_r, Pathname dbPath_r, bool doRebuild_r )
   if ( root_r.empty() )
     root_r = "/";
 
-  if ( dbPath_r.empty() )
-    dbPath_r = "/var/lib/rpm";
+  const Pathname & dbPath_r { librpmDb::suggestedDbPath( root_r ) };	// also asserts root_r is absolute
 
-  if ( ! (root_r.absolute() && dbPath_r.absolute()) )
+  // The rpmdb compat symlink.
+  // Required at least until rpmdb2solv takes a dppath argument.
+  // Otherwise it creates a db at "/var/lib/rpm".
+  if ( dbPath_r != "/var/lib/rpm" && ! PathInfo( root_r/"/var/lib/rpm" ).isExist() )
   {
-    ERR << "Illegal root or dbPath: " << stringPath( root_r, dbPath_r ) << endl;
-    ZYPP_THROW(RpmInvalidRootException(root_r, dbPath_r));
+    WAR << "Inject missing /var/lib/rpm compat symlink to " << dbPath_r << endl;
+    filesystem::assert_dir( root_r/"/var/lib" );
+    filesystem::symlink( "../../"/dbPath_r, root_r/"/var/lib/rpm" );
   }
 
-  MIL << "Calling initDatabase: " << stringPath( root_r, dbPath_r )
-      << ( doRebuild_r ? " (rebuilddb)" : "" )
-      << ( quickinit ? " (quickinit)" : "" ) << endl;
-
   ///////////////////////////////////////////////////////////////////
   // Check whether already initialized
   ///////////////////////////////////////////////////////////////////
   if ( initialized() )
   {
-    if ( root_r == _root && dbPath_r == _dbPath )
-    {
+    // Just check for a changing root because the librpmDb::suggestedDbPath
+    // may indeed change: rpm %post moving the db from /var/lib/rpm
+    // to /usr/lib/sysimage/rpm. We continue to use the old dbpath
+    // (via the compat symlink) until a re-init.
+    if ( root_r == _root ) {
+      MIL << "Calling initDatabase: already initialized at " << stringPath( _root, _dbPath ) << endl;
       return;
     }
     else
-    {
       ZYPP_THROW(RpmDbAlreadyOpenException(_root, _dbPath, root_r, dbPath_r));
-    }
   }
 
+  MIL << "Calling initDatabase: " << stringPath( root_r, dbPath_r )
+      << ( doRebuild_r ? " (rebuilddb)" : "" )
+      << ( quickinit ? " (quickinit)" : "" ) << endl;
+
   ///////////////////////////////////////////////////////////////////
   // init database
   ///////////////////////////////////////////////////////////////////
@@ -361,56 +315,23 @@ void RpmDb::initDatabase( Pathname root_r, Pathname dbPath_r, bool doRebuild_r )
     return;
   }
 
-  DbStateInfoBits info = DbSI_NO_INIT;
   try
   {
-    internal_initDatabase( root_r, dbPath_r, info );
+    // creates dbdir and empty rpm database if not present
+    librpmDb::dbAccess( root_r );
   }
   catch (const RpmException & excpt_r)
   {
     ZYPP_CAUGHT(excpt_r);
     librpmDb::blockAccess();
-    ERR << "Cleanup on error: state " << info << endl;
-
-    if ( dbsi_has( info, DbSI_MADE_V4 ) )
-    {
-      // remove the newly created rpm4 database and
-      // any backup created on conversion.
-      removeV4( root_r + dbPath_r, dbsi_has( info, DbSI_MADE_V3TOV4 ) );
-    }
     ZYPP_RETHROW(excpt_r);
   }
-  if ( dbsi_has( info, DbSI_HAVE_V3 ) )
-  {
-    if ( root_r == "/" || dbsi_has( info, DbSI_MODIFIED_V4 ) )
-    {
-      // Move obsolete rpm3 database beside.
-      MIL << "Cleanup: state " << info << endl;
-      removeV3( root_r + dbPath_r, dbsi_has( info, DbSI_MADE_V3TOV4 ) );
-      dbsi_clr( info, DbSI_HAVE_V3 );
-    }
-    else
-    {
-      // Performing an update: Keep the original rpm3 database
-      // and wait if the rpm4 database gets modified by installing
-      // or removing packages. Cleanup in modifyDatabase or closeDatabase.
-      MIL << "Update mode: Cleanup delayed until closeOldDatabase." << endl;
-    }
-  }
-#warning CHECK: notify root about conversion backup.
 
   _root   = root_r;
   _dbPath = dbPath_r;
-  _dbStateInfo = info;
 
   if ( doRebuild_r )
-  {
-    if (      dbsi_has( info, DbSI_HAVE_V4 )
-         && ! dbsi_has( info, DbSI_MADE_V4 ) )
-    {
-      rebuildDatabase();
-    }
-  }
+    rebuildDatabase();
 
   MIL << "Synchronizing keys with zypp keyring" << endl;
   syncTrustedKeys();
@@ -424,286 +345,6 @@ void RpmDb::initDatabase( Pathname root_r, Pathname dbPath_r, bool doRebuild_r )
   MIL << "InitDatabase: " << *this << endl;
 }
 
-///////////////////////////////////////////////////////////////////
-//
-//
-//	METHOD NAME : RpmDb::internal_initDatabase
-//	METHOD TYPE : PMError
-//
-void RpmDb::internal_initDatabase( const Pathname & root_r, const Pathname & dbPath_r,
-                                   DbStateInfoBits & info_r )
-{
-  info_r = DbSI_NO_INIT;
-
-  ///////////////////////////////////////////////////////////////////
-  // Get info about the desired database dir
-  ///////////////////////////////////////////////////////////////////
-  librpmDb::DbDirInfo dbInfo( root_r, dbPath_r );
-
-  if ( dbInfo.illegalArgs() )
-  {
-    // should not happen (checked in initDatabase)
-    ZYPP_THROW(RpmInvalidRootException(root_r, dbPath_r));
-  }
-  if ( ! dbInfo.usableArgs() )
-  {
-    ERR << "Bad database directory: " << dbInfo.dbDir() << endl;
-    ZYPP_THROW(RpmInvalidRootException(root_r, dbPath_r));
-  }
-
-  if ( dbInfo.hasDbV4() )
-  {
-    dbsi_set( info_r, DbSI_HAVE_V4 );
-    MIL << "Found rpm4 database in " << dbInfo.dbDir() << endl;
-  }
-  else
-  {
-    MIL << "Creating new rpm4 database in " << dbInfo.dbDir() << endl;
-  }
-
-  if ( dbInfo.hasDbV3() )
-  {
-    dbsi_set( info_r, DbSI_HAVE_V3 );
-  }
-  if ( dbInfo.hasDbV3ToV4() )
-  {
-    dbsi_set( info_r, DbSI_HAVE_V3TOV4 );
-  }
-
-  DBG << "Initial state: " << info_r << ": " << stringPath( root_r, dbPath_r );
-  librpmDb::dumpState( DBG ) << endl;
-
-  ///////////////////////////////////////////////////////////////////
-  // Access database, create if needed
-  ///////////////////////////////////////////////////////////////////
-
-  // creates dbdir and empty rpm4 database if not present
-  librpmDb::dbAccess( root_r, dbPath_r );
-
-  if ( ! dbInfo.hasDbV4() )
-  {
-    dbInfo.restat();
-    if ( dbInfo.hasDbV4() )
-    {
-      dbsi_set( info_r, DbSI_HAVE_V4 | DbSI_MADE_V4 );
-    }
-  }
-
-  DBG << "Access state: " << info_r << ": " << stringPath( root_r, dbPath_r );
-  librpmDb::dumpState( DBG ) << endl;
-
-  ///////////////////////////////////////////////////////////////////
-  // Check whether to convert something. Create backup but do
-  // not remove anything here
-  ///////////////////////////////////////////////////////////////////
-  librpmDb::constPtr dbptr;
-  librpmDb::dbAccess( dbptr );
-  bool dbEmpty = dbptr->empty();
-  if ( dbEmpty )
-  {
-    MIL << "Empty rpm4 database "  << dbInfo.dbV4() << endl;
-  }
-
-  if ( dbInfo.hasDbV3() )
-  {
-    MIL << "Found rpm3 database " << dbInfo.dbV3() << endl;
-
-    if ( dbEmpty )
-    {
-      extern void convertV3toV4( const Pathname & v3db_r, const librpmDb::constPtr & v4db_r );
-      convertV3toV4( dbInfo.dbV3().path(), dbptr );
-
-      // create a backup copy
-      int res = filesystem::copy( dbInfo.dbV3().path(), dbInfo.dbV3ToV4().path() );
-      if ( res )
-      {
-        WAR << "Backup converted rpm3 database failed: error(" << res << ")" << endl;
-      }
-      else
-      {
-        dbInfo.restat();
-        if ( dbInfo.hasDbV3ToV4() )
-        {
-          MIL << "Backup converted rpm3 database: " << dbInfo.dbV3ToV4() << endl;
-          dbsi_set( info_r, DbSI_HAVE_V3TOV4 | DbSI_MADE_V3TOV4 );
-        }
-      }
-
-    }
-    else
-    {
-
-      WAR << "Non empty rpm3 and rpm4 database found: using rpm4" << endl;
-      // set DbSI_MODIFIED_V4 as it's not a temporary which can be removed.
-      dbsi_set( info_r, DbSI_MODIFIED_V4 );
-
-    }
-
-    DBG << "Convert state: " << info_r << ": " << stringPath( root_r, dbPath_r );
-    librpmDb::dumpState( DBG ) << endl;
-  }
-
-  if ( dbInfo.hasDbV3ToV4() )
-  {
-    MIL << "Rpm3 database backup: " << dbInfo.dbV3ToV4() << endl;
-  }
-}
-
-///////////////////////////////////////////////////////////////////
-//
-//
-//	METHOD NAME : RpmDb::removeV4
-//	METHOD TYPE : void
-//
-void RpmDb::removeV4( const Pathname & dbdir_r, bool v3backup_r )
-{
-  const char * v3backup = "packages.rpm3";
-  const char * master = "Packages";
-  const char * index[] =
-    {
-      "Basenames",
-      "Conflictname",
-      "Depends",
-      "Dirnames",
-      "Filemd5s",
-      "Group",
-      "Installtid",
-      "Name",
-      "Providename",
-      "Provideversion",
-      "Pubkeys",
-      "Requirename",
-      "Requireversion",
-      "Sha1header",
-      "Sigmd5",
-      "Triggername",
-      // last entry!
-      NULL
-    };
-
-  PathInfo pi( dbdir_r );
-  if ( ! pi.isDir() )
-  {
-    ERR << "Can't remove rpm4 database in non directory: " << dbdir_r << endl;
-    return;
-  }
-
-  for ( const char ** f = index; *f; ++f )
-  {
-    pi( dbdir_r + *f );
-    if ( pi.isFile() )
-    {
-      filesystem::unlink( pi.path() );
-    }
-  }
-
-  pi( dbdir_r + master );
-  if ( pi.isFile() )
-  {
-    MIL << "Removing rpm4 database " << pi << endl;
-    filesystem::unlink( pi.path() );
-  }
-
-  if ( v3backup_r )
-  {
-    pi( dbdir_r + v3backup );
-    if ( pi.isFile() )
-    {
-      MIL << "Removing converted rpm3 database backup " << pi << endl;
-      filesystem::unlink( pi.path() );
-    }
-  }
-}
-
-///////////////////////////////////////////////////////////////////
-//
-//
-//	METHOD NAME : RpmDb::removeV3
-//	METHOD TYPE : void
-//
-void RpmDb::removeV3( const Pathname & dbdir_r, bool v3backup_r )
-{
-  const char * master = "packages.rpm";
-  const char * index[] =
-    {
-      "conflictsindex.rpm",
-      "fileindex.rpm",
-      "groupindex.rpm",
-      "nameindex.rpm",
-      "providesindex.rpm",
-      "requiredby.rpm",
-      "triggerindex.rpm",
-      // last entry!
-      NULL
-    };
-
-  PathInfo pi( dbdir_r );
-  if ( ! pi.isDir() )
-  {
-    ERR << "Can't remove rpm3 database in non directory: " << dbdir_r << endl;
-    return;
-  }
-
-  for ( const char ** f = index; *f; ++f )
-  {
-    pi( dbdir_r + *f );
-    if ( pi.isFile() )
-    {
-      filesystem::unlink( pi.path() );
-    }
-  }
-
-#warning CHECK: compare vs existing v3 backup. notify root
-  pi( dbdir_r + master );
-  if ( pi.isFile() )
-  {
-    Pathname m( pi.path() );
-    if ( v3backup_r )
-    {
-      // backup was already created
-      filesystem::unlink( m );
-      Pathname b( m.extend( "3" ) );
-      pi( b ); // stat backup
-    }
-    else
-    {
-      Pathname b( m.extend( ".deleted" ) );
-      pi( b );
-      if ( pi.isFile() )
-      {
-        // rempve existing backup
-        filesystem::unlink( b );
-      }
-      filesystem::rename( m, b );
-      pi( b ); // stat backup
-    }
-    MIL << "(Re)moved rpm3 database to " << pi << endl;
-  }
-}
-
-///////////////////////////////////////////////////////////////////
-//
-//
-//	METHOD NAME : RpmDb::modifyDatabase
-//	METHOD TYPE : void
-//
-void RpmDb::modifyDatabase()
-{
-  if ( ! initialized() )
-    return;
-
-  // tag database as modified
-  dbsi_set( _dbStateInfo, DbSI_MODIFIED_V4 );
-
-  // Move outdated rpm3 database beside.
-  if ( dbsi_has( _dbStateInfo, DbSI_HAVE_V3 ) )
-  {
-    MIL << "Update mode: Delayed cleanup: state " << _dbStateInfo << endl;
-    removeV3( _root + _dbPath, dbsi_has( _dbStateInfo, DbSI_MADE_V3TOV4 ) );
-    dbsi_clr( _dbStateInfo, DbSI_HAVE_V3 );
-  }
-}
-
 ///////////////////////////////////////////////////////////////////
 //
 //
@@ -724,29 +365,10 @@ void RpmDb::closeDatabase()
   ///////////////////////////////////////////////////////////////////
   librpmDb::blockAccess();
 
-  ///////////////////////////////////////////////////////////////////
-  // Check fate if old version database still present
-  ///////////////////////////////////////////////////////////////////
-  if ( dbsi_has( _dbStateInfo, DbSI_HAVE_V3 ) )
-  {
-    MIL << "Update mode: Delayed cleanup: state " << _dbStateInfo << endl;
-    if ( dbsi_has( _dbStateInfo, DbSI_MODIFIED_V4 ) )
-    {
-      // Move outdated rpm3 database beside.
-      removeV3( _root + _dbPath, dbsi_has( _dbStateInfo, DbSI_MADE_V3TOV4 )  );
-    }
-    else
-    {
-      // Remove unmodified rpm4 database
-      removeV4( _root + _dbPath, dbsi_has( _dbStateInfo, DbSI_MADE_V3TOV4 ) );
-    }
-  }
-
   ///////////////////////////////////////////////////////////////////
   // Uninit
   ///////////////////////////////////////////////////////////////////
   _root = _dbPath = Pathname();
-  _dbStateInfo = DbSI_NO_INIT;
 
   MIL << "closeDatabase: " << *this << endl;
 }
@@ -778,62 +400,73 @@ void RpmDb::rebuildDatabase()
 void RpmDb::doRebuildDatabase(callback::SendReport<RebuildDBReport> & report)
 {
   FAILIFNOTINITIALIZED;
-
   MIL << "RpmDb::rebuildDatabase" << *this << endl;
-  // FIXME  Timecount _t( "RpmDb::rebuildDatabase" );
 
-  PathInfo dbMaster( root() + dbPath() + "Packages" );
-  PathInfo dbMasterBackup( dbMaster.path().extend( ".y2backup" ) );
+  const Pathname mydbpath { root()/dbPath() };	// the configured path used in reports
+  {
+    // For --rebuilddb take care we're using the real db directory
+    // and not a symlink. Otherwise rpm will rename the symlink and
+    // replace it with a real directory containing the converted db.
+    DtorReset guardRoot  { _root };
+    DtorReset guardDbPath{ _dbPath };
+    _root = "/";
+    _dbPath = filesystem::expandlink( mydbpath );
 
-  // run rpm
-  RpmArgVec opts;
-  opts.push_back("--rebuilddb");
-  opts.push_back("-vv");
+    // run rpm
+    RpmArgVec opts;
+    opts.push_back("--rebuilddb");
+    opts.push_back("-vv");
+    run_rpm (opts, ExternalProgram::Stderr_To_Stdout);
+  }
 
-  // don't call modifyDatabase because it would remove the old
-  // rpm3 database, if the current database is a temporary one.
-  run_rpm (opts, ExternalProgram::Stderr_To_Stdout);
-
-  // progress report: watch this file growing
-  PathInfo newMaster( root()
-                      + dbPath().extend( str::form( "rebuilddb.%d",
-                                                    process?process->getpid():0) )
-                      + "Packages" );
-
-  std::string       line;
-  std::string       errmsg;
+  // generate and report progress
+  ProgressData tics;
+  {
+    ProgressData::value_type hdrTotal = 0;
+    for ( librpmDb::db_const_iterator it; *it; ++it, ++hdrTotal )
+    {;}
+    tics.range( hdrTotal );
+  }
+  tics.sendTo( [&report,&mydbpath]( const ProgressData & tics_r ) -> bool {
+    return report->progress( tics_r.reportValue(), mydbpath );
+  } );
+  tics.toMin();
 
+  std::string line;
+  std::string errmsg;
   while ( systemReadLine( line ) )
   {
-    if ( newMaster() )
-    { // file is removed at the end of rebuild.
-      // current size should be upper limit for new db
-      if ( ! report->progress( (100 * newMaster.size()) / dbMaster.size(), root() + dbPath()) )
+    static const std::string debugPrefix    { "D:" };
+    static const std::string progressPrefix { "D:  read h#" };
+    static const std::string ignoreSuffix   { "digest: OK" };
+
+    if ( ! str::startsWith( line, debugPrefix ) )
+    {
+      if ( ! str::endsWith( line, ignoreSuffix ) )
       {
-        WAR << "User requested abort." << endl;
-        systemKill();
-        filesystem::recursive_rmdir( newMaster.path().dirname() );
+	errmsg += line;
+	errmsg += '\n';
+	WAR << line << endl;
       }
     }
-
-    if ( line.compare( 0, 2, "D:" ) )
+    else if ( str::startsWith( line, progressPrefix ) )
     {
-      errmsg += line + '\n';
-      //      report.notify( line );
-      WAR << line << endl;
+      if ( ! tics.incr() )
+      {
+	WAR << "User requested abort." << endl;
+	systemKill();
+      }
     }
   }
 
-  int rpm_status = systemStatus();
-
-  if ( rpm_status != 0 )
+  if ( systemStatus() != 0 )
   {
     //TranslatorExplanation after semicolon is error message
     ZYPP_THROW(RpmSubprocessException(std::string(_("RPM failed: ")) + (errmsg.empty() ? error_message: errmsg) ) );
   }
   else
   {
-    report->progress( 100, root() + dbPath() ); // 100%
+    tics.toMax();
   }
 }
 
@@ -1019,9 +652,10 @@ void RpmDb::syncTrustedKeys( SyncTrustedKeyBits mode_r )
       if ( ! missingKeys.empty() )
         callback::SendReport<KeyRingReport>()->reportNonImportedKeys(missingKeys);
     }
-    catch (Exception &e)
+    catch ( const Exception & excpt )
     {
-      ERR << "Could not import keys into zypp keyring" << endl;
+      ZYPP_CAUGHT( excpt );
+      ERR << "Could not import keys into zypp keyring: " << endl;
     }
   }
 
@@ -1111,8 +745,6 @@ void RpmDb::importPubkey( const PublicKey & pubkey_r )
     opts.push_back ( "--allmatches" );
     opts.push_back ( "--" );
     opts.push_back ( keyName.c_str() );
-    // don't call modifyDatabase because it would remove the old
-    // rpm3 database, if the current database is a temporary one.
     run_rpm( opts, ExternalProgram::Stderr_To_Stdout );
 
     std::string line;
@@ -1137,9 +769,6 @@ void RpmDb::importPubkey( const PublicKey & pubkey_r )
   opts.push_back ( "--" );
   std::string pubkeypath( pubkey_r.path().asString() );
   opts.push_back ( pubkeypath.c_str() );
-
-  // don't call modifyDatabase because it would remove the old
-  // rpm3 database, if the current database is a temporary one.
   run_rpm( opts, ExternalProgram::Stderr_To_Stdout );
 
   std::string line;
@@ -1207,9 +836,6 @@ void RpmDb::removePubkey( const PublicKey & pubkey_r )
   opts.push_back ( "-e" );
   opts.push_back ( "--" );
   opts.push_back ( rpm_name.c_str() );
-
-  // don't call modifyDatabase because it would remove the old
-  // rpm3 database, if the current database is a temporary one.
   run_rpm( opts, ExternalProgram::Stderr_To_Stdout );
 
   std::string line;
@@ -1547,8 +1173,13 @@ namespace
 
     rpmQVKArguments_s qva;
     memset( &qva, 0, sizeof(rpmQVKArguments_s) );
+#ifdef HAVE_NO_RPMTSSETVFYFLAGS
+    // Legacy: In rpm >= 4.15 qva_flags symbols don't exist
+    // and qva_flags is not used in signature checking at all.
     qva.qva_flags = (VERIFY_DIGEST|VERIFY_SIGNATURE);
-
+#else
+    ::rpmtsSetVfyFlags( ts, RPMVSF_DEFAULT );
+#endif
     RpmlogCapture vresult;
     LocaleGuard guard( LC_ALL, "C" );	// bsc#1076415: rpm log output is localized, but we need to parse it :(
     int res = ::rpmVerifySignatures( &qva, ts, fd, path_r.basename().c_str() );
@@ -1586,6 +1217,8 @@ namespace
       { lineres = RpmDb::CHK_NOTFOUND; }
       else if ( line.find( ": NOTRUSTED" ) != std::string::npos )
       { lineres = RpmDb::CHK_NOTTRUSTED; }
+      else if ( line.find( ": NOTFOUND" ) != std::string::npos )
+      { continue; } // just collect details for signatures found (#229)
 
       ++count[lineres];
       detail_r.push_back( RpmDb::CheckPackageDetail::value_type( lineres, std::move(line) ) );
@@ -1620,6 +1253,8 @@ namespace
       WAR << path_r << " (" << requireGPGSig_r << " -> " << ret << ")" << endl;
       WAR << vresult;
     }
+    else
+      DBG << path_r << " [0-Signature is OK]" << endl;
     return ret;
   }
 
@@ -1733,7 +1368,8 @@ RpmDb::run_rpm (const RpmArgVec& opts,
   args.push_back(_root.asString().c_str());
   args.push_back("--dbpath");
   args.push_back(_dbPath.asString().c_str());
-
+  if ( env::ZYPP_RPM_DEBUG() )
+    args.push_back("-vv");
   const char* argv[args.size() + opts.size() + 1];
 
   const char** p = argv;
@@ -1764,61 +1400,39 @@ bool RpmDb::systemReadLine( std::string & line )
   {
     process->setBlocking( false );
     FILE * inputfile = process->inputFile();
-    int    inputfileFd = ::fileno( inputfile );
-    do
-    {
-      /* Watch inputFile to see when it has input. */
-      fd_set rfds;
-      FD_ZERO( &rfds );
-      FD_SET( inputfileFd, &rfds );
+    do {
+      // Check every 5 seconds if the process is still running to prevent against
+      // daemons launched in rpm %post that do not close their filedescriptors,
+      // causing us to block for infinity. (bnc#174548)
+      const auto &readResult = io::receiveUpto( inputfile, '\n', 5 * 1000, false );
+      switch ( readResult.first ) {
+        case io::ReceiveUpToResult::Timeout: {
+          if ( !process->running() )
+            return false;
 
-      /* Wait up to 5 seconds. */
-      struct timeval tv;
-      tv.tv_sec = 5;
-      tv.tv_usec = 0;
+          // we might have received a partial line, lets not forget about it
+          line += readResult.second;
+        }
+        case io::ReceiveUpToResult::Error:
+        case io::ReceiveUpToResult::EndOfFile: {
+          line += readResult.second;
+          if ( line.size() && line.back() == '\n')
+            line.pop_back();
+          return line.size(); // in case of pending output
+        }
+        case io::ReceiveUpToResult::Success: {
+          line += readResult.second;
 
-      int retval = select( inputfileFd+1, &rfds, NULL, NULL, &tv );
+          if ( line.size() && line.back() == '\n')
+            line.pop_back();
 
-      if ( retval == -1 )
-      {
-	ERR << "select error: " << strerror(errno) << endl;
-	if ( errno != EINTR )
-	  return false;
+          if ( env::ZYPP_RPM_DEBUG() )
+            L_DBG("RPM_DEBUG") << line << endl;
+          return true; // complete line
+        }
       }
-      else if ( retval )
-      {
-	// Data is available now.
-	static size_t linebuffer_size = 0;	// static because getline allocs
-	static char * linebuffer = 0; 		// and reallocs if buffer is too small
-	ssize_t nread = getline( &linebuffer, &linebuffer_size, inputfile );
-	if ( nread == -1 )
-	{
-	  if ( ::feof( inputfile ) )
-	    return line.size(); // in case of pending output
-	}
-	else
-	{
-	  if ( nread > 0 )
-	  {
-	    if ( linebuffer[nread-1] == '\n' )
-	      --nread;
-	    line += std::string( linebuffer, nread );
-	  }
-
-	  if ( ! ::ferror( inputfile ) || ::feof( inputfile ) )
-	    return true; // complete line
-	}
-	clearerr( inputfile );
-      }
-      else
-      {
-	// No data within time.
-	if ( ! process->running() )
-	  return false;
-      }
-    } while ( true );
+    } while( true );
   }
-
   return false;
 }
 
@@ -2044,15 +1658,20 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
   // rpm requires additional quoting of special chars:
   std::string quotedFilename( rpmQuoteFilename( workaroundRpmPwdBug( filename ) ) );
   opts.push_back ( quotedFilename.c_str() );
-
-  modifyDatabase(); // BEFORE run_rpm
   run_rpm( opts, ExternalProgram::Stderr_To_Stdout );
 
+  // forward additional rpm output via report;
   std::string line;
+  unsigned    lineno = 0;
+  callback::UserData cmdout( InstallResolvableReport::contentRpmout );
+  // Key "solvable" injected by RpmInstallPackageReceiver
+  cmdout.set( "line",   std::cref(line) );
+  cmdout.set( "lineno", lineno );
+
+  // LEGACY: collect and forward additional rpm output in finish
   std::string rpmmsg;				// TODO: immediately forward lines via Callback::report rather than collecting
   std::vector<std::string> configwarnings;	// TODO: immediately process lines rather than collecting
 
-  unsigned linecnt = 0;
   while ( systemReadLine( line ) )
   {
     if ( str::startsWith( line, "%%" ) )
@@ -2062,18 +1681,21 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
       report->progress( percent );
       continue;
     }
+    ++lineno;
+    cmdout.set( "lineno", lineno );
+    report->report( cmdout );
 
-    if ( linecnt < MAXRPMMESSAGELINES )
-      ++linecnt;
-    else if ( line.find( " scriptlet failed, " ) == std::string::npos )	// always log %script errors
-      continue;
+    if ( lineno >= MAXRPMMESSAGELINES ) {
+      if ( line.find( " scriptlet failed, " ) == std::string::npos )	// always log %script errors
+	continue;
+    }
 
     rpmmsg += line+'\n';
 
     if ( str::startsWith( line, "warning:" ) )
       configwarnings.push_back(line);
   }
-  if ( linecnt >= MAXRPMMESSAGELINES )
+  if ( lineno >= MAXRPMMESSAGELINES )
     rpmmsg += "[truncated]\n";
 
   int rpm_status = systemStatus();
@@ -2215,11 +1837,18 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
 
   opts.push_back("--");
   opts.push_back(name_r.c_str());
-
-  modifyDatabase(); // BEFORE run_rpm
   run_rpm (opts, ExternalProgram::Stderr_To_Stdout);
 
+  // forward additional rpm output via report;
   std::string line;
+  unsigned    lineno = 0;
+  callback::UserData cmdout( RemoveResolvableReport::contentRpmout );
+  // Key "solvable" injected by RpmInstallPackageReceiver
+  cmdout.set( "line",   std::cref(line) );
+  cmdout.set( "lineno", lineno );
+
+
+  // LEGACY: collect and forward additional rpm output in finish
   std::string rpmmsg;		// TODO: immediately forward lines via Callback::report rather than collecting
 
   // got no progress from command, so we fake it:
@@ -2227,16 +1856,19 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
   // 50 - command completed
   // 100 if no error
   report->progress( 5 );
-  unsigned linecnt = 0;
   while (systemReadLine(line))
   {
-    if ( linecnt < MAXRPMMESSAGELINES )
-      ++linecnt;
-    else if ( line.find( " scriptlet failed, " ) == std::string::npos )	// always log %script errors
-      continue;
+    ++lineno;
+    cmdout.set( "lineno", lineno );
+    report->report( cmdout );
+
+    if ( lineno >= MAXRPMMESSAGELINES ) {
+      if ( line.find( " scriptlet failed, " ) == std::string::npos )	// always log %script errors
+	continue;
+    }
     rpmmsg += line+'\n';
   }
-  if ( linecnt >= MAXRPMMESSAGELINES )
+  if ( lineno >= MAXRPMMESSAGELINES )
     rpmmsg += "[truncated]\n";
   report->progress( 50 );
   int rpm_status = systemStatus();
