@@ -14,13 +14,13 @@
 
 #include <iosfwd>
 
-#include "zypp/base/ReferenceCounted.h"
-#include "zypp/base/NonCopyable.h"
-#include "zypp/base/PtrTypes.h"
-#include "zypp/base/Iterator.h"
+#include <zypp/base/ReferenceCounted.h>
+#include <zypp/base/NonCopyable.h>
+#include <zypp/base/PtrTypes.h>
+#include <zypp/base/Iterator.h>
 
-#include "zypp/ui/SelectableTraits.h"
-#include "zypp/ui/Status.h"
+#include <zypp/ui/SelectableTraits.h>
+#include <zypp/ui/Status.h>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -125,6 +125,8 @@ namespace zypp
       /** The 'best' or 'most interesting' among all available objects.
        * One that is, or is likely to be, chosen for installation, unless
        * it violated any solver policy (see \ref updateCandidateObj).
+       * \note Might return a retracted item if explicitly set by \ref setCandidate
+       * or nothing else available.
        */
       PoolItem candidateObj() const;
 
@@ -132,6 +134,7 @@ namespace zypp
        * In contrary to \ref candidateObj, this may return no item even if
        * there are available objects. This simply means the \ref Repository
        * does not provide this object.
+       * \note Avoids to return retracted items.
        */
       PoolItem candidateObjFrom( Repository repo_r ) const;
 
@@ -140,6 +143,7 @@ namespace zypp
        * there are available objects. This simply means the best object is
        * already installed, and all available objects violate at least one
        * update policy.
+       * \note Avoids to return retracted items.
        */
       PoolItem updateCandidateObj() const;
 
@@ -147,10 +151,14 @@ namespace zypp
        * It's doubtful whether solely looking at the version makes a good
        * candidate, but apps ask for it. Beware that different vendors may
        * use different (uncomparable) version schemata.
+       * \note Avoids to return retracted items.
        */
       PoolItem highestAvailableVersionObj() const;
 
-     /** \c True if \a rhs is installed and one with the same content is available.
+      /** Whether this \ref ident is flagged as AutoInstalled. */
+      bool identIsAutoInstalled() const;
+
+      /** \c True if \a rhs is installed and one with the same content is available.
        * Basically the same name, edition, arch, vendor and buildtime.
        * \see \ref sat::Solvable::identical
        */
@@ -274,6 +282,18 @@ namespace zypp
       picklist_iterator picklistEnd() const;
       inline Iterable<picklist_iterator> picklist() const
       { return makeIterable( picklistBegin(), picklistEnd() ); }
+
+      /** Returned by \ref picklistPos if the Item does not belong to the picklist. */
+      static constexpr const picklist_size_type picklistNoPos = picklist_size_type(-1);
+
+      /** Return the position of \a pi_r in the piclist or \ref picklistNoPos.
+       * \note \ref picklistNoPos is returned if you pass an installed Poolitem,
+       * whci has an \ref identicalAvailableObj.
+       */
+      picklist_size_type picklistPos( const PoolItem & pi_r ) const;
+
+      /** \overload taking a sat::Solvable */
+      picklist_size_type picklistPos( const sat::Solvable & solv_r ) const;
       //@}
 
       ////////////////////////////////////////////////////////////////////////
@@ -305,6 +325,12 @@ namespace zypp
       /** True if candidate object is present but no installed. */
       bool hasCandidateObjOnly() const
       { return ( installedEmpty() ) && candidateObj(); }
+
+      /** True if this Selectable contains a retracted item. */
+      bool hasRetracted() const;
+
+      /** True if this Selectable contains an installed retracted item. */
+      bool hasRetractedInstalled() const;
       //@}
 
       /**
@@ -422,10 +448,22 @@ namespace zypp
       bool unmodified() const
       { return fate() == UNMODIFIED; }
 
-      /** True if locked (subclass of unmodified). */
+      /** True if locked (subclass of unmodified).
+       * The \ref locked status indicates that \b all installed and/or \b all available
+       * items are locked. So you can't remove and/or can't install any item. This
+       * is the common case.
+       * \see \ref hasLocks
+       */
       bool locked() const
       { Status st( status() ); return( st == S_Protected || st == S_Taboo ); }
 
+      /** True if it includes locked items (don't mix this with the \ref locked status).
+       * This is also \c true for partially locked items, where only specific versions
+       * are locked.
+       * \see \ref locked
+       */
+      bool hasLocks() const;
+
       /** True if either to delete or to install */
       bool toModify() const
       { return fate() != UNMODIFIED; }
@@ -501,7 +539,7 @@ namespace zypp
 
     public:
       /** Implementation  */
-      class Impl;
+      struct Impl;
       typedef shared_ptr<Impl> Impl_Ptr;
       /** Default ctor */
       Selectable( Impl_Ptr pimpl_r );
