@@ -12,8 +12,8 @@
 #ifndef   ZYPP_URL_URLBASE_H
 #define   ZYPP_URL_URLBASE_H
 
-#include "zypp/url/UrlUtils.h"
-#include "zypp/base/PtrTypes.h"
+#include <zypp/url/UrlUtils.h>
+#include <zypp/base/PtrTypes.h>
 
 
 //////////////////////////////////////////////////////////////////////
@@ -230,6 +230,7 @@ namespace zypp
         return o.opt & opt;
       }
 
+      static const ViewOption hotfix1050625;
     private:
       ViewOption(int option);
       int opt;
@@ -594,6 +595,10 @@ namespace zypp
       virtual std::string
       getQueryString() const;
 
+      /** \overload Returns the safe query string (passwds stripped) unless WITH_PASSWORD is set. */
+      virtual std::string
+      getQueryString( const ViewOptions & viewopts_r ) const;
+
       /**
        * Returns a vector with query string parameter substrings.
        *
@@ -995,7 +1000,7 @@ namespace zypp
       void
       setViewOptions(const ViewOptions &vopts);
 
-
+      std::string asString1050625() const;
     protected:
       /**
        * Utility method to cleanup an encoded path name.
